@@ -16,4 +16,7 @@ module.exports = {
         libraryTarget: 'umd',
         libraryExport: 'default',
     },
+    optimization: {
+        minimize: false,
+    },
 };
