@@ -5,7 +5,7 @@ declare(strict_types=1);
 namespace PhpMyAdmin\Controllers\Database;
 
 use PhpMyAdmin\Controllers\AbstractController as Controller;
-use PhpMyAdmin\Response;
+use PhpMyAdmin\ResponseRenderer;
 use PhpMyAdmin\Template;
 
 abstract class AbstractController extends Controller
@@ -13,11 +13,7 @@ abstract class AbstractController extends Controller
     /** @var string */
     protected $db;
 
-    /**
-     * @param Response $response
-     * @param string   $db       Database name
-     */
-    public function __construct($response, Template $template, $db)
+    public function __construct(ResponseRenderer $response, Template $template, string $db)
     {
         parent::__construct($response, $template);
         $this->db = $db;
