@@ -5,14 +5,8 @@ declare(strict_types=1);
 namespace PhpMyAdmin;
 
 use ZipArchive;
-use const UPLOAD_ERR_CANT_WRITE;
-use const UPLOAD_ERR_EXTENSION;
-use const UPLOAD_ERR_FORM_SIZE;
-use const UPLOAD_ERR_INI_SIZE;
-use const UPLOAD_ERR_NO_FILE;
-use const UPLOAD_ERR_NO_TMP_DIR;
-use const UPLOAD_ERR_OK;
-use const UPLOAD_ERR_PARTIAL;
+
+use function __;
 use function basename;
 use function bin2hex;
 use function bzopen;
@@ -21,7 +15,6 @@ use function extension_loaded;
 use function fclose;
 use function feof;
 use function file_get_contents;
-use function filesize;
 use function fopen;
 use function fread;
 use function function_exists;
@@ -41,6 +34,15 @@ use function tempnam;
 use function trim;
 use function unlink;
 
+use const UPLOAD_ERR_CANT_WRITE;
+use const UPLOAD_ERR_EXTENSION;
+use const UPLOAD_ERR_FORM_SIZE;
+use const UPLOAD_ERR_INI_SIZE;
+use const UPLOAD_ERR_NO_FILE;
+use const UPLOAD_ERR_NO_TMP_DIR;
+use const UPLOAD_ERR_OK;
+use const UPLOAD_ERR_PARTIAL;
+
 /**
  * File wrapper class
  *
@@ -49,34 +51,19 @@ use function unlink;
  */
 class File
 {
-    /**
-     * @var string the temporary file name
-     * @access protected
-     */
+    /** @var string the temporary file name */
     protected $name = null;
 
-    /**
-     * @var string the content
-     * @access protected
-     */
+    /** @var string the content */
     protected $content = null;
 
-    /**
-     * @var Message|null the error message
-     * @access protected
-     */
+    /** @var Message|null the error message */
     protected $errorMessage = null;
 
-    /**
-     * @var bool whether the file is temporary or not
-     * @access protected
-     */
+    /** @var bool whether the file is temporary or not */
     protected $isTemp = false;
 
-    /**
-     * @var string type of compression
-     * @access protected
-     */
+    /** @var string type of compression */
     protected $compression = null;
 
     /** @var int */
@@ -99,8 +86,6 @@ class File
 
     /**
      * @param bool|string $name file name or false
-     *
-     * @access public
      */
     public function __construct($name = false)
     {
@@ -119,8 +104,6 @@ class File
      * destructor
      *
      * @see     File::cleanUp()
-     *
-     * @access public
      */
     public function __destruct()
     {
@@ -129,10 +112,6 @@ class File
 
     /**
      * deletes file if it is temporary, usually from a moved upload file
-     *
-     * @return bool success
-     *
-     * @access public
      */
     public function cleanUp(): bool
     {
@@ -145,10 +124,6 @@ class File
 
     /**
      * deletes the file
-     *
-     * @return bool success
-     *
-     * @access public
      */
     public function delete(): bool
     {
@@ -160,10 +135,6 @@ class File
      * file objects with temp flags are deleted with object destruction
      *
      * @param bool $is_temp sets the temp flag
-     *
-     * @return bool File::$_is_temp
-     *
-     * @access public
      */
     public function isTemp(?bool $is_temp = null): bool
     {
@@ -178,8 +149,6 @@ class File
      * accessor
      *
      * @param string|null $name file name
-     *
-     * @access public
      */
     public function setName(?string $name): void
     {
@@ -189,9 +158,7 @@ class File
     /**
      * Gets file content
      *
-     * @return string|false|null the binary file content, or false if no content
-     *
-     * @access public
+     * @return string|false the binary file content, or false if no content
      */
     public function getRawContent()
     {
@@ -207,19 +174,7 @@ class File
             return false;
         }
 
-        if (function_exists('file_get_contents')) {
-            $this->content = file_get_contents((string) $this->getName());
-
-            return $this->content;
-        }
-
-        $size = filesize((string) $this->getName());
-
-        if ($size) {
-            $handle = fopen((string) $this->getName(), 'rb');
-            $this->content = fread($handle, $size);
-            fclose($handle);
-        }
+        $this->content = file_get_contents((string) $this->getName());
 
         return $this->content;
     }
@@ -229,13 +184,11 @@ class File
      *
      * @return string|false the binary file content as a string,
      *                      or false if no content
-     *
-     * @access public
      */
     public function getContent()
     {
         $result = $this->getRawContent();
-        if ($result === false || $result === null) {
+        if ($result === false) {
             return false;
         }
 
@@ -244,8 +197,6 @@ class File
 
     /**
      * Whether file is uploaded.
-     *
-     * @access public
      */
     public function isUploaded(): bool
     {
@@ -260,8 +211,6 @@ class File
      * accessor
      *
      * @return string|null File::$_name
-     *
-     * @access public
      */
     public function getName(): ?string
     {
@@ -272,10 +221,6 @@ class File
      * Initializes object from uploaded file.
      *
      * @param string $name name of file uploaded
-     *
-     * @return bool success
-     *
-     * @access public
      */
     public function setUploadedFile(string $name): bool
     {
@@ -296,41 +241,34 @@ class File
      *
      * @param string $key       the md5 hash of the column name
      * @param string $rownumber number of row to process
-     *
-     * @return bool success
-     *
-     * @access public
      */
     public function setUploadedFromTblChangeRequest(
         string $key,
         string $rownumber
     ): bool {
-        if (! isset($_FILES['fields_upload'])
+        if (
+            ! isset($_FILES['fields_upload'])
             || empty($_FILES['fields_upload']['name']['multi_edit'][$rownumber][$key])
         ) {
             return false;
         }
-        $file = $this->fetchUploadedFromTblChangeRequestMultiple(
-            $_FILES['fields_upload'],
-            $rownumber,
-            $key
-        );
+
+        $file = $this->fetchUploadedFromTblChangeRequestMultiple($_FILES['fields_upload'], $rownumber, $key);
 
         switch ($file['error']) {
             case UPLOAD_ERR_OK:
                 return $this->setUploadedFile($file['tmp_name']);
+
             case UPLOAD_ERR_NO_FILE:
                 break;
             case UPLOAD_ERR_INI_SIZE:
                 $this->errorMessage = Message::error(__(
-                    'The uploaded file exceeds the upload_max_filesize directive in '
-                    . 'php.ini.'
+                    'The uploaded file exceeds the upload_max_filesize directive in php.ini.'
                 ));
                 break;
             case UPLOAD_ERR_FORM_SIZE:
                 $this->errorMessage = Message::error(__(
-                    'The uploaded file exceeds the MAX_FILE_SIZE directive that was '
-                    . 'specified in the HTML form.'
+                    'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.'
                 ));
                 break;
             case UPLOAD_ERR_PARTIAL:
@@ -379,7 +317,6 @@ class File
      *
      * @return array
      *
-     * @access public
      * @static
      */
     public function fetchUploadedFromTblChangeRequestMultiple(
@@ -401,22 +338,17 @@ class File
      *
      * @param string $key       the md5 hash of the column name
      * @param string $rownumber number of row to process
-     *
-     * @return bool success
-     *
-     * @access public
      */
     public function setSelectedFromTblChangeRequest(
         string $key,
         ?string $rownumber = null
     ): bool {
-        if (! empty($_REQUEST['fields_uploadlocal']['multi_edit'][$rownumber][$key])
+        if (
+            ! empty($_REQUEST['fields_uploadlocal']['multi_edit'][$rownumber][$key])
             && is_string($_REQUEST['fields_uploadlocal']['multi_edit'][$rownumber][$key])
         ) {
             // ... whether with multiple rows ...
-            return $this->setLocalSelectedFile(
-                $_REQUEST['fields_uploadlocal']['multi_edit'][$rownumber][$key]
-            );
+            return $this->setLocalSelectedFile($_REQUEST['fields_uploadlocal']['multi_edit'][$rownumber][$key]);
         }
 
         return false;
@@ -426,8 +358,6 @@ class File
      * Returns possible error message.
      *
      * @return Message|null error message
-     *
-     * @access public
      */
     public function getError(): ?Message
     {
@@ -436,10 +366,6 @@ class File
 
     /**
      * Checks whether there was any error.
-     *
-     * @return bool whether an error occurred or not
-     *
-     * @access public
      */
     public function isError(): bool
     {
@@ -452,10 +378,6 @@ class File
      *
      * @param string $key       the md5 hash of the column name
      * @param string $rownumber number of row to process
-     *
-     * @return bool success
-     *
-     * @access public
      */
     public function checkTblChangeForm(string $key, string $rownumber): bool
     {
@@ -472,6 +394,7 @@ class File
 
             return true;
         }
+
         // all failed, whether just no file uploaded/selected or an error
 
         return false;
@@ -481,10 +404,6 @@ class File
      * Sets named file to be read from UploadDir.
      *
      * @param string $name file name
-     *
-     * @return bool success
-     *
-     * @access public
      */
     public function setLocalSelectedFile(string $name): bool
     {
@@ -492,6 +411,10 @@ class File
             return false;
         }
 
+        if (! is_string($GLOBALS['cfg']['UploadDir'])) {
+            return false;
+        }
+
         $this->setName(
             Util::userDir($GLOBALS['cfg']['UploadDir']) . Core::securePath($name)
         );
@@ -501,6 +424,7 @@ class File
 
             return false;
         }
+
         if (! $this->isReadable()) {
             $this->errorMessage = Message::error(__('File could not be read!'));
             $this->setName(null);
@@ -513,10 +437,6 @@ class File
 
     /**
      * Checks whether file can be read.
-     *
-     * @return bool whether the file is readable or not
-     *
-     * @access public
      */
     public function isReadable(): bool
     {
@@ -530,10 +450,7 @@ class File
      * before opening it. The FAQ 1.11 explains how to create the "./tmp"
      * directory - if needed
      *
-     * @return bool whether uploaded file is fine or not
-     *
      * @todo move check of $cfg['TempDir'] into Config?
-     * @access public
      */
     public function checkUploadedFile(): bool
     {
@@ -541,7 +458,7 @@ class File
             return true;
         }
 
-        $tmp_subdir = $GLOBALS['PMA_Config']->getUploadTempDir();
+        $tmp_subdir = $GLOBALS['config']->getUploadTempDir();
         if ($tmp_subdir === null) {
             // cannot create directory or access, point user to FAQ 1.11
             $this->errorMessage = Message::error(__(
@@ -590,7 +507,6 @@ class File
      *
      * @todo   move file read part into readChunk() or getChunk()
      * @todo   add support for compression plugins
-     * @access protected
      */
     protected function detectCompression()
     {
@@ -624,7 +540,7 @@ class File
     /**
      * Returns the file handle
      *
-     * @return resource file handle
+     * @return resource|null file handle
      */
     public function getHandle()
     {
@@ -672,6 +588,7 @@ class File
         switch ($this->getCompression()) {
             case false:
                 return false;
+
             case 'application/bzip2':
                 if (! $GLOBALS['cfg']['BZipDump'] || ! function_exists('bzopen')) {
                     $this->errorUnsupported();
@@ -698,6 +615,7 @@ class File
                 $this->errorUnsupported();
 
                 return false;
+
             case 'none':
                 $this->handle = @fopen((string) $this->getName(), 'r');
                 break;
@@ -723,6 +641,7 @@ class File
 
             return false;
         }
+
         $this->content = $result['data'];
         $this->offset = 0;
 
@@ -753,6 +672,7 @@ class File
             $this->content = '';
             $this->offset = 0;
         }
+
         $this->cleanUp();
     }
 
@@ -763,20 +683,26 @@ class File
      */
     public function read(int $size): string
     {
-        switch ($this->compression) {
-            case 'application/bzip2':
-                return bzread($this->handle, $size);
-            case 'application/gzip':
-                return gzread($this->handle, $size);
-            case 'application/zip':
-                $result = mb_strcut($this->content, $this->offset, $size);
-                $this->offset += strlen($result);
+        if ($this->compression === 'application/zip') {
+            $result = mb_strcut($this->content, $this->offset, $size);
+            $this->offset += strlen($result);
 
-                return $result;
-            case 'none':
-            default:
-                return fread($this->handle, $size);
+            return $result;
         }
+
+        if ($this->handle === null) {
+            return '';
+        }
+
+        if ($this->compression === 'application/bzip2') {
+            return (string) bzread($this->handle, $size);
+        }
+
+        if ($this->compression === 'application/gzip') {
+            return (string) gzread($this->handle, $size);
+        }
+
+        return (string) fread($this->handle, $size);
     }
 
     /**
@@ -803,8 +729,6 @@ class File
      * Returns compression used by file.
      *
      * @return string MIME type of compression, none for none
-     *
-     * @access public
      */
     public function getCompression(): string
     {
