@@ -1,19 +1,17 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * This class is responsible for instantiating
  * the various components of the navigation panel
- *
- * @package PhpMyAdmin-navigation
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Navigation;
 
 use PhpMyAdmin\Config\PageSettings;
+use PhpMyAdmin\ConfigStorage\Relation;
 use PhpMyAdmin\DatabaseInterface;
-use PhpMyAdmin\Relation;
-use PhpMyAdmin\Response;
+use PhpMyAdmin\ResponseRenderer;
 use PhpMyAdmin\Sanitize;
 use PhpMyAdmin\Server\Select;
 use PhpMyAdmin\Template;
@@ -21,35 +19,35 @@ use PhpMyAdmin\Theme;
 use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
 
+use function __;
+use function count;
+use function defined;
+use function file_exists;
+use function is_bool;
+use function parse_url;
+use function strpos;
+use function trim;
+
+use const PHP_URL_HOST;
+
 /**
  * The navigation panel - displays server, db and table selection tree
- *
- * @package PhpMyAdmin-Navigation
  */
 class Navigation
 {
-    /**
-     * @var Template
-     */
+    /** @var Template */
     private $template;
 
-    /**
-     * @var Relation
-     */
+    /** @var Relation */
     private $relation;
 
-    /**
-     * @var DatabaseInterface
-     */
+    /** @var DatabaseInterface */
     private $dbi;
 
-    /**
-     * @var NavigationTree
-     */
+    /** @var NavigationTree */
     private $tree;
 
     /**
-     * Navigation constructor.
      * @param Template          $template Template instance
      * @param Relation          $relation Relation instance
      * @param DatabaseInterface $dbi      DatabaseInterface instance
@@ -79,7 +77,7 @@ class Navigation
             'source' => '',
         ];
 
-        $response = Response::getInstance();
+        $response = ResponseRenderer::getInstance();
         if (! $response->isAjax()) {
             $logo['source'] = $this->getLogoSource();
             $logo['has_link'] = (string) $cfg['NavigationLogoLink'] !== '';
@@ -87,6 +85,7 @@ class Navigation
             if (! Sanitize::checkLink($logo['link'], true)) {
                 $logo['link'] = 'index.php';
             }
+
             if ($cfg['NavigationLogoLinkWindow'] === 'main') {
                 if (empty(parse_url($logo['link'], PHP_URL_HOST))) {
                     $hasStartChar = strpos($logo['link'], '?');
@@ -94,8 +93,13 @@ class Navigation
                         [],
                         is_bool($hasStartChar) ? '?' : Url::getArgSeparator()
                     );
+                    // Internal link detected
+                    $logo['attributes'] = '';
+                } else {
+                    // External links having a domain name should not be considered
+                    // to be links that can use our internal ajax loading
+                    $logo['attributes'] = ' class="disableAjax"';
                 }
-                $logo['attributes'] = '';
             }
 
             if ($cfg['NavigationDisplayServers'] && count($cfg['Servers']) > 1) {
@@ -103,13 +107,13 @@ class Navigation
             }
 
             if (! defined('PMA_DISABLE_NAVI_SETTINGS')) {
-                $navigationSettings = PageSettings::getNaviSettings();
+                $pageSettings = new PageSettings('Navi', 'pma_navigation_settings');
+                $response->addHTML($pageSettings->getErrorHTML());
+                $navigationSettings = $pageSettings->getHTML();
             }
         }
-        if (! $response->isAjax()
-            || ! empty($_POST['full'])
-            || ! empty($_POST['reload'])
-        ) {
+
+        if (! $response->isAjax() || ! empty($_POST['full']) || ! empty($_POST['reload'])) {
             if ($cfg['ShowDatabasesNavigationAsTree']) {
                 // provide database tree in navigation
                 $navRender = $this->tree->renderState();
@@ -124,6 +128,7 @@ class Navigation
         return $this->template->render('navigation/main', [
             'is_ajax' => $response->isAjax(),
             'logo' => $logo,
+            'config_navigation_width' => $cfg['NavigationWidth'],
             'is_synced' => $cfg['NavigationLinkWithMainPanel'],
             'is_highlighted' => $cfg['NavigationTreePointerEnable'],
             'is_autoexpanded' => $cfg['NavigationTreeAutoexpandSingleDb'],
@@ -136,6 +141,7 @@ class Navigation
             'is_navigation_settings_enabled' => ! defined('PMA_DISABLE_NAVI_SETTINGS'),
             'navigation_settings' => $navigationSettings ?? '',
             'is_drag_drop_import_enabled' => $cfg['enable_drag_drop_import'] === true,
+            'is_mariadb' => $this->dbi->isMariaDB(),
         ]);
     }
 
@@ -146,27 +152,30 @@ class Navigation
      * @param string $itemType  type of the navigation tree item
      * @param string $dbName    database name
      * @param string $tableName table name if applicable
-     *
-     * @return void
      */
     public function hideNavigationItem(
         $itemName,
         $itemType,
         $dbName,
         $tableName = null
-    ) {
-        $navTable = Util::backquote($GLOBALS['cfgRelation']['db'])
-            . "." . Util::backquote($GLOBALS['cfgRelation']['navigationhiding']);
-        $sqlQuery = "INSERT INTO " . $navTable
-            . "(`username`, `item_name`, `item_type`, `db_name`, `table_name`)"
-            . " VALUES ("
+    ): void {
+        $navigationItemsHidingFeature = $this->relation->getRelationParameters()->navigationItemsHidingFeature;
+        if ($navigationItemsHidingFeature === null) {
+            return;
+        }
+
+        $navTable = Util::backquote($navigationItemsHidingFeature->database)
+            . '.' . Util::backquote($navigationItemsHidingFeature->navigationHiding);
+        $sqlQuery = 'INSERT INTO ' . $navTable
+            . '(`username`, `item_name`, `item_type`, `db_name`, `table_name`)'
+            . ' VALUES ('
             . "'" . $this->dbi->escapeString($GLOBALS['cfg']['Server']['user']) . "',"
             . "'" . $this->dbi->escapeString($itemName) . "',"
             . "'" . $this->dbi->escapeString($itemType) . "',"
             . "'" . $this->dbi->escapeString($dbName) . "',"
-            . "'" . (! empty($tableName) ? $this->dbi->escapeString($tableName) : "" )
+            . "'" . (! empty($tableName) ? $this->dbi->escapeString($tableName) : '' )
             . "')";
-        $this->relation->queryAsControlUser($sqlQuery, false);
+        $this->dbi->tryQueryAsControlUser($sqlQuery);
     }
 
     /**
@@ -177,19 +186,22 @@ class Navigation
      * @param string $itemType  type of the navigation tree item
      * @param string $dbName    database name
      * @param string $tableName table name if applicable
-     *
-     * @return void
      */
     public function unhideNavigationItem(
         $itemName,
         $itemType,
         $dbName,
         $tableName = null
-    ) {
-        $navTable = Util::backquote($GLOBALS['cfgRelation']['db'])
-            . "." . Util::backquote($GLOBALS['cfgRelation']['navigationhiding']);
-        $sqlQuery = "DELETE FROM " . $navTable
-            . " WHERE"
+    ): void {
+        $navigationItemsHidingFeature = $this->relation->getRelationParameters()->navigationItemsHidingFeature;
+        if ($navigationItemsHidingFeature === null) {
+            return;
+        }
+
+        $navTable = Util::backquote($navigationItemsHidingFeature->database)
+            . '.' . Util::backquote($navigationItemsHidingFeature->navigationHiding);
+        $sqlQuery = 'DELETE FROM ' . $navTable
+            . ' WHERE'
             . " `username`='"
             . $this->dbi->escapeString($GLOBALS['cfg']['Server']['user']) . "'"
             . " AND `item_name`='" . $this->dbi->escapeString($itemName) . "'"
@@ -197,9 +209,9 @@ class Navigation
             . " AND `db_name`='" . $this->dbi->escapeString($dbName) . "'"
             . (! empty($tableName)
                 ? " AND `table_name`='" . $this->dbi->escapeString($tableName) . "'"
-                : ""
+                : ''
             );
-        $this->relation->queryAsControlUser($sqlQuery, false);
+        $this->dbi->tryQueryAsControlUser($sqlQuery);
     }
 
     /**
@@ -236,31 +248,38 @@ class Navigation
     /**
      * @param string      $database Database name
      * @param string|null $table    Table name
+     *
      * @return array
      */
     private function getHiddenItems(string $database, ?string $table): array
     {
-        $navTable = Util::backquote($GLOBALS['cfgRelation']['db'])
-            . "." . Util::backquote($GLOBALS['cfgRelation']['navigationhiding']);
-        $sqlQuery = "SELECT `item_name`, `item_type` FROM " . $navTable
+        $navigationItemsHidingFeature = $this->relation->getRelationParameters()->navigationItemsHidingFeature;
+        if ($navigationItemsHidingFeature === null) {
+            return [];
+        }
+
+        $navTable = Util::backquote($navigationItemsHidingFeature->database)
+            . '.' . Util::backquote($navigationItemsHidingFeature->navigationHiding);
+        $sqlQuery = 'SELECT `item_name`, `item_type` FROM ' . $navTable
             . " WHERE `username`='"
             . $this->dbi->escapeString($GLOBALS['cfg']['Server']['user']) . "'"
             . " AND `db_name`='" . $this->dbi->escapeString($database) . "'"
             . " AND `table_name`='"
             . (! empty($table) ? $this->dbi->escapeString($table) : '') . "'";
-        $result = $this->relation->queryAsControlUser($sqlQuery, false);
+        $result = $this->dbi->tryQueryAsControlUser($sqlQuery);
 
         $hidden = [];
         if ($result) {
-            while ($row = $this->dbi->fetchArray($result)) {
+            foreach ($result as $row) {
                 $type = $row['item_type'];
                 if (! isset($hidden[$type])) {
                     $hidden[$type] = [];
                 }
+
                 $hidden[$type][] = $row['item_name'];
             }
         }
-        $this->dbi->freeResult($result);
+
         return $hidden;
     }
 
@@ -269,17 +288,18 @@ class Navigation
      */
     private function getLogoSource(): string
     {
-        /** @var Theme|null $PMA_Theme */
-        global $PMA_Theme;
-        if ($PMA_Theme !== null) {
-            if (@file_exists($PMA_Theme->getFsPath() . 'img/logo_left.png')) {
-                return $PMA_Theme->getPath() . '/img/logo_left.png';
+        global $theme;
+
+        if ($theme instanceof Theme) {
+            if (@file_exists($theme->getFsPath() . 'img/logo_left.png')) {
+                return $theme->getPath() . '/img/logo_left.png';
             }
 
-            if (@file_exists($PMA_Theme->getFsPath() . 'img/pma_logo2.png')) {
-                return $PMA_Theme->getPath() . '/img/pma_logo2.png';
+            if (@file_exists($theme->getFsPath() . 'img/pma_logo2.png')) {
+                return $theme->getPath() . '/img/pma_logo2.png';
             }
         }
+
         return '';
     }
 }
