@@ -1,20 +1,16 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Functionality for the navigation tree
- *
- * @package PhpMyAdmin-Navigation
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Navigation\Nodes;
 
-use PhpMyAdmin\Util;
+use function __;
 
 /**
  * Represents a trigger node in the navigation tree
- *
- * @package PhpMyAdmin-Navigation
  */
 class NodeTrigger extends Node
 {
@@ -29,13 +25,18 @@ class NodeTrigger extends Node
     public function __construct($name, $type = Node::OBJECT, $isGroup = false)
     {
         parent::__construct($name, $type, $isGroup);
-        $this->icon = Util::getImage('b_triggers');
+        $this->icon = ['image' => 'b_triggers', 'title' => __('Trigger')];
         $this->links = [
-            'text' => 'db_triggers.php?server=' . $GLOBALS['server']
-                . '&amp;db=%3$s&amp;item_name=%1$s&amp;edit_item=1',
-            'icon' => 'db_triggers.php?server=' . $GLOBALS['server']
-                . '&amp;db=%3$s&amp;item_name=%1$s&amp;export_item=1',
+            'text' => [
+                'route' => '/database/triggers',
+                'params' => ['edit_item' => 1, 'db' => null, 'item_name' => null],
+            ],
+            'icon' => [
+                'route' => '/database/triggers',
+                'params' => ['export_item' => 1, 'db' => null, 'item_name' => null],
+            ],
         ];
         $this->classes = 'trigger';
+        $this->urlParamName = 'item_name';
     }
 }
