@@ -55,20 +55,14 @@ class ConfigFileTest extends AbstractTestCase
     public function testNewObjectState(): void
     {
         // Check default dynamic values
-        $this->assertEquals(
-            [],
-            $this->object->getConfig()
-        );
+        self::assertSame([], $this->object->getConfig());
 
         // Check environment state
-        $this->assertEquals(
-            [],
-            $_SESSION['ConfigFile1']
-        );
+        self::assertSame([], $_SESSION['ConfigFile1']);
 
         // Validate default value used in tests
         $default_value = $this->object->getDefault(self::SIMPLE_KEY_WITH_DEFAULT_VALUE);
-        $this->assertNotNull($default_value);
+        self::assertNotNull($default_value);
     }
 
     /**
@@ -90,7 +84,7 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->set(self::SIMPLE_KEY_WITH_DEFAULT_VALUE, $default_simple_value);
         $this->object->set('Servers/1/host', $default_host);
         $this->object->set('Servers/2/host', $default_host);
-        $this->assertEmpty($this->object->getConfig());
+        self::assertEmpty($this->object->getConfig());
 
         /**
          * Case 2: persistent keys should be always present in flat array,
@@ -98,21 +92,15 @@ class ConfigFileTest extends AbstractTestCase
          */
         $this->object->setPersistKeys(array_keys($default_config));
         $this->object->resetConfigData();
-        $this->assertEmpty($this->object->getConfig());
-        $this->assertEquals(
-            $default_config,
-            $this->object->getConfigArray()
-        );
+        self::assertEmpty($this->object->getConfig());
+        self::assertSame($default_config, $this->object->getConfigArray());
 
         /**
          * Case 3: persistent keys should be always saved,
          * even if set to default values
          */
         $this->object->set('Servers/2/host', $default_host);
-        $this->assertEquals(
-            ['Servers' => [2 => ['host' => $default_host]]],
-            $this->object->getConfig()
-        );
+        self::assertSame(['Servers' => [2 => ['host' => $default_host]]], $this->object->getConfig());
     }
 
     /**
@@ -128,13 +116,10 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->set('b', 2);
         $this->object->set('c', 3);
 
-        $this->assertEquals(
-            [
-                'a' => 1,
-                'c' => 3,
-            ],
-            $this->object->getConfig()
-        );
+        self::assertSame([
+            'a' => 1,
+            'c' => 3,
+        ], $this->object->getConfig());
 
         /**
          * Case 2: disabling filter should allow to set b
@@ -142,14 +127,11 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->setAllowedKeys(null);
         $this->object->set('b', 2);
 
-        $this->assertEquals(
-            [
-                'a' => 1,
-                'b' => 2,
-                'c' => 3,
-            ],
-            $this->object->getConfig()
-        );
+        self::assertEquals([
+            'a' => 1,
+            'b' => 2,
+            'c' => 3,
+        ], $this->object->getConfig());
     }
 
     /**
@@ -167,22 +149,16 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->set('Servers/1/passthrough2', 2);
         $this->object->updateWithGlobalConfig(['Servers/value1' => 3]);
 
-        $this->assertEquals(
-            [
-                'Servers' => [
-                    1 => [
-                        'passthrough1' => 1,
-                        'passthrough2' => 2,
-                        'value1' => 3,
-                    ],
+        self::assertSame([
+            'Servers' => [
+                1 => [
+                    'passthrough1' => 1,
+                    'passthrough2' => 2,
+                    'value1' => 3,
                 ],
             ],
-            $this->object->getConfig()
-        );
-        $this->assertEquals(
-            3,
-            $this->object->get('Servers/1/value1')
-        );
+        ], $this->object->getConfig());
+        self::assertSame(3, $this->object->get('Servers/1/value1'));
     }
 
     /**
@@ -194,8 +170,8 @@ class ConfigFileTest extends AbstractTestCase
 
         $this->object->resetConfigData();
 
-        $this->assertEmpty($this->object->getConfig());
-        $this->assertEmpty($this->object->getConfigArray());
+        self::assertEmpty($this->object->getConfig());
+        self::assertEmpty($this->object->getConfigArray());
     }
 
     /**
@@ -206,14 +182,8 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->set('abc', 'should be deleted by setConfigData');
         $this->object->setConfigData(['a' => 'b']);
 
-        $this->assertEquals(
-            ['a' => 'b'],
-            $this->object->getConfig()
-        );
-        $this->assertEquals(
-            ['a' => 'b'],
-            $this->object->getConfigArray()
-        );
+        self::assertSame(['a' => 'b'], $this->object->getConfig());
+        self::assertSame(['a' => 'b'], $this->object->getConfigArray());
     }
 
     /**
@@ -227,32 +197,15 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->set('Servers/4/host', $nondefault_host);
         $this->object->set('Servers/5/host', $default_host);
         $this->object->set('Servers/6/host', $default_host, 'Servers/6/host');
-        $this->assertEquals(
-            $nondefault_host,
-            $this->object->get('Servers/4/host')
-        );
-        $this->assertEquals(
-            null,
-            $this->object->get('Servers/5/host')
-        );
-        $this->assertEquals(
-            $default_host,
-            $this->object->get('Servers/6/host')
-        );
+        self::assertSame($nondefault_host, $this->object->get('Servers/4/host'));
+        self::assertNull($this->object->get('Servers/5/host'));
+        self::assertSame($default_host, $this->object->get('Servers/6/host'));
 
         // return default value for nonexistent keys
-        $this->assertNull(
-            $this->object->get('key not excist')
-        );
-        $this->assertEquals(
-            [1],
-            $this->object->get('key not excist', [1])
-        );
+        self::assertNull($this->object->get('key not excist'));
+        self::assertSame([1], $this->object->get('key not excist', [1]));
         $default = new stdClass();
-        $this->assertInstanceOf(
-            stdClass::class,
-            $this->object->get('key not excist', $default)
-        );
+        self::assertInstanceOf(stdClass::class, $this->object->get('key not excist', $default));
     }
 
     /**
@@ -264,7 +217,7 @@ class ConfigFileTest extends AbstractTestCase
 
         // default values are not written
         $this->object->set(self::SIMPLE_KEY_WITH_DEFAULT_VALUE, $default_value);
-        $this->assertEmpty($this->object->getConfig());
+        self::assertEmpty($this->object->getConfig());
     }
 
     /**
@@ -279,7 +232,7 @@ class ConfigFileTest extends AbstractTestCase
             [self::SIMPLE_KEY_WITH_DEFAULT_VALUE => $default_value]
         );
         $this->object->set(self::SIMPLE_KEY_WITH_DEFAULT_VALUE, $default_value);
-        $this->assertEmpty($this->object->getConfig());
+        self::assertEmpty($this->object->getConfig());
 
         // but if config.inc.php differs from the default values,
         // allow to overwrite with value from the default values
@@ -288,10 +241,7 @@ class ConfigFileTest extends AbstractTestCase
             [self::SIMPLE_KEY_WITH_DEFAULT_VALUE => $config_inc_php_value]
         );
         $this->object->set(self::SIMPLE_KEY_WITH_DEFAULT_VALUE, $default_value);
-        $this->assertEquals(
-            [self::SIMPLE_KEY_WITH_DEFAULT_VALUE => $default_value],
-            $this->object->getConfig()
-        );
+        self::assertSame([self::SIMPLE_KEY_WITH_DEFAULT_VALUE => $default_value], $this->object->getConfig());
     }
 
     /**
@@ -304,16 +254,16 @@ class ConfigFileTest extends AbstractTestCase
         $flat_default_config = $this->object->getFlatDefaultConfig();
 
         $default_value = $this->object->getDefault(self::SIMPLE_KEY_WITH_DEFAULT_VALUE);
-        $this->assertEquals($default_value, $flat_default_config[self::SIMPLE_KEY_WITH_DEFAULT_VALUE]);
+        self::assertSame($default_value, $flat_default_config[self::SIMPLE_KEY_WITH_DEFAULT_VALUE]);
 
         $localhost_value = $this->object->getDefault('Servers/1/host');
-        $this->assertEquals($localhost_value, $flat_default_config['Servers/1/host']);
+        self::assertSame($localhost_value, $flat_default_config['Servers/1/host']);
 
         $settings = new Settings([]);
         $cfg = $settings->toArray();
 
-        $this->assertGreaterThanOrEqual(100, count($cfg));
-        $this->assertGreaterThanOrEqual(count($cfg), count($flat_default_config));
+        self::assertGreaterThanOrEqual(100, count($cfg));
+        self::assertGreaterThanOrEqual(count($cfg), count($flat_default_config));
     }
 
     /**
@@ -325,13 +275,10 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->set('key2', 'value');
         $this->object->updateWithGlobalConfig(['key' => 'ABC']);
 
-        $this->assertEquals(
-            [
-                'key' => 'ABC',
-                'key2' => 'value',
-            ],
-            $this->object->getConfig()
-        );
+        self::assertSame([
+            'key' => 'ABC',
+            'key2' => 'value',
+        ], $this->object->getConfig());
     }
 
     /**
@@ -339,15 +286,9 @@ class ConfigFileTest extends AbstractTestCase
      */
     public function testGetCanonicalPath(): void
     {
-        $this->assertEquals(
-            'Servers/1/abcd',
-            $this->object->getCanonicalPath('Servers/2/abcd')
-        );
+        self::assertSame('Servers/1/abcd', $this->object->getCanonicalPath('Servers/2/abcd'));
 
-        $this->assertEquals(
-            'Servers/foo/bar',
-            $this->object->getCanonicalPath('Servers/foo/bar')
-        );
+        self::assertSame('Servers/foo/bar', $this->object->getCanonicalPath('Servers/foo/bar'));
     }
 
     /**
@@ -357,17 +298,11 @@ class ConfigFileTest extends AbstractTestCase
     {
         $cfg_db = include ROOT_PATH . 'libraries/config.values.php';
         // verify that $cfg_db read from config.values.php is valid
-        $this->assertGreaterThanOrEqual(20, count($cfg_db));
+        self::assertGreaterThanOrEqual(20, count($cfg_db));
 
-        $this->assertEquals(
-            $cfg_db['Servers'][1]['port'],
-            $this->object->getDbEntry('Servers/1/port')
-        );
-        $this->assertNull($this->object->getDbEntry('no such key'));
-        $this->assertEquals(
-            [1],
-            $this->object->getDbEntry('no such key', [1])
-        );
+        self::assertSame($cfg_db['Servers'][1]['port'], $this->object->getDbEntry('Servers/1/port'));
+        self::assertNull($this->object->getDbEntry('no such key'));
+        self::assertSame([1], $this->object->getDbEntry('no such key', [1]));
     }
 
     /**
@@ -381,39 +316,24 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->set('Servers/4/x', 4);
         $this->object->set('ServerDefault', 3);
 
-        $this->assertEquals(
-            4,
-            $this->object->getServerCount()
-        );
+        self::assertSame(4, $this->object->getServerCount());
 
         $this->object->removeServer(2);
         $this->object->removeServer(2);
 
-        $this->assertEquals(
-            2,
-            $this->object->getServerCount()
-        );
+        self::assertSame(2, $this->object->getServerCount());
 
-        $this->assertLessThanOrEqual(
-            2,
-            $this->object->get('ServerDefault')
-        );
-        $this->assertEquals(
-            [
-                'Servers' => [
-                    1 => ['x' => 1],
-                    2 => ['x' => 4],
-                ],
+        self::assertLessThanOrEqual(2, $this->object->get('ServerDefault'));
+        self::assertSame([
+            'Servers' => [
+                1 => ['x' => 1],
+                2 => ['x' => 4],
             ],
-            $this->object->getConfig()
-        );
-        $this->assertEquals(
-            [
-                'Servers/1/x' => 1,
-                'Servers/2/x' => 4,
-            ],
-            $this->object->getConfigArray()
-        );
+        ], $this->object->getConfig());
+        self::assertSame([
+            'Servers/1/x' => 1,
+            'Servers/2/x' => 4,
+        ], $this->object->getConfigArray());
     }
 
     /**
@@ -424,13 +344,10 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->set('Servers/1/x', 'a');
         $this->object->set('Servers/2/x', 'b');
 
-        $this->assertEquals(
-            [
-                1 => ['x' => 'a'],
-                2 => ['x' => 'b'],
-            ],
-            $this->object->getServers()
-        );
+        self::assertSame([
+            1 => ['x' => 'a'],
+            2 => ['x' => 'b'],
+        ], $this->object->getServers());
     }
 
     /**
@@ -438,10 +355,7 @@ class ConfigFileTest extends AbstractTestCase
      */
     public function testGetServerDSN(): void
     {
-        $this->assertEquals(
-            '',
-            $this->object->getServerDSN(1)
-        );
+        self::assertSame('', $this->object->getServerDSN(1));
 
         $this->object->updateWithGlobalConfig(
             [
@@ -455,10 +369,7 @@ class ConfigFileTest extends AbstractTestCase
                 ],
             ]
         );
-        $this->assertEquals(
-            'mysqli://testUser@example.com:21',
-            $this->object->getServerDSN(1)
-        );
+        self::assertSame('mysqli://testUser@example.com:21', $this->object->getServerDSN(1));
 
         $this->object->updateWithGlobalConfig(
             [
@@ -474,10 +385,7 @@ class ConfigFileTest extends AbstractTestCase
                 ],
             ]
         );
-        $this->assertEquals(
-            'mysqli://testUser@123',
-            $this->object->getServerDSN(1)
-        );
+        self::assertSame('mysqli://testUser@123', $this->object->getServerDSN(1));
 
         $this->object->updateWithGlobalConfig(
             [
@@ -492,10 +400,7 @@ class ConfigFileTest extends AbstractTestCase
                 ],
             ]
         );
-        $this->assertEquals(
-            'mysqli://testUser:***@example.com:21',
-            $this->object->getServerDSN(1)
-        );
+        self::assertSame('mysqli://testUser:***@example.com:21', $this->object->getServerDSN(1));
     }
 
     /**
@@ -503,22 +408,13 @@ class ConfigFileTest extends AbstractTestCase
      */
     public function testGetServerName(): void
     {
-        $this->assertEquals(
-            '',
-            $this->object->getServerName(1)
-        );
+        self::assertSame('', $this->object->getServerName(1));
 
         $this->object->set('Servers/1/host', 'example.com');
-        $this->assertEquals(
-            'example.com',
-            $this->object->getServerName(1)
-        );
+        self::assertSame('example.com', $this->object->getServerName(1));
 
         $this->object->set('Servers/1/verbose', 'testData');
-        $this->assertEquals(
-            'testData',
-            $this->object->getServerName(1)
-        );
+        self::assertSame('testData', $this->object->getServerName(1));
     }
 
     /**
@@ -530,15 +426,12 @@ class ConfigFileTest extends AbstractTestCase
         $this->object->set('Array/test', ['x', 'y']);
         $default_value = $this->object->getDefault(self::SIMPLE_KEY_WITH_DEFAULT_VALUE);
 
-        $this->assertEquals(
-            [
-                self::SIMPLE_KEY_WITH_DEFAULT_VALUE => $default_value,
-                'Array/test' => [
-                    'x',
-                    'y',
-                ],
+        self::assertEquals([
+            self::SIMPLE_KEY_WITH_DEFAULT_VALUE => $default_value,
+            'Array/test' => [
+                'x',
+                'y',
             ],
-            $this->object->getConfigArray()
-        );
+        ], $this->object->getConfigArray());
     }
 }
