@@ -53,31 +53,31 @@ class FormDisplayTemplateTest extends AbstractTestCase
             $opts
         );
 
-        $this->assertStringContainsString('<tr class="group-header-field group-header-1 disabled-field">', $result);
+        self::assertStringContainsString('<tr class="group-header-field group-header-1 disabled-field">', $result);
 
-        $this->assertStringContainsString('<label for="test/path">', $result);
+        self::assertStringContainsString('<label for="test/path">', $result);
 
-        $this->assertStringContainsString('<a href="https://example.com/" target="documentation"', $result);
+        self::assertStringContainsString('<a href="https://example.com/" target="documentation"', $result);
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<img src="themes/dot.gif" title="Documentation" alt="Documentation" class="icon ic_b_help"',
             $result
         );
 
-        $this->assertStringContainsString('<span class="disabled-notice"', $result);
+        self::assertStringContainsString('<span class="disabled-notice"', $result);
 
-        $this->assertStringContainsString('<small>', $result);
+        self::assertStringContainsString('<small>', $result);
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<input type="text" name="test/path" id="test/path" value="val" class="w-75 custom field-error">',
             $result
         );
 
-        $this->assertStringContainsString('<a class="restore-default hide" href="#test/path"', $result);
+        self::assertStringContainsString('<a class="restore-default hide" href="#test/path"', $result);
 
-        $this->assertStringContainsString('<dl class="inline_errors">', $result);
-        $this->assertStringContainsString('<dd>e1</dd>', $result);
-        $this->assertStringContainsString('</dl>', $result);
+        self::assertStringContainsString('<dl class="inline_errors">', $result);
+        self::assertStringContainsString('<dd>e1</dd>', $result);
+        self::assertStringContainsString('</dl>', $result);
 
         // second case
 
@@ -100,18 +100,18 @@ class FormDisplayTemplateTest extends AbstractTestCase
             $opts
         );
 
-        $this->assertStringContainsString('<tr class="group-field group-field-1">', $result);
+        self::assertStringContainsString('<tr class="group-field group-field-1">', $result);
 
-        $this->assertStringContainsString('<input type="checkbox" name="test/path" id="test/path" checked>', $result);
+        self::assertStringContainsString('<input type="checkbox" name="test/path" id="test/path" checked>', $result);
 
-        $this->assertStringContainsString('<a class="userprefs-comment" title="userprefsComment">', $result);
+        self::assertStringContainsString('<a class="userprefs-comment" title="userprefsComment">', $result);
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<td class="userprefs-allow" title="Allow users to customize this value">',
             $result
         );
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<a class="set-value hide" href="#test/path=setVal" title="Set value: setVal">',
             $result
         );
@@ -130,7 +130,7 @@ class FormDisplayTemplateTest extends AbstractTestCase
             $opts
         );
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<input type="text" size="25" name="test/path" id="test/path" value="val" class="">',
             $result
         );
@@ -146,7 +146,7 @@ class FormDisplayTemplateTest extends AbstractTestCase
             $opts
         );
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<input type="number" name="test/path" id="test/path" value="val" class="">',
             $result
         );
@@ -163,13 +163,13 @@ class FormDisplayTemplateTest extends AbstractTestCase
             'key2' => false,
         ];
         $result = $this->formDisplayTemplate->displayInput('test/path', 'testName', 'select', true, '', true, $opts);
-        $this->assertStringContainsString('<select name="test/path" id="test/path" class="w-75">', $result);
+        self::assertStringContainsString('<select name="test/path" id="test/path" class="w-75">', $result);
 
-        $this->assertStringContainsString('<option value="1" selected disabled>', $result);
+        self::assertStringContainsString('<option value="1" selected disabled>', $result);
 
-        $this->assertStringContainsString('<option value="key1">', $result);
+        self::assertStringContainsString('<option value="key1">', $result);
 
-        $this->assertStringContainsString('<option value="key2">', $result);
+        self::assertStringContainsString('<option value="key2">', $result);
 
         // select case 2
         $opts['values_escaped'] = false;
@@ -184,10 +184,10 @@ class FormDisplayTemplateTest extends AbstractTestCase
         ];
         $result = $this->formDisplayTemplate->displayInput('test/path', 'testName', 'select', false, '', true, $opts);
 
-        $this->assertStringContainsString('<select name="test/path" id="test/path" class="w-75">', $result);
+        self::assertStringContainsString('<select name="test/path" id="test/path" class="w-75">', $result);
 
         // assertContains doesn't seem to work with htmlentities
-        $this->assertStringContainsString('<option value="a&lt;b">c&amp;d</option>', $result);
+        self::assertStringContainsString('<option value="a&lt;b">c&amp;d</option>', $result);
 
         // list
         $result = $this->formDisplayTemplate->displayInput(
@@ -203,7 +203,7 @@ class FormDisplayTemplateTest extends AbstractTestCase
             $opts
         );
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<textarea cols="35" rows="5" name="test/path" id="test/path" class="">',
             $result
         );
@@ -214,10 +214,7 @@ class FormDisplayTemplateTest extends AbstractTestCase
      */
     public function testDisplayGroupHeader(): void
     {
-        $this->assertEquals(
-            '',
-            $this->formDisplayTemplate->displayGroupHeader('')
-        );
+        self::assertSame('', $this->formDisplayTemplate->displayGroupHeader(''));
 
         $this->formDisplayTemplate->group = 3;
 
@@ -225,7 +222,7 @@ class FormDisplayTemplateTest extends AbstractTestCase
 
         $result = $this->formDisplayTemplate->displayGroupHeader('headerText');
 
-        $this->assertStringContainsString('<tr class="group-header group-header-4">', $result);
+        self::assertStringContainsString('<tr class="group-header group-header-4">', $result);
 
         // without PMA_SETUP
         $this->config->set('is_setup', false);
@@ -234,7 +231,7 @@ class FormDisplayTemplateTest extends AbstractTestCase
 
         $result = $this->formDisplayTemplate->displayGroupHeader('headerText');
 
-        $this->assertStringContainsString('<tr class="group-header group-header-4">', $result);
+        self::assertStringContainsString('<tr class="group-header group-header-4">', $result);
     }
 
     /**
@@ -244,7 +241,7 @@ class FormDisplayTemplateTest extends AbstractTestCase
     {
         $this->formDisplayTemplate->group = 3;
         $this->formDisplayTemplate->displayGroupFooter();
-        $this->assertEquals(2, $this->formDisplayTemplate->group);
+        self::assertSame(2, $this->formDisplayTemplate->group);
     }
 
     /**
@@ -264,14 +261,11 @@ class FormDisplayTemplateTest extends AbstractTestCase
 
         $this->formDisplayTemplate->addJsValidate('testID', $validators, $js);
 
-        $this->assertEquals(
-            [
-                'registerFieldValidator(\'testID\', \'\\\';\', true, '
-                . '[\'\\\\r\\\\n\\\\\\\''
-                . '<scrIpt></\\\' + \\\'script>\'])',
-                'registerFieldValidator(\'testID\', \'\', true)',
-            ],
-            $js
-        );
+        self::assertSame([
+            'registerFieldValidator(\'testID\', \'\\\';\', true, '
+            . '[\'\\\\r\\\\n\\\\\\\''
+            . '<scrIpt></\\\' + \\\'script>\'])',
+            'registerFieldValidator(\'testID\', \'\', true)',
+        ], $js);
     }
 }
