@@ -15,6 +15,8 @@ use ReflectionProperty;
 use function function_exists;
 use function gettype;
 
+use const PHP_VERSION_ID;
+
 /**
  * @covers \PhpMyAdmin\Config\FormDisplay
  */
@@ -55,7 +57,9 @@ class FormDisplayTest extends AbstractTestCase
         $reflection = new ReflectionClass(FormDisplay::class);
 
         $attrForms = $reflection->getProperty('forms');
-        $attrForms->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrForms->setAccessible(true);
+        }
 
         $array = [
             'Servers' => [
@@ -68,29 +72,27 @@ class FormDisplayTest extends AbstractTestCase
 
         $this->object->registerForm('pma_testform', $array, 2);
         $_forms = $attrForms->getValue($this->object);
-        $this->assertInstanceOf(Form::class, $_forms['pma_testform']);
+        self::assertInstanceOf(Form::class, $_forms['pma_testform']);
 
         $attrSystemPaths = $reflection->getProperty('systemPaths');
-        $attrSystemPaths->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrSystemPaths->setAccessible(true);
+        }
 
-        $this->assertEquals(
-            [
-                'Servers/2/test' => 'Servers/1/test',
-                'Servers/2/:group:end:0' => 'Servers/1/:group:end:0',
-            ],
-            $attrSystemPaths->getValue($this->object)
-        );
+        self::assertSame([
+            'Servers/2/test' => 'Servers/1/test',
+            'Servers/2/:group:end:0' => 'Servers/1/:group:end:0',
+        ], $attrSystemPaths->getValue($this->object));
 
         $attrTranslatedPaths = $reflection->getProperty('translatedPaths');
-        $attrTranslatedPaths->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrTranslatedPaths->setAccessible(true);
+        }
 
-        $this->assertEquals(
-            [
-                'Servers/2/test' => 'Servers-2-test',
-                'Servers/2/:group:end:0' => 'Servers-2-:group:end:0',
-            ],
-            $attrTranslatedPaths->getValue($this->object)
-        );
+        self::assertSame([
+            'Servers/2/test' => 'Servers-2-test',
+            'Servers/2/:group:end:0' => 'Servers-2-:group:end:0',
+        ], $attrTranslatedPaths->getValue($this->object));
     }
 
     /**
@@ -100,9 +102,7 @@ class FormDisplayTest extends AbstractTestCase
      */
     public function testProcess(): void
     {
-        $this->assertFalse(
-            $this->object->process(true, true)
-        );
+        self::assertFalse($this->object->process(true, true));
 
         $this->object = $this->getMockBuilder(FormDisplay::class)
             ->disableOriginalConstructor()
@@ -110,7 +110,10 @@ class FormDisplayTest extends AbstractTestCase
             ->getMock();
 
         $attrForms = new ReflectionProperty(FormDisplay::class, 'forms');
-        $attrForms->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrForms->setAccessible(true);
+        }
+
         $attrForms->setValue($this->object, [1, 2, 3]);
 
         $this->object->expects($this->once())
@@ -118,15 +121,11 @@ class FormDisplayTest extends AbstractTestCase
             ->with([0, 1, 2], false)
             ->will($this->returnValue(true));
 
-        $this->assertTrue(
-            $this->object->process(false, false)
-        );
+        self::assertTrue($this->object->process(false, false));
 
         $attrForms->setValue($this->object, []);
 
-        $this->assertFalse(
-            $this->object->process(false, false)
-        );
+        self::assertFalse($this->object->process(false, false));
     }
 
     /**
@@ -137,16 +136,22 @@ class FormDisplayTest extends AbstractTestCase
         $reflection = new ReflectionClass(FormDisplay::class);
 
         $attrIsValidated = $reflection->getProperty('isValidated');
-        $attrIsValidated->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrIsValidated->setAccessible(true);
+        }
+
         $attrIsValidated->setValue($this->object, true);
 
         $attrIsValidated = $reflection->getProperty('errors');
-        $attrIsValidated->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrIsValidated->setAccessible(true);
+        }
+
         $attrIsValidated->setValue($this->object, []);
 
         $result = $this->object->displayErrors();
 
-        $this->assertNull($result);
+        self::assertNull($result);
 
         $arr = [
             'Servers/1/test' => ['e1'],
@@ -159,19 +164,22 @@ class FormDisplayTest extends AbstractTestCase
         $sysArr = ['Servers/1/test' => 'Servers/1/test2'];
 
         $attrSystemPaths = $reflection->getProperty('systemPaths');
-        $attrSystemPaths->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrSystemPaths->setAccessible(true);
+        }
+
         $attrSystemPaths->setValue($this->object, $sysArr);
 
         $attrIsValidated->setValue($this->object, $arr);
 
         $result = $this->object->displayErrors();
 
-        $this->assertIsString($result);
-        $this->assertStringContainsString('<dt>Servers/1/test2</dt>', $result);
-        $this->assertStringContainsString('<dd>e1</dd>', $result);
-        $this->assertStringContainsString('<dt>Form_foobar</dt>', $result);
-        $this->assertStringContainsString('<dd>e2</dd>', $result);
-        $this->assertStringContainsString('<dd>e3</dd>', $result);
+        self::assertIsString($result);
+        self::assertStringContainsString('<dt>Servers/1/test2</dt>', $result);
+        self::assertStringContainsString('<dd>e1</dd>', $result);
+        self::assertStringContainsString('<dt>Form_foobar</dt>', $result);
+        self::assertStringContainsString('<dd>e2</dd>', $result);
+        self::assertStringContainsString('<dd>e3</dd>', $result);
     }
 
     /**
@@ -182,11 +190,17 @@ class FormDisplayTest extends AbstractTestCase
         $reflection = new ReflectionClass(FormDisplay::class);
 
         $attrIsValidated = $reflection->getProperty('isValidated');
-        $attrIsValidated->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrIsValidated->setAccessible(true);
+        }
+
         $attrIsValidated->setValue($this->object, true);
 
         $attrIsValidated = $reflection->getProperty('errors');
-        $attrIsValidated->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrIsValidated->setAccessible(true);
+        }
+
         $attrIsValidated->setValue($this->object, []);
 
         $this->object->fixErrors();
@@ -203,21 +217,21 @@ class FormDisplayTest extends AbstractTestCase
         $sysArr = ['Servers/1/test' => 'Servers/1/host'];
 
         $attrSystemPaths = $reflection->getProperty('systemPaths');
-        $attrSystemPaths->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrSystemPaths->setAccessible(true);
+        }
+
         $attrSystemPaths->setValue($this->object, $sysArr);
 
         $attrIsValidated->setValue($this->object, $arr);
 
         $this->object->fixErrors();
 
-        $this->assertEquals(
-            [
-                'Servers' => [
-                    '1' => ['test' => 'localhost'],
-                ],
+        self::assertSame([
+            'Servers' => [
+                '1' => ['test' => 'localhost'],
             ],
-            $_SESSION['ConfigFile0']
-        );
+        ], $_SESSION['ConfigFile0']);
     }
 
     /**
@@ -226,59 +240,50 @@ class FormDisplayTest extends AbstractTestCase
     public function testValidateSelect(): void
     {
         $attrValidateSelect = new ReflectionMethod(FormDisplay::class, 'validateSelect');
-        $attrValidateSelect->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrValidateSelect->setAccessible(true);
+        }
 
         $arr = ['foo' => 'var'];
         $value = 'foo';
-        $this->assertTrue(
-            $attrValidateSelect->invokeArgs(
-                $this->object,
-                [
-                    &$value,
-                    $arr,
-                ]
-            )
-        );
+        self::assertTrue($attrValidateSelect->invokeArgs(
+            $this->object,
+            [
+                &$value,
+                $arr,
+            ]
+        ));
 
         $arr = ['' => 'foobar'];
         $value = null;
-        $this->assertTrue(
-            $attrValidateSelect->invokeArgs(
-                $this->object,
-                [
-                    &$value,
-                    $arr,
-                ]
-            )
-        );
-        $this->assertEquals(
-            'string',
-            gettype($value)
-        );
+        self::assertTrue($attrValidateSelect->invokeArgs(
+            $this->object,
+            [
+                &$value,
+                $arr,
+            ]
+        ));
+        self::assertSame('string', gettype($value));
 
         $arr = [0 => 'foobar'];
         $value = 0;
-        $this->assertTrue(
-            $attrValidateSelect->invokeArgs(
-                $this->object,
-                [
-                    &$value,
-                    $arr,
-                ]
-            )
-        );
+        self::assertTrue($attrValidateSelect->invokeArgs(
+            $this->object,
+            [
+                &$value,
+                $arr,
+            ]
+        ));
 
         $arr = ['1' => 'foobar'];
         $value = 0;
-        $this->assertFalse(
-            $attrValidateSelect->invokeArgs(
-                $this->object,
-                [
-                    &$value,
-                    $arr,
-                ]
-            )
-        );
+        self::assertFalse($attrValidateSelect->invokeArgs(
+            $this->object,
+            [
+                &$value,
+                $arr,
+            ]
+        ));
     }
 
     /**
@@ -287,11 +292,11 @@ class FormDisplayTest extends AbstractTestCase
     public function testHasErrors(): void
     {
         $attrErrors = new ReflectionProperty(FormDisplay::class, 'errors');
-        $attrErrors->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrErrors->setAccessible(true);
+        }
 
-        $this->assertFalse(
-            $this->object->hasErrors()
-        );
+        self::assertFalse($this->object->hasErrors());
 
         $attrErrors->setValue(
             $this->object,
@@ -301,9 +306,7 @@ class FormDisplayTest extends AbstractTestCase
             ]
         );
 
-        $this->assertTrue(
-            $this->object->hasErrors()
-        );
+        self::assertTrue($this->object->hasErrors());
     }
 
     /**
@@ -311,20 +314,14 @@ class FormDisplayTest extends AbstractTestCase
      */
     public function testGetDocLink(): void
     {
-        $this->assertEquals(
+        self::assertSame(
             './url.php?url=https%3A%2F%2Fdocs.phpmyadmin.net%2Fen%2Flatest%2Fconfig.html%23cfg_Servers_3_test_2_',
             $this->object->getDocLink('Servers/3/test/2/')
         );
 
-        $this->assertEquals(
-            '',
-            $this->object->getDocLink('Import')
-        );
+        self::assertSame('', $this->object->getDocLink('Import'));
 
-        $this->assertEquals(
-            '',
-            $this->object->getDocLink('Export')
-        );
+        self::assertSame('', $this->object->getDocLink('Export'));
     }
 
     /**
@@ -333,17 +330,13 @@ class FormDisplayTest extends AbstractTestCase
     public function testGetOptName(): void
     {
         $method = new ReflectionMethod(FormDisplay::class, 'getOptName');
-        $method->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $method->setAccessible(true);
+        }
 
-        $this->assertEquals(
-            'Servers_',
-            $method->invoke($this->object, 'Servers/1/')
-        );
+        self::assertSame('Servers_', $method->invoke($this->object, 'Servers/1/'));
 
-        $this->assertEquals(
-            'Servers_23_',
-            $method->invoke($this->object, 'Servers/1/23/')
-        );
+        self::assertSame('Servers_23_', $method->invoke($this->object, 'Servers/1/23/'));
     }
 
     /**
@@ -352,16 +345,18 @@ class FormDisplayTest extends AbstractTestCase
     public function testLoadUserprefsInfo(): void
     {
         $method = new ReflectionMethod(FormDisplay::class, 'loadUserprefsInfo');
-        $method->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $method->setAccessible(true);
+        }
 
         $attrUserprefs = new ReflectionProperty(FormDisplay::class, 'userprefsDisallow');
 
-        $attrUserprefs->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $attrUserprefs->setAccessible(true);
+        }
+
         $method->invoke($this->object, null);
-        $this->assertEquals(
-            [],
-            $attrUserprefs->getValue($this->object)
-        );
+        self::assertSame([], $attrUserprefs->getValue($this->object));
     }
 
     /**
@@ -370,7 +365,9 @@ class FormDisplayTest extends AbstractTestCase
     public function testSetComments(): void
     {
         $method = new ReflectionMethod(FormDisplay::class, 'setComments');
-        $method->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $method->setAccessible(true);
+        }
 
         // recoding
         $opts = ['values' => []];
@@ -404,7 +401,7 @@ class FormDisplayTest extends AbstractTestCase
 
         $expect['comment_warning'] = 1;
 
-        $this->assertEquals($expect, $opts);
+        self::assertEquals($expect, $opts);
 
         // ZipDump, GZipDump, BZipDump
         $method->invokeArgs(
@@ -425,9 +422,9 @@ class FormDisplayTest extends AbstractTestCase
             'due to missing function gzcompress.';
         }
 
-        $this->assertEquals($comment, $opts['comment']);
+        self::assertSame($comment, $opts['comment']);
 
-        $this->assertTrue($opts['comment_warning']);
+        self::assertTrue($opts['comment_warning']);
 
         $method->invokeArgs(
             $this->object,
@@ -447,9 +444,9 @@ class FormDisplayTest extends AbstractTestCase
             'due to missing function gzencode.';
         }
 
-        $this->assertEquals($comment, $opts['comment']);
+        self::assertSame($comment, $opts['comment']);
 
-        $this->assertTrue($opts['comment_warning']);
+        self::assertTrue($opts['comment_warning']);
 
         $method->invokeArgs(
             $this->object,
@@ -469,9 +466,9 @@ class FormDisplayTest extends AbstractTestCase
             'due to missing function bzcompress.';
         }
 
-        $this->assertEquals($comment, $opts['comment']);
+        self::assertSame($comment, $opts['comment']);
 
-        $this->assertTrue($opts['comment_warning']);
+        self::assertTrue($opts['comment_warning']);
 
         $GLOBALS['config']->set('is_setup', false);
 
@@ -487,7 +484,7 @@ class FormDisplayTest extends AbstractTestCase
             ]
         );
 
-        $this->assertEquals('maximum 10', $opts['comment']);
+        self::assertSame('maximum 10', $opts['comment']);
 
         $method->invokeArgs(
             $this->object,
@@ -497,7 +494,7 @@ class FormDisplayTest extends AbstractTestCase
             ]
         );
 
-        $this->assertEquals('maximum 10', $opts['comment']);
+        self::assertSame('maximum 10', $opts['comment']);
 
         $method->invokeArgs(
             $this->object,
@@ -507,6 +504,6 @@ class FormDisplayTest extends AbstractTestCase
             ]
         );
 
-        $this->assertEquals('maximum 10', $opts['comment']);
+        self::assertSame('maximum 10', $opts['comment']);
     }
 }
