@@ -100,7 +100,7 @@ class ServerTest extends TestCase
         $settings = new Server($actualValues);
 
         foreach (array_keys($expectedValues) as $key) {
-            $this->assertSame($expected[$key], $settings->$key);
+            self::assertSame($expected[$key], $settings->$key);
         }
     }
 
@@ -110,7 +110,7 @@ class ServerTest extends TestCase
      * @return mixed[][][][]
      * @psalm-return (array{0: string, 1: mixed, 2: mixed})[][][]
      */
-    public function providerForTestConstructor(): array
+    public static function providerForTestConstructor(): array
     {
         return [
             'null values' => [
