@@ -15,23 +15,14 @@ use function defined;
 use function file_exists;
 use function file_put_contents;
 use function fileperms;
-use function function_exists;
-use function gd_info;
-use function mb_strstr;
-use function ob_end_clean;
-use function ob_get_contents;
-use function ob_start;
-use function phpinfo;
-use function preg_match;
+use function get_defined_constants;
 use function realpath;
-use function strip_tags;
 use function stristr;
 use function sys_get_temp_dir;
 use function tempnam;
 use function unlink;
 
 use const DIRECTORY_SEPARATOR;
-use const INFO_MODULES;
 use const PHP_EOL;
 use const PHP_OS;
 use const TEST_PATH;
@@ -89,13 +80,13 @@ class ConfigTest extends AbstractTestCase
             $this->markTestSkipped('Creating a temporary file does not work');
         }
 
-        $this->assertFileExists($tmpConfig);
+        self::assertFileExists($tmpConfig);
 
         // end of setup
 
         // Test loading an empty file does not change the default config
         $config = new Config($tmpConfig);
-        $this->assertSame($defaultConfig->settings, $config->settings);
+        self::assertSame($defaultConfig->settings, $config->settings);
 
         $contents = '<?php' . PHP_EOL
                     . '$cfg[\'ProtectBinary\'] = true;';
@@ -104,12 +95,12 @@ class ConfigTest extends AbstractTestCase
         // Test loading a config changes the setup
         $config = new Config($tmpConfig);
         $defaultConfig->settings['ProtectBinary'] = true;
-        $this->assertSame($defaultConfig->settings, $config->settings);
+        self::assertSame($defaultConfig->settings, $config->settings);
         $defaultConfig->settings['ProtectBinary'] = 'blob';
 
         // Teardown
         unlink($tmpConfig);
-        $this->assertFalse(file_exists($tmpConfig));
+        self::assertFalse(file_exists($tmpConfig));
     }
 
     /**
@@ -123,13 +114,13 @@ class ConfigTest extends AbstractTestCase
             $this->markTestSkipped('Creating a temporary file does not work');
         }
 
-        $this->assertFileExists($tmpConfig);
+        self::assertFileExists($tmpConfig);
 
         // end of setup
 
         // Test loading an empty file does not change the default config
         $config = new Config($tmpConfig);
-        $this->assertSame($defaultConfig->settings, $config->settings);
+        self::assertSame($defaultConfig->settings, $config->settings);
 
         $contents = '<?php' . PHP_EOL
                     . '$cfg[\'fooBar\'] = true;';
@@ -139,7 +130,7 @@ class ConfigTest extends AbstractTestCase
         $config = new Config($tmpConfig);
         $defaultConfig->settings['fooBar'] = true;
         // Equals because of the key sorting
-        $this->assertEquals($defaultConfig->settings, $config->settings);
+        self::assertEquals($defaultConfig->settings, $config->settings);
         unset($defaultConfig->settings['fooBar']);
 
         $contents = '<?php' . PHP_EOL
@@ -154,12 +145,12 @@ class ConfigTest extends AbstractTestCase
         $config = new Config($tmpConfig);
         $defaultConfig->settings['ValidKey'] = true;
         // Equals because of the key sorting
-        $this->assertEquals($defaultConfig->settings, $config->settings);
+        self::assertEquals($defaultConfig->settings, $config->settings);
         unset($defaultConfig->settings['ValidKey']);
 
         // Teardown
         unlink($tmpConfig);
-        $this->assertFalse(file_exists($tmpConfig));
+        self::assertFalse(file_exists($tmpConfig));
     }
 
     /**
@@ -171,7 +162,7 @@ class ConfigTest extends AbstractTestCase
     {
         $this->object->checkSystem();
 
-        $this->assertIsBool($this->object->get('PMA_IS_WINDOWS'));
+        self::assertIsBool($this->object->get('PMA_IS_WINDOWS'));
     }
 
     /**
@@ -184,13 +175,13 @@ class ConfigTest extends AbstractTestCase
         $this->object->set('PMA_USR_BROWSER_AGENT', 'IE');
         $this->object->set('PMA_USR_BROWSER_VER', 6);
         $this->object->checkOutputCompression();
-        $this->assertTrue($this->object->get('OBGzip'));
+        self::assertTrue($this->object->get('OBGzip'));
 
         $this->object->set('OBGzip', 'auto');
         $this->object->set('PMA_USR_BROWSER_AGENT', 'MOZILLA');
         $this->object->set('PMA_USR_BROWSER_VER', 5);
         $this->object->checkOutputCompression();
-        $this->assertTrue($this->object->get('OBGzip'));
+        self::assertTrue($this->object->get('OBGzip'));
     }
 
     /**
@@ -207,22 +198,16 @@ class ConfigTest extends AbstractTestCase
     {
         $_SERVER['HTTP_USER_AGENT'] = $agent;
         $this->object->checkClient();
-        $this->assertEquals($os, $this->object->get('PMA_USR_OS'));
+        self::assertSame($os, $this->object->get('PMA_USR_OS'));
         if ($os != null) {
-            $this->assertEquals(
-                $browser,
-                $this->object->get('PMA_USR_BROWSER_AGENT')
-            );
+            self::assertSame($browser, $this->object->get('PMA_USR_BROWSER_AGENT'));
         }
 
         if ($version == null) {
             return;
         }
 
-        $this->assertEquals(
-            $version,
-            $this->object->get('PMA_USR_BROWSER_VER')
-        );
+        self::assertEquals($version, $this->object->get('PMA_USR_BROWSER_VER'));
     }
 
     /**
@@ -230,7 +215,7 @@ class ConfigTest extends AbstractTestCase
      *
      * @return array
      */
-    public function userAgentProvider(): array
+    public static function userAgentProvider(): array
     {
         return [
             [
@@ -334,64 +319,18 @@ class ConfigTest extends AbstractTestCase
     {
         $this->object->set('GD2Available', 'yes');
         $this->object->checkGd2();
-        $this->assertEquals(1, $this->object->get('PMA_IS_GD2'));
+        self::assertSame(1, $this->object->get('PMA_IS_GD2'));
 
         $this->object->set('GD2Available', 'no');
         $this->object->checkGd2();
-        $this->assertEquals(0, $this->object->get('PMA_IS_GD2'));
+        self::assertSame(0, $this->object->get('PMA_IS_GD2'));
 
         $this->object->set('GD2Available', 'auto');
-
-        if (! function_exists('imagecreatetruecolor')) {
-            $this->object->checkGd2();
-            $this->assertEquals(
-                0,
-                $this->object->get('PMA_IS_GD2'),
-                'imagecreatetruecolor does not exist, PMA_IS_GD2 should be 0'
-            );
-        }
-
-        if (function_exists('gd_info')) {
-            $this->object->checkGd2();
-            $gd_nfo = gd_info();
-            if (mb_strstr($gd_nfo['GD Version'], '2.')) {
-                $this->assertEquals(
-                    1,
-                    $this->object->get('PMA_IS_GD2'),
-                    'GD Version >= 2, PMA_IS_GD2 should be 1'
-                );
-            } else {
-                $this->assertEquals(
-                    0,
-                    $this->object->get('PMA_IS_GD2'),
-                    'GD Version < 2, PMA_IS_GD2 should be 0'
-                );
-            }
-        }
-
-        /* Get GD version string from phpinfo output */
-        ob_start();
-        phpinfo(INFO_MODULES); /* Only modules */
-        $a = strip_tags((string) ob_get_contents());
-        ob_end_clean();
-
-        if (! preg_match('@GD Version[[:space:]]*\(.*\)@', $a, $v)) {
-            return;
-        }
-
-        if (mb_strstr($v, '2.')) {
-            $this->assertEquals(
-                1,
-                $this->object->get('PMA_IS_GD2'),
-                'PMA_IS_GD2 should be 1'
-            );
-        } else {
-            $this->assertEquals(
-                0,
-                $this->object->get('PMA_IS_GD2'),
-                'PMA_IS_GD2 should be 0'
-            );
-        }
+        $this->object->checkGd2();
+        self::assertSame(
+            (get_defined_constants()['GD_MAJOR_VERSION'] ?? 0) >= 2 ? 1 : 0,
+            $this->object->get('PMA_IS_GD2')
+        );
     }
 
     /**
@@ -406,7 +345,7 @@ class ConfigTest extends AbstractTestCase
     {
         $_SERVER['SERVER_SOFTWARE'] = $server;
         $this->object->checkWebServer();
-        $this->assertEquals($iis, $this->object->get('PMA_IS_IIS'));
+        self::assertSame($iis, $this->object->get('PMA_IS_IIS'));
         unset($_SERVER['SERVER_SOFTWARE']);
     }
 
@@ -415,7 +354,7 @@ class ConfigTest extends AbstractTestCase
      *
      * @return array
      */
-    public function serverNames(): array
+    public static function serverNames(): array
     {
         return [
             [
@@ -438,21 +377,21 @@ class ConfigTest extends AbstractTestCase
 
         if (defined('PHP_OS')) {
             if (stristr(PHP_OS, 'darwin')) {
-                $this->assertFalse($this->object->get('PMA_IS_WINDOWS'));
+                self::assertFalse($this->object->get('PMA_IS_WINDOWS'));
             } elseif (stristr(PHP_OS, 'win')) {
-                $this->assertTrue($this->object->get('PMA_IS_WINDOWS'));
+                self::assertTrue($this->object->get('PMA_IS_WINDOWS'));
             } elseif (stristr(PHP_OS, 'OS/2')) {
-                $this->assertTrue($this->object->get('PMA_IS_WINDOWS'));
+                self::assertTrue($this->object->get('PMA_IS_WINDOWS'));
             } elseif (stristr(PHP_OS, 'Linux')) {
-                $this->assertFalse($this->object->get('PMA_IS_WINDOWS'));
+                self::assertFalse($this->object->get('PMA_IS_WINDOWS'));
             } else {
                 $this->markTestIncomplete('Not known PHP_OS: ' . PHP_OS);
             }
         } else {
-            $this->assertEquals(0, $this->object->get('PMA_IS_WINDOWS'));
+            self::assertSame(0, $this->object->get('PMA_IS_WINDOWS'));
 
             define('PHP_OS', 'Windows');
-            $this->assertTrue($this->object->get('PMA_IS_WINDOWS'));
+            self::assertTrue($this->object->get('PMA_IS_WINDOWS'));
         }
     }
 
@@ -472,11 +411,11 @@ class ConfigTest extends AbstractTestCase
         $settings = new Settings([]);
         $config = $settings->toArray();
 
-        $this->assertIsArray($config['Servers']);
-        $this->assertEquals($config['Servers'][1], $this->object->defaultServer);
+        self::assertIsArray($config['Servers']);
+        self::assertSame($config['Servers'][1], $this->object->defaultServer);
         unset($config['Servers']);
-        $this->assertEquals($config, $this->object->default);
-        $this->assertEquals(
+        self::assertSame($config, $this->object->default);
+        self::assertSame(
             array_replace_recursive(['is_setup' => false, 'AvailableCharsets' => ['test']], $config),
             $this->object->settings
         );
@@ -488,13 +427,13 @@ class ConfigTest extends AbstractTestCase
     public function testCheckConfigSource(): void
     {
         $this->object->setSource('unexisted.config.php');
-        $this->assertFalse($this->object->checkConfigSource());
-        $this->assertEquals(0, $this->object->sourceMtime);
+        self::assertFalse($this->object->checkConfigSource());
+        self::assertSame(0, $this->object->sourceMtime);
 
         $this->object->setSource(TEST_PATH . 'test/test_data/config.inc.php');
 
-        $this->assertNotEmpty($this->object->getSource());
-        $this->assertTrue($this->object->checkConfigSource());
+        self::assertNotEmpty($this->object->getSource());
+        self::assertTrue($this->object->checkConfigSource());
     }
 
     /**
@@ -502,11 +441,11 @@ class ConfigTest extends AbstractTestCase
      */
     public function testGetAndSet(): void
     {
-        $this->assertNull($this->object->get('unresisting_setting'));
+        self::assertNull($this->object->get('unresisting_setting'));
 
         $this->object->set('test_setting', 'test_value');
 
-        $this->assertEquals('test_value', $this->object->get('test_setting'));
+        self::assertSame('test_value', $this->object->get('test_setting'));
     }
 
     /**
@@ -516,15 +455,11 @@ class ConfigTest extends AbstractTestCase
     {
         echo $this->object->getSource();
 
-        $this->assertEmpty($this->object->getSource(), 'Source is null by default');
+        self::assertEmpty($this->object->getSource(), 'Source is null by default');
 
         $this->object->setSource(ROOT_PATH . 'config.sample.inc.php');
 
-        $this->assertEquals(
-            ROOT_PATH . 'config.sample.inc.php',
-            $this->object->getSource(),
-            'Cant set new source'
-        );
+        self::assertSame(ROOT_PATH . 'config.sample.inc.php', $this->object->getSource(), 'Cant set new source');
     }
 
     /**
@@ -569,7 +504,7 @@ class ConfigTest extends AbstractTestCase
 
         $this->object->set('is_https', null);
         $this->object->set('PmaAbsoluteUri', $pmaAbsoluteUri);
-        $this->assertEquals($expected, $this->object->isHttps());
+        self::assertSame($expected, $this->object->isHttps());
     }
 
     /**
@@ -577,7 +512,7 @@ class ConfigTest extends AbstractTestCase
      *
      * @return array
      */
-    public function httpsParams(): array
+    public static function httpsParams(): array
     {
         return [
             [
@@ -804,7 +739,7 @@ class ConfigTest extends AbstractTestCase
     {
         $GLOBALS['PMA_PHP_SELF'] = $request;
         $this->object->set('PmaAbsoluteUri', $absolute);
-        $this->assertEquals($expected, $this->object->getRootPath());
+        self::assertSame($expected, $this->object->getRootPath());
     }
 
     /**
@@ -812,7 +747,7 @@ class ConfigTest extends AbstractTestCase
      *
      * @return array data for testGetRootPath
      */
-    public function rootUris(): array
+    public static function rootUris(): array
     {
         return [
             [
@@ -909,9 +844,9 @@ class ConfigTest extends AbstractTestCase
     public function testLoad(string $source, bool $result): void
     {
         if ($result) {
-            $this->assertTrue($this->object->load($source));
+            self::assertTrue($this->object->load($source));
         } else {
-            $this->assertFalse($this->object->load($source));
+            self::assertFalse($this->object->load($source));
         }
     }
 
@@ -920,7 +855,7 @@ class ConfigTest extends AbstractTestCase
      *
      * @return array
      */
-    public function configPaths(): array
+    public static function configPaths(): array
     {
         return [
             [
@@ -952,10 +887,7 @@ class ConfigTest extends AbstractTestCase
     {
         $this->object->setUserValue(null, 'lang', 'cs', 'en');
         $this->object->setUserValue('TEST_COOKIE_USER_VAL', '', 'cfg_val_1');
-        $this->assertEquals(
-            $this->object->getUserValue('TEST_COOKIE_USER_VAL', 'fail'),
-            'cfg_val_1'
-        );
+        self::assertSame($this->object->getUserValue('TEST_COOKIE_USER_VAL', 'fail'), 'cfg_val_1');
     }
 
     /**
@@ -963,7 +895,7 @@ class ConfigTest extends AbstractTestCase
      */
     public function testGetUserValue(): void
     {
-        $this->assertEquals($this->object->getUserValue('test_val', 'val'), 'val');
+        self::assertSame($this->object->getUserValue('test_val', 'val'), 'val');
     }
 
     /**
@@ -974,15 +906,15 @@ class ConfigTest extends AbstractTestCase
         //load file permissions for the current permissions file
         $perms = @fileperms($this->object->getSource());
         //testing for permissions for no configuration file
-        $this->assertFalse(! ($perms === false) && ($perms & 2));
+        self::assertFalse(! ($perms === false) && ($perms & 2));
 
         //load file permissions for the current permissions file
         $perms = @fileperms($this->permTestObj->getSource());
 
         if (! ($perms === false) && ($perms & 2)) {
-            $this->assertTrue((bool) $this->permTestObj->get('PMA_IS_WINDOWS'));
+            self::assertTrue((bool) $this->permTestObj->get('PMA_IS_WINDOWS'));
         } else {
-            $this->assertFalse((bool) $this->permTestObj->get('PMA_IS_WINDOWS'));
+            self::assertFalse((bool) $this->permTestObj->get('PMA_IS_WINDOWS'));
         }
     }
 
@@ -992,39 +924,31 @@ class ConfigTest extends AbstractTestCase
     public function testSetCookie(): void
     {
         $this->object->set('is_https', false);
-        $this->assertFalse(
-            $this->object->setCookie(
-                'TEST_DEF_COOKIE',
-                'test_def_123',
-                'test_def_123'
-            )
-        );
+        self::assertFalse($this->object->setCookie(
+            'TEST_DEF_COOKIE',
+            'test_def_123',
+            'test_def_123'
+        ));
 
-        $this->assertTrue(
-            $this->object->setCookie(
-                'TEST_CONFIG_COOKIE',
-                'test_val_123',
-                null,
-                3600
-            )
-        );
+        self::assertTrue($this->object->setCookie(
+            'TEST_CONFIG_COOKIE',
+            'test_val_123',
+            null,
+            3600
+        ));
 
-        $this->assertTrue(
-            $this->object->setCookie(
-                'TEST_CONFIG_COOKIE',
-                '',
-                'default_val'
-            )
-        );
+        self::assertTrue($this->object->setCookie(
+            'TEST_CONFIG_COOKIE',
+            '',
+            'default_val'
+        ));
 
         $_COOKIE['TEST_MANUAL_COOKIE'] = 'some_test_val';
-        $this->assertTrue(
-            $this->object->setCookie(
-                'TEST_MANUAL_COOKIE',
-                'other',
-                'other'
-            )
-        );
+        self::assertTrue($this->object->setCookie(
+            'TEST_MANUAL_COOKIE',
+            'other',
+            'other'
+        ));
     }
 
     /**
@@ -1034,27 +958,32 @@ class ConfigTest extends AbstractTestCase
      */
     public function testGetTempDir(): void
     {
-        $this->object->set('TempDir', sys_get_temp_dir() . DIRECTORY_SEPARATOR);
+        $dir = realpath(sys_get_temp_dir());
+        self::assertNotFalse($dir);
+        self::assertDirectoryExists($dir);
+        self::assertDirectoryIsWritable($dir);
+
+        $this->object->set('TempDir', $dir . DIRECTORY_SEPARATOR);
         // Check no double slash is here
-        $this->assertEquals(
-            sys_get_temp_dir() . DIRECTORY_SEPARATOR . 'upload',
-            $this->object->getTempDir('upload')
-        );
+        self::assertSame($dir . DIRECTORY_SEPARATOR . 'upload', $this->object->getTempDir('upload'));
     }
 
     /**
      * Test for getUploadTempDir
      *
      * @group file-system
+     * @depends testGetTempDir
      */
     public function testGetUploadTempDir(): void
     {
-        $this->object->set('TempDir', realpath(sys_get_temp_dir()) . DIRECTORY_SEPARATOR);
+        $dir = realpath(sys_get_temp_dir());
+        self::assertNotFalse($dir);
+        self::assertDirectoryExists($dir);
+        self::assertDirectoryIsWritable($dir);
 
-        $this->assertEquals(
-            $this->object->getTempDir('upload'),
-            $this->object->getUploadTempDir()
-        );
+        $this->object->set('TempDir', $dir . DIRECTORY_SEPARATOR);
+
+        self::assertSame($this->object->getTempDir('upload'), $this->object->getUploadTempDir());
     }
 
     /**
@@ -1071,7 +1000,7 @@ class ConfigTest extends AbstractTestCase
         $this->object->checkServers();
         $expected = array_merge($this->object->defaultServer, $expected);
 
-        $this->assertEquals($expected, $this->object->settings['Servers'][1]);
+        self::assertSame($expected, $this->object->settings['Servers'][1]);
     }
 
     /**
@@ -1079,7 +1008,7 @@ class ConfigTest extends AbstractTestCase
      *
      * @return array
      */
-    public function serverSettingsProvider(): array
+    public static function serverSettingsProvider(): array
     {
         return [
             'empty' => [
@@ -1102,6 +1031,7 @@ class ConfigTest extends AbstractTestCase
 
     /**
      * @group with-trigger-error
+     * @requires PHPUnit < 10
      */
     public function testCheckServersWithInvalidServer(): void
     {
@@ -1112,7 +1042,7 @@ class ConfigTest extends AbstractTestCase
         $this->object->checkServers();
         $expected = array_merge($this->object->defaultServer, ['host' => '127.0.0.1']);
 
-        $this->assertEquals($expected, $this->object->settings['Servers'][1]);
+        self::assertSame($expected, $this->object->settings['Servers'][1]);
     }
 
     /**
@@ -1130,7 +1060,7 @@ class ConfigTest extends AbstractTestCase
         $this->object->settings['Servers'] = $settings;
         $this->object->checkServers();
         $_REQUEST['server'] = $request;
-        $this->assertEquals($expected, $this->object->selectServer());
+        self::assertSame($expected, $this->object->selectServer());
     }
 
     /**
@@ -1138,7 +1068,7 @@ class ConfigTest extends AbstractTestCase
      *
      * @return array
      */
-    public function selectServerProvider(): array
+    public static function selectServerProvider(): array
     {
         return [
             'zero' => [
@@ -1203,7 +1133,7 @@ class ConfigTest extends AbstractTestCase
     {
         $GLOBALS['cfg']['Server'] = $server_cfg;
         $result = Config::getConnectionParams($mode, $server);
-        $this->assertEquals($expected, $result);
+        self::assertEquals($expected, $result);
     }
 
     /**
@@ -1211,7 +1141,7 @@ class ConfigTest extends AbstractTestCase
      *
      * @return array
      */
-    public function connectionParams(): array
+    public static function connectionParams(): array
     {
         $cfg_basic = [
             'user' => 'u',
