@@ -41,6 +41,6 @@ class UpdateControllerTest extends AbstractTestCase
             new Relation($this->dbi)
         ))($request);
 
-        $this->assertTrue($response->hasSuccessState());
+        self::assertTrue($response->hasSuccessState());
     }
 }
