@@ -14,7 +14,6 @@ use stdClass;
 use function __;
 use function _pgettext;
 use function hash;
-use function header;
 use function htmlspecialchars;
 use function mb_strpos;
 use function ob_end_clean;
@@ -76,75 +75,33 @@ class CoreTest extends AbstractNetworkTestCase
             ],
         ];
 
-        $this->assertEquals(
-            Core::arrayRead('int', $arr),
-            $arr['int']
-        );
+        self::assertSame(Core::arrayRead('int', $arr), $arr['int']);
 
-        $this->assertEquals(
-            Core::arrayRead('str', $arr),
-            $arr['str']
-        );
+        self::assertSame(Core::arrayRead('str', $arr), $arr['str']);
 
-        $this->assertEquals(
-            Core::arrayRead('arr/0', $arr),
-            $arr['arr'][0]
-        );
+        self::assertSame(Core::arrayRead('arr/0', $arr), $arr['arr'][0]);
 
-        $this->assertEquals(
-            Core::arrayRead('arr/1', $arr),
-            $arr['arr'][1]
-        );
+        self::assertSame(Core::arrayRead('arr/1', $arr), $arr['arr'][1]);
 
-        $this->assertEquals(
-            Core::arrayRead('arr/2', $arr),
-            $arr['arr'][2]
-        );
+        self::assertSame(Core::arrayRead('arr/2', $arr), $arr['arr'][2]);
 
-        $this->assertEquals(
-            Core::arrayRead('sarr/arr1/0', $arr),
-            $arr['sarr']['arr1'][0]
-        );
+        self::assertSame(Core::arrayRead('sarr/arr1/0', $arr), $arr['sarr']['arr1'][0]);
 
-        $this->assertEquals(
-            Core::arrayRead('sarr/arr1/1', $arr),
-            $arr['sarr']['arr1'][1]
-        );
+        self::assertSame(Core::arrayRead('sarr/arr1/1', $arr), $arr['sarr']['arr1'][1]);
 
-        $this->assertEquals(
-            Core::arrayRead('sarr/arr1/2', $arr),
-            $arr['sarr']['arr1'][2]
-        );
+        self::assertSame(Core::arrayRead('sarr/arr1/2', $arr), $arr['sarr']['arr1'][2]);
 
-        $this->assertEquals(
-            Core::arrayRead('sarr/0/0', $arr),
-            $arr['sarr'][0][0]
-        );
+        self::assertSame(Core::arrayRead('sarr/0/0', $arr), $arr['sarr'][0][0]);
 
-        $this->assertEquals(
-            Core::arrayRead('sarr/0/1', $arr),
-            $arr['sarr'][0][1]
-        );
+        self::assertSame(Core::arrayRead('sarr/0/1', $arr), $arr['sarr'][0][1]);
 
-        $this->assertEquals(
-            Core::arrayRead('sarr/0/1/2', $arr),
-            $arr['sarr'][0][1][2]
-        );
+        self::assertSame(Core::arrayRead('sarr/0/1/2', $arr), $arr['sarr'][0][1][2]);
 
-        $this->assertEquals(
-            Core::arrayRead('sarr/not_exiting/1', $arr),
-            null
-        );
+        self::assertSame(Core::arrayRead('sarr/not_exiting/1', $arr), null);
 
-        $this->assertEquals(
-            Core::arrayRead('sarr/not_exiting/1', $arr, 0),
-            0
-        );
+        self::assertSame(Core::arrayRead('sarr/not_exiting/1', $arr, 0), 0);
 
-        $this->assertEquals(
-            Core::arrayRead('sarr/not_exiting/1', $arr, 'default_val'),
-            'default_val'
-        );
+        self::assertSame(Core::arrayRead('sarr/not_exiting/1', $arr, 'default_val'), 'default_val');
     }
 
     /**
@@ -179,40 +136,40 @@ class CoreTest extends AbstractNetworkTestCase
         ];
 
         Core::arrayWrite('int', $arr, 5);
-        $this->assertEquals($arr['int'], 5);
+        self::assertSame($arr['int'], 5);
 
         Core::arrayWrite('str', $arr, '_str');
-        $this->assertEquals($arr['str'], '_str');
+        self::assertSame($arr['str'], '_str');
 
         Core::arrayWrite('arr/0', $arr, 'val_arr_0');
-        $this->assertEquals($arr['arr'][0], 'val_arr_0');
+        self::assertSame($arr['arr'][0], 'val_arr_0');
 
         Core::arrayWrite('arr/1', $arr, 'val_arr_1');
-        $this->assertEquals($arr['arr'][1], 'val_arr_1');
+        self::assertSame($arr['arr'][1], 'val_arr_1');
 
         Core::arrayWrite('arr/2', $arr, 'val_arr_2');
-        $this->assertEquals($arr['arr'][2], 'val_arr_2');
+        self::assertSame($arr['arr'][2], 'val_arr_2');
 
         Core::arrayWrite('sarr/arr1/0', $arr, 'val_sarr_arr_0');
-        $this->assertEquals($arr['sarr']['arr1'][0], 'val_sarr_arr_0');
+        self::assertSame($arr['sarr']['arr1'][0], 'val_sarr_arr_0');
 
         Core::arrayWrite('sarr/arr1/1', $arr, 'val_sarr_arr_1');
-        $this->assertEquals($arr['sarr']['arr1'][1], 'val_sarr_arr_1');
+        self::assertSame($arr['sarr']['arr1'][1], 'val_sarr_arr_1');
 
         Core::arrayWrite('sarr/arr1/2', $arr, 'val_sarr_arr_2');
-        $this->assertEquals($arr['sarr']['arr1'][2], 'val_sarr_arr_2');
+        self::assertSame($arr['sarr']['arr1'][2], 'val_sarr_arr_2');
 
         Core::arrayWrite('sarr/0/0', $arr, 5);
-        $this->assertEquals($arr['sarr'][0][0], 5);
+        self::assertSame($arr['sarr'][0][0], 5);
 
         Core::arrayWrite('sarr/0/1/0', $arr, 'e');
-        $this->assertEquals($arr['sarr'][0][1][0], 'e');
+        self::assertSame($arr['sarr'][0][1][0], 'e');
 
         Core::arrayWrite('sarr/not_existing/1', $arr, 'some_val');
-        $this->assertEquals($arr['sarr']['not_existing'][1], 'some_val');
+        self::assertSame($arr['sarr']['not_existing'][1], 'some_val');
 
         Core::arrayWrite('sarr/0/2', $arr, null);
-        $this->assertNull($arr['sarr'][0][2]);
+        self::assertNull($arr['sarr'][0][2]);
     }
 
     /**
@@ -247,48 +204,48 @@ class CoreTest extends AbstractNetworkTestCase
         ];
 
         Core::arrayRemove('int', $arr);
-        $this->assertArrayNotHasKey('int', $arr);
+        self::assertArrayNotHasKey('int', $arr);
 
         Core::arrayRemove('str', $arr);
-        $this->assertArrayNotHasKey('str', $arr);
+        self::assertArrayNotHasKey('str', $arr);
 
         Core::arrayRemove('arr/0', $arr);
-        $this->assertArrayNotHasKey(0, $arr['arr']);
+        self::assertArrayNotHasKey(0, $arr['arr']);
 
         Core::arrayRemove('arr/1', $arr);
-        $this->assertArrayNotHasKey(1, $arr['arr']);
+        self::assertArrayNotHasKey(1, $arr['arr']);
 
         Core::arrayRemove('arr/2', $arr);
-        $this->assertArrayNotHasKey('arr', $arr);
+        self::assertArrayNotHasKey('arr', $arr);
 
         $tmp_arr = $arr;
         Core::arrayRemove('sarr/not_existing/1', $arr);
-        $this->assertEquals($tmp_arr, $arr);
+        self::assertSame($tmp_arr, $arr);
 
         Core::arrayRemove('sarr/arr1/0', $arr);
-        $this->assertArrayNotHasKey(0, $arr['sarr']['arr1']);
+        self::assertArrayNotHasKey(0, $arr['sarr']['arr1']);
 
         Core::arrayRemove('sarr/arr1/1', $arr);
-        $this->assertArrayNotHasKey(1, $arr['sarr']['arr1']);
+        self::assertArrayNotHasKey(1, $arr['sarr']['arr1']);
 
         Core::arrayRemove('sarr/arr1/2', $arr);
-        $this->assertArrayNotHasKey('arr1', $arr['sarr']);
+        self::assertArrayNotHasKey('arr1', $arr['sarr']);
 
         Core::arrayRemove('sarr/0/0', $arr);
-        $this->assertArrayNotHasKey(0, $arr['sarr'][0]);
+        self::assertArrayNotHasKey(0, $arr['sarr'][0]);
 
         Core::arrayRemove('sarr/0/1/0', $arr);
-        $this->assertArrayNotHasKey(0, $arr['sarr'][0][1]);
+        self::assertArrayNotHasKey(0, $arr['sarr'][0][1]);
 
         Core::arrayRemove('sarr/0/1/1', $arr);
-        $this->assertArrayNotHasKey(1, $arr['sarr'][0][1]);
+        self::assertArrayNotHasKey(1, $arr['sarr'][0][1]);
 
         Core::arrayRemove('sarr/0/1/2', $arr);
-        $this->assertArrayNotHasKey(1, $arr['sarr'][0]);
+        self::assertArrayNotHasKey(1, $arr['sarr'][0]);
 
         Core::arrayRemove('sarr/0/2', $arr);
 
-        $this->assertEmpty($arr);
+        self::assertEmpty($arr);
     }
 
     /**
@@ -303,7 +260,7 @@ class CoreTest extends AbstractNetworkTestCase
      */
     public function testGotoNowhere(?string $page, array $allowList, bool $include, bool $expected): void
     {
-        $this->assertSame($expected, Core::checkPageValidity($page, $allowList, $include));
+        self::assertSame($expected, Core::checkPageValidity($page, $allowList, $include));
     }
 
     /**
@@ -311,7 +268,7 @@ class CoreTest extends AbstractNetworkTestCase
      *
      * @return array
      */
-    public function providerTestGotoNowhere(): array
+    public static function providerTestGotoNowhere(): array
     {
         return [
             [
@@ -413,7 +370,7 @@ class CoreTest extends AbstractNetworkTestCase
      */
     public function testGetRealSize(string $size, int $expected): void
     {
-        $this->assertEquals($expected, Core::getRealSize($size));
+        self::assertSame($expected, Core::getRealSize($size));
     }
 
     /**
@@ -421,7 +378,7 @@ class CoreTest extends AbstractNetworkTestCase
      *
      * @return array
      */
-    public function providerTestGetRealSize(): array
+    public static function providerTestGetRealSize(): array
     {
         return [
             [
@@ -481,11 +438,8 @@ class CoreTest extends AbstractNetworkTestCase
     public function testGetPHPDocLink(): void
     {
         $lang = _pgettext('PHP documentation language', 'en');
-        $this->assertEquals(
-            Core::getPHPDocLink('function'),
-            './url.php?url=https%3A%2F%2Fwww.php.net%2Fmanual%2F'
-            . $lang . '%2Ffunction'
-        );
+        self::assertSame(Core::getPHPDocLink('function'), './url.php?url=https%3A%2F%2Fwww.php.net%2Fmanual%2F'
+        . $lang . '%2Ffunction');
     }
 
     /**
@@ -498,7 +452,7 @@ class CoreTest extends AbstractNetworkTestCase
      */
     public function testLinkURL(string $link, string $url): void
     {
-        $this->assertEquals(Core::linkURL($link), $url);
+        self::assertSame(Core::linkURL($link), $url);
     }
 
     /**
@@ -506,7 +460,7 @@ class CoreTest extends AbstractNetworkTestCase
      *
      * @return array
      */
-    public function providerTestLinkURL(): array
+    public static function providerTestLinkURL(): array
     {
         return [
             [
@@ -614,10 +568,7 @@ class CoreTest extends AbstractNetworkTestCase
     public function testIsAllowedDomain(string $url, $expected): void
     {
         $_SERVER['SERVER_NAME'] = 'server.local';
-        $this->assertEquals(
-            $expected,
-            Core::isAllowedDomain($url)
-        );
+        self::assertSame($expected, Core::isAllowedDomain($url));
     }
 
     /**
@@ -625,7 +576,7 @@ class CoreTest extends AbstractNetworkTestCase
      *
      * @return array
      */
-    public function provideTestIsAllowedDomain(): array
+    public static function provideTestIsAllowedDomain(): array
     {
         return [
             [
@@ -673,10 +624,7 @@ class CoreTest extends AbstractNetworkTestCase
      */
     public function testSafeUnserialize(string $data, $expected): void
     {
-        $this->assertEquals(
-            $expected,
-            Core::safeUnserialize($data)
-        );
+        self::assertSame($expected, Core::safeUnserialize($data));
     }
 
     /**
@@ -684,7 +632,7 @@ class CoreTest extends AbstractNetworkTestCase
      *
      * @return array
      */
-    public function provideTestSafeUnserialize(): array
+    public static function provideTestSafeUnserialize(): array
     {
         return [
             [
@@ -745,10 +693,7 @@ class CoreTest extends AbstractNetworkTestCase
      */
     public function testSanitizeMySQLHost(string $host, string $expected): void
     {
-        $this->assertEquals(
-            $expected,
-            Core::sanitizeMySQLHost($host)
-        );
+        self::assertSame($expected, Core::sanitizeMySQLHost($host));
     }
 
     /**
@@ -756,7 +701,7 @@ class CoreTest extends AbstractNetworkTestCase
      *
      * @return array
      */
-    public function provideTestSanitizeMySQLHost(): array
+    public static function provideTestSanitizeMySQLHost(): array
     {
         return [
             [
@@ -783,18 +728,9 @@ class CoreTest extends AbstractNetworkTestCase
      */
     public function testReplaceDots(): void
     {
-        $this->assertEquals(
-            Core::securePath('../../../etc/passwd'),
-            './././etc/passwd'
-        );
-        $this->assertEquals(
-            Core::securePath('/var/www/../phpmyadmin'),
-            '/var/www/./phpmyadmin'
-        );
-        $this->assertEquals(
-            Core::securePath('./path/with..dots/../../file..php'),
-            './path/with.dots/././file.php'
-        );
+        self::assertSame(Core::securePath('../../../etc/passwd'), './././etc/passwd');
+        self::assertSame(Core::securePath('/var/www/../phpmyadmin'), '/var/www/./phpmyadmin');
+        self::assertSame(Core::securePath('./path/with..dots/../../file..php'), './path/with.dots/././file.php');
     }
 
     /**
@@ -836,7 +772,7 @@ class CoreTest extends AbstractNetworkTestCase
         $printed = ob_get_contents();
         ob_end_clean();
 
-        $this->assertGreaterThan(0, mb_strpos((string) $printed, $warn));
+        self::assertGreaterThan(0, mb_strpos((string) $printed, $warn));
     }
 
     /**
@@ -848,7 +784,7 @@ class CoreTest extends AbstractNetworkTestCase
         $sqlQuery = 'SELECT * FROM `test`.`db` WHERE 1;';
         $signature = Core::signSqlQuery($sqlQuery);
         $hmac = '33371e8680a640dc05944a2a24e6e630d3e9e3dba24464135f2fb954c3a4ffe2';
-        $this->assertSame($hmac, $signature, 'The signature must match the computed one');
+        self::assertSame($hmac, $signature, 'The signature must match the computed one');
     }
 
     /**
@@ -859,7 +795,7 @@ class CoreTest extends AbstractNetworkTestCase
         $_SESSION[' HMAC_secret '] = hash('sha1', 'test');
         $sqlQuery = 'SELECT * FROM `test`.`db` WHERE 1;';
         $hmac = '33371e8680a640dc05944a2a24e6e630d3e9e3dba24464135f2fb954c3a4ffe2';
-        $this->assertTrue(Core::checkSqlQuerySignature($sqlQuery, $hmac));
+        self::assertTrue(Core::checkSqlQuerySignature($sqlQuery, $hmac));
     }
 
     /**
@@ -870,7 +806,7 @@ class CoreTest extends AbstractNetworkTestCase
         $_SESSION[' HMAC_secret '] = hash('sha1', '132654987gguieunofz');
         $sqlQuery = 'SELECT * FROM `test`.`db` WHERE 1;';
         $hmac = '33371e8680a640dc05944a2a24e6e630d3e9e3dba24464135f2fb954c3a4ffe2';
-        $this->assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
+        self::assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
     }
 
     /**
@@ -881,7 +817,7 @@ class CoreTest extends AbstractNetworkTestCase
         $_SESSION[' HMAC_secret '] = hash('sha1', 'test');
         $sqlQuery = 'SELECT * FROM `test`.`db` WHERE 1;';
         $hmac = '3333333380a640dc05944a2a24e6e630d3e9e3dba24464135f2fb954c3eeeeee';
-        $this->assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
+        self::assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
     }
 
     /**
@@ -892,7 +828,7 @@ class CoreTest extends AbstractNetworkTestCase
         $_SESSION[' HMAC_secret '] = 'empty';
         $sqlQuery = 'SELECT * FROM `test`.`db` WHERE 1;';
         $hmac = '3333333380a640dc05944a2a24e6e630d3e9e3dba24464135f2fb954c3eeeeee';
-        $this->assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
+        self::assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
     }
 
     /**
@@ -903,10 +839,10 @@ class CoreTest extends AbstractNetworkTestCase
         $_SESSION[' HMAC_secret '] = hash('sha1', 'firstSession');
         $sqlQuery = 'SELECT * FROM `test`.`db` WHERE 1;';
         $hmac = Core::signSqlQuery($sqlQuery);
-        $this->assertTrue(Core::checkSqlQuerySignature($sqlQuery, $hmac));
+        self::assertTrue(Core::checkSqlQuerySignature($sqlQuery, $hmac));
         $_SESSION[' HMAC_secret '] = hash('sha1', 'secondSession');
         // Try to use the token (hmac) from the previous session
-        $this->assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
+        self::assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
     }
 
     /**
@@ -918,16 +854,16 @@ class CoreTest extends AbstractNetworkTestCase
         $_SESSION[' HMAC_secret '] = hash('sha1', 'firstSession');
         $sqlQuery = 'SELECT * FROM `test`.`db` WHERE 1;';
         $hmac = Core::signSqlQuery($sqlQuery);
-        $this->assertTrue(Core::checkSqlQuerySignature($sqlQuery, $hmac));
+        self::assertTrue(Core::checkSqlQuerySignature($sqlQuery, $hmac));
         $GLOBALS['cfg']['blowfish_secret'] = str_repeat('a', 32);
         // Try to use the previous HMAC signature
-        $this->assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
+        self::assertFalse(Core::checkSqlQuerySignature($sqlQuery, $hmac));
 
         $GLOBALS['cfg']['blowfish_secret'] = str_repeat('a', 32);
         // Generate the HMAC signature to check that it works
         $hmac = Core::signSqlQuery($sqlQuery);
         // Must work now, (good secret and blowfish_secret)
-        $this->assertTrue(Core::checkSqlQuerySignature($sqlQuery, $hmac));
+        self::assertTrue(Core::checkSqlQuerySignature($sqlQuery, $hmac));
     }
 
     public function testPopulateRequestWithEncryptedQueryParams(): void
@@ -951,8 +887,8 @@ class CoreTest extends AbstractNetworkTestCase
 
         $expected = ['pos' => '0', 'db' => 'test_db', 'table' => 'test_table'];
 
-        $this->assertEquals($expected, $_GET);
-        $this->assertEquals($expected, $_REQUEST);
+        self::assertSame($expected, $_GET);
+        self::assertSame($expected, $_REQUEST);
     }
 
     /**
@@ -982,14 +918,14 @@ class CoreTest extends AbstractNetworkTestCase
 
         Core::populateRequestWithEncryptedQueryParams($request);
 
-        $this->assertEquals($decrypted, $_GET);
-        $this->assertEquals($decrypted, $_REQUEST);
+        self::assertSame($decrypted, $_GET);
+        self::assertSame($decrypted, $_REQUEST);
     }
 
     /**
      * @return array<int, array<int, array<string, string|mixed[]>>>
      */
-    public function providerForTestPopulateRequestWithEncryptedQueryParamsWithInvalidParam(): array
+    public static function providerForTestPopulateRequestWithEncryptedQueryParamsWithInvalidParam(): array
     {
         return [
             [[], []],
@@ -999,57 +935,30 @@ class CoreTest extends AbstractNetworkTestCase
         ];
     }
 
-    /**
-     * @runInSeparateProcess
-     * @preserveGlobalState disabled
-     * @requires extension xdebug
-     * @group ext-xdebug
-     */
-    public function testDownloadHeader(): void
+    public function testGetDownloadHeaders(): void
     {
-        $GLOBALS['config']->set('PMA_USR_BROWSER_AGENT', 'FIREFOX');
+        $headersList = Core::getDownloadHeaders('test.sql', 'text/x-sql', 100, false);
 
-        header('Cache-Control: private, max-age=10800');
-
-        Core::downloadHeader('test.sql', 'text/x-sql', 100, false);
-
-        // phpcs:disable SlevomatCodingStandard.Namespaces.ReferenceUsedNamesOnly.ReferenceViaFullyQualifiedName
-        $headersList = \xdebug_get_headers();
-        // phpcs:enable
-
-        $this->assertContains('Cache-Control: private, max-age=10800', $headersList);
-        $this->assertContains('Content-Description: File Transfer', $headersList);
-        $this->assertContains('Content-Disposition: attachment; filename="test.sql"', $headersList);
-        $this->assertContains('Content-type: text/x-sql;charset=UTF-8', $headersList);
-        $this->assertContains('Content-Transfer-Encoding: binary', $headersList);
-        $this->assertContains('Content-Length: 100', $headersList);
-        $this->assertNotContains('Content-Encoding: gzip', $headersList);
+        $expected = [
+            'Content-Description' => 'File Transfer',
+            'Content-Disposition' => 'attachment; filename="test.sql"',
+            'Content-Type' => 'text/x-sql',
+            'Content-Transfer-Encoding' => 'binary',
+            'Content-Length' => '100',
+        ];
+        self::assertSame($expected, $headersList);
     }
 
-    /**
-     * @runInSeparateProcess
-     * @preserveGlobalState disabled
-     * @requires extension xdebug
-     * @group ext-xdebug
-     */
-    public function testDownloadHeader2(): void
+    public function testGetDownloadHeaders2(): void
     {
-        $GLOBALS['config']->set('PMA_USR_BROWSER_AGENT', 'FIREFOX');
+        $headersList = Core::getDownloadHeaders('test.sql.gz', 'application/x-gzip', 0, false);
 
-        header('Cache-Control: private, max-age=10800');
-
-        Core::downloadHeader('test.sql.gz', 'application/x-gzip', 0, false);
-
-        // phpcs:disable SlevomatCodingStandard.Namespaces.ReferenceUsedNamesOnly.ReferenceViaFullyQualifiedName
-        $headersList = \xdebug_get_headers();
-        // phpcs:enable
-
-        $this->assertContains('Cache-Control: private, max-age=10800', $headersList);
-        $this->assertContains('Content-Description: File Transfer', $headersList);
-        $this->assertContains('Content-Disposition: attachment; filename="test.sql.gz"', $headersList);
-        $this->assertContains('Content-Type: application/x-gzip', $headersList);
-        $this->assertNotContains('Content-Encoding: gzip', $headersList);
-        $this->assertContains('Content-Transfer-Encoding: binary', $headersList);
-        $this->assertNotContains('Content-Length: 0', $headersList);
+        $expected = [
+            'Content-Description' => 'File Transfer',
+            'Content-Disposition' => 'attachment; filename="test.sql.gz"',
+            'Content-Type' => 'application/x-gzip',
+            'Content-Transfer-Encoding' => 'binary',
+        ];
+        self::assertSame($expected, $headersList);
     }
 }
