@@ -14,6 +14,8 @@ use PhpMyAdmin\SystemDatabase;
 use PhpMyAdmin\Utils\SessionCache;
 use stdClass;
 
+use function array_keys;
+
 /**
  * @covers \PhpMyAdmin\DatabaseInterface
  */
@@ -60,15 +62,9 @@ class DatabaseInterfaceTest extends AbstractTestCase
             $this->dummyDbi->addResult('SELECT CURRENT_USER();', $value);
         }
 
-        $this->assertEquals(
-            $expected,
-            $this->dbi->getCurrentUserAndHost()
-        );
+        self::assertSame($expected, $this->dbi->getCurrentUserAndHost());
 
-        $this->assertEquals(
-            $string,
-            $this->dbi->getCurrentUser()
-        );
+        self::assertSame($string, $this->dbi->getCurrentUser());
 
         $this->assertAllQueriesConsumed();
     }
@@ -78,7 +74,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
      *
      * @return array
      */
-    public function currentUserData(): array
+    public static function currentUserData(): array
     {
         return [
             [
@@ -111,6 +107,74 @@ class DatabaseInterfaceTest extends AbstractTestCase
         ];
     }
 
+    /**
+     * Tests for DBI::getCurrentRole() method.
+     *
+     * @param string[][]|false $value
+     * @param string[]         $string
+     * @param string[][]       $expected
+     *
+     * @dataProvider currentRolesData
+     */
+    public function testGetCurrentRoles(
+        string $version,
+        bool $isRoleSupported,
+        $value,
+        array $string,
+        array $expected
+    ): void {
+        $this->dbi->setVersion(['@@version' => $version]);
+
+        SessionCache::remove('mysql_cur_role');
+
+        if ($isRoleSupported) {
+            $this->dummyDbi->addResult('SELECT CURRENT_ROLE();', $value);
+        }
+
+        self::assertSame($expected, $this->dbi->getCurrentRolesAndHost());
+
+        self::assertSame($string, $this->dbi->getCurrentRoles());
+
+        $this->assertAllQueriesConsumed();
+    }
+
+    /**
+     * Data provider for getCurrentRole() tests.
+     *
+     * @return mixed[]
+     */
+    public static function currentRolesData(): array
+    {
+        return [
+            ['10.4.99-MariaDB', false, false, [], []],
+            ['5.7.35 - MySQL Community Server (GPL)', false, false, [], []],
+            [
+                '8.0.0 - MySQL Community Server - GPL',
+                true,
+                [['`role`@`localhost`']],
+                ['role@localhost'],
+                [['role', 'localhost']],
+            ],
+            [
+                '8.0.0 - MySQL Community Server - GPL',
+                true,
+                [['`role`@`localhost`, `role2`@`localhost`']],
+                ['role@localhost', 'role2@localhost'],
+                [['role', 'localhost'], ['role2', 'localhost']],
+            ],
+            ['8.0.0 - MySQL Community Server - GPL', true, [['@`localhost`']], ['@localhost'], [['', 'localhost']]],
+            ['10.5.0-MariaDB', true, [['`role`@`localhost`']], ['role@localhost'], [['role', 'localhost']]],
+            [
+                '10.5.0-MariaDB',
+                true,
+                [['`role`@`localhost`, `role2`@`localhost`']],
+                ['role@localhost', 'role2@localhost'],
+                [['role', 'localhost'], ['role2', 'localhost']],
+            ],
+            ['10.5.0-MariaDB', true, [['@`localhost`']], ['@localhost'], [['', 'localhost']]],
+        ];
+    }
+
     /**
      * Tests for DBI::getColumnMapFromSql() method.
      */
@@ -140,22 +204,16 @@ class DatabaseInterfaceTest extends AbstractTestCase
 
         $column_map = $this->dbi->getColumnMapFromSql($sql_query, $view_columns);
 
-        $this->assertEquals(
-            [
-                'table_name' => 'meta1_table',
-                'refering_column' => 'meta1_name',
-                'real_column' => 'view_columns1',
-            ],
-            $column_map[0]
-        );
-        $this->assertEquals(
-            [
-                'table_name' => 'meta2_table',
-                'refering_column' => 'meta2_name',
-                'real_column' => 'view_columns2',
-            ],
-            $column_map[1]
-        );
+        self::assertSame([
+            'table_name' => 'meta1_table',
+            'refering_column' => 'meta1_name',
+            'real_column' => 'view_columns1',
+        ], $column_map[0]);
+        self::assertSame([
+            'table_name' => 'meta2_table',
+            'refering_column' => 'meta2_name',
+            'real_column' => 'view_columns2',
+        ], $column_map[1]);
 
         $this->assertAllQueriesConsumed();
     }
@@ -166,7 +224,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
     public function testGetSystemDatabase(): void
     {
         $sd = $this->dbi->getSystemDatabase();
-        $this->assertInstanceOf(SystemDatabase::class, $sd);
+        self::assertInstanceOf(SystemDatabase::class, $sd);
     }
 
     /**
@@ -182,7 +240,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
         $GLOBALS['db'] = '';
         $GLOBALS['cfg']['Server']['only_db'] = [];
         $this->dbi->postConnectControl(new Relation($this->dbi));
-        $this->assertInstanceOf(DatabaseList::class, $GLOBALS['dblist']);
+        self::assertInstanceOf(DatabaseList::class, $GLOBALS['dblist']);
     }
 
     /**
@@ -267,9 +325,9 @@ class DatabaseInterfaceTest extends AbstractTestCase
 
         $mock->postConnect();
 
-        $this->assertEquals($mock->getVersion(), $versionInt);
-        $this->assertEquals($mock->isMariaDB(), $isMariaDb);
-        $this->assertEquals($mock->isPercona(), $isPercona);
+        self::assertSame($mock->getVersion(), $versionInt);
+        self::assertSame($mock->isMariaDB(), $isMariaDb);
+        self::assertSame($mock->isPercona(), $isPercona);
     }
 
     /**
@@ -278,19 +336,20 @@ class DatabaseInterfaceTest extends AbstractTestCase
     public function testGetDbCollation(): void
     {
         $GLOBALS['server'] = 1;
-        // test case for system schema
-        $this->assertEquals(
-            'utf8_general_ci',
-            $this->dbi->getDbCollation('information_schema')
-        );
-
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
         $GLOBALS['cfg']['DBG']['sql'] = false;
 
-        $this->assertEquals(
-            'utf8_general_ci',
-            $this->dbi->getDbCollation('pma_test')
-        );
+        self::assertSame('utf8_general_ci', $this->dbi->getDbCollation('pma_test'));
+
+        $GLOBALS['cfg']['Server']['DisableIS'] = true;
+
+        $this->dummyDbi->addSelectDb('information_schema');
+        $GLOBALS['db'] = 'information_schema';
+
+        $this->dummyDbi->removeDefaultResults();
+        $this->dummyDbi->addResult('SELECT @@collation_database', [['utf8mb3_general_ci']], ['@@collation_database']);
+
+        self::assertSame('utf8mb3_general_ci', $this->dbi->getDbCollation('information_schema'));
     }
 
     /**
@@ -300,7 +359,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
     {
         $GLOBALS['server'] = 1;
         $GLOBALS['cfg']['DBG']['sql'] = true;
-        $this->assertEquals('utf8_general_ci', $this->dbi->getServerCollation());
+        self::assertSame('utf8_general_ci', $this->dbi->getServerCollation());
     }
 
     /**
@@ -314,13 +373,10 @@ class DatabaseInterfaceTest extends AbstractTestCase
      */
     public function testFormatError(int $error_number, string $error_message, string $match): void
     {
-        $this->assertStringContainsString(
-            $match,
-            Utilities::formatError($error_number, $error_message)
-        );
+        self::assertStringContainsString($match, Utilities::formatError($error_number, $error_message));
     }
 
-    public function errorData(): array
+    public static function errorData(): array
     {
         return [
             [
@@ -370,10 +426,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
 
         $this->dummyDbi->addResult('SELECT @@basedir', $value);
 
-        $this->assertEquals(
-            $expected,
-            $this->dbi->isAmazonRds()
-        );
+        self::assertSame($expected, $this->dbi->isAmazonRds());
 
         $this->assertAllQueriesConsumed();
     }
@@ -383,7 +436,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
      *
      * @return array
      */
-    public function isAmazonRdsData(): array
+    public static function isAmazonRdsData(): array
     {
         return [
             [
@@ -418,12 +471,12 @@ class DatabaseInterfaceTest extends AbstractTestCase
     public function testVersion(string $version, int $expected, int $major, bool $upgrade): void
     {
         $ver_int = Utilities::versionToInt($version);
-        $this->assertEquals($expected, $ver_int);
-        $this->assertEquals($major, (int) ($ver_int / 10000));
-        $this->assertEquals($upgrade, $ver_int < $GLOBALS['cfg']['MysqlMinVersion']['internal']);
+        self::assertSame($expected, $ver_int);
+        self::assertSame($major, (int) ($ver_int / 10000));
+        self::assertSame($upgrade, $ver_int < $GLOBALS['cfg']['MysqlMinVersion']['internal']);
     }
 
-    public function versionData(): array
+    public static function versionData(): array
     {
         return [
             [
@@ -524,7 +577,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
         ];
 
         $actual = $this->dbi->getTablesFull('test_db');
-        $this->assertEquals($expected, $actual);
+        self::assertSame($expected, $actual);
     }
 
     public function testGetTablesFullWithInformationSchema(): void
@@ -580,7 +633,24 @@ class DatabaseInterfaceTest extends AbstractTestCase
         ];
 
         $actual = $this->dbi->getTablesFull('test_db');
-        $this->assertEquals($expected, $actual);
+        self::assertSame($expected, $actual);
+    }
+
+    public function testGetTablesFullBug18913(): void
+    {
+        $GLOBALS['cfg']['Server']['DisableIS'] = true;
+        $GLOBALS['cfg']['NaturalOrder'] = false;
+
+        $expected = ['0', '1', '42'];
+
+        $this->dummyDbi->addResult('SHOW TABLE STATUS FROM `test_db_bug_18913`', [
+            ['0', ''],
+            ['1', ''],
+            ['42', ''],
+        ], ['Name', 'Engine']);
+
+        $actual = $this->dbi->getTablesFull('test_db_bug_18913');
+        self::assertEquals($expected, array_keys($actual));
     }
 
     /**
@@ -593,15 +663,9 @@ class DatabaseInterfaceTest extends AbstractTestCase
         $this->dummyDbi->addResult($sql, [true]);
         $this->dummyDbi->addResult('Invalid query', false);
 
-        $this->assertInstanceOf(
-            ResultInterface::class,
-            $this->dbi->queryAsControlUser($sql)
-        );
-        $this->assertInstanceOf(
-            ResultInterface::class,
-            $this->dbi->tryQueryAsControlUser($sql)
-        );
-        $this->assertFalse($this->dbi->tryQueryAsControlUser('Invalid query'));
+        self::assertInstanceOf(ResultInterface::class, $this->dbi->queryAsControlUser($sql));
+        self::assertInstanceOf(ResultInterface::class, $this->dbi->tryQueryAsControlUser($sql));
+        self::assertFalse($this->dbi->tryQueryAsControlUser('Invalid query'));
     }
 
     public function testGetDatabasesFullDisabledISAndSortIntColumn(): void
@@ -775,7 +839,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
             100
         );
 
-        $this->assertSame([
+        self::assertSame([
             [
                 'SCHEMA_NAME' => 'db2',
                 'DEFAULT_COLLATION_NAME' => 'utf8_general_ci',
@@ -822,10 +886,10 @@ class DatabaseInterfaceTest extends AbstractTestCase
     ): void {
         $this->dbi->setVersion($version);
 
-        $this->assertEquals($versionInt, $this->dbi->getVersion());
-        $this->assertEquals($isMariaDb, $this->dbi->isMariaDB());
-        $this->assertEquals($isPercona, $this->dbi->isPercona());
-        $this->assertEquals($version['@@version'], $this->dbi->getVersionString());
+        self::assertSame($versionInt, $this->dbi->getVersion());
+        self::assertSame($isMariaDb, $this->dbi->isMariaDB());
+        self::assertSame($isPercona, $this->dbi->isPercona());
+        self::assertSame($version['@@version'], $this->dbi->getVersionString());
     }
 
     /**
@@ -834,7 +898,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
      * @return array
      * @psalm-return array<int, array{array<array-key, mixed>, int, bool, bool}>
      */
-    public function provideDatabaseVersionData(): array
+    public static function provideDatabaseVersionData(): array
     {
         return [
             [
