@@ -18,9 +18,6 @@ class EnvironmentTest extends AbstractTestCase
      */
     public function testPhpVersion(): void
     {
-        $this->assertTrue(
-            version_compare('7.2.5', PHP_VERSION, '<='),
-            'phpMyAdmin requires PHP 7.2.5 or above'
-        );
+        self::assertTrue(version_compare('7.2.5', PHP_VERSION, '<='), 'phpMyAdmin requires PHP 7.2.5 or above');
     }
 }
