@@ -43,7 +43,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array common data for data providers
      */
-    private function getData(): array
+    private static function getData(): array
     {
         return [
             'MULTIPOLYGON' => [
@@ -124,10 +124,10 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array data for testGenerateWkt
      */
-    public function providerForTestGenerateWkt(): array
+    public static function providerForTestGenerateWkt(): array
     {
         $temp = [
-            0 => $this->getData(),
+            0 => self::getData(),
         ];
 
         $temp1 = $temp;
@@ -178,11 +178,11 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array data for testGenerateParams
      */
-    public function providerForTestGenerateParams(): array
+    public static function providerForTestGenerateParams(): array
     {
-        $temp = $this->getData();
+        $temp = self::getData();
 
-        $temp1 = $this->getData();
+        $temp1 = self::getData();
         $temp1['gis_type'] = 'MULTIPOLYGON';
 
         return [
@@ -214,7 +214,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      */
     public function testGetShape(array $row_data, string $shape): void
     {
-        $this->assertEquals($this->object->getShape($row_data), $shape);
+        self::assertSame($this->object->getShape($row_data), $shape);
     }
 
     /**
@@ -222,7 +222,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array data for testGetShape
      */
-    public function providerForTestGetShape(): array
+    public static function providerForTestGetShape(): array
     {
         return [
             [
@@ -305,7 +305,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array data for testScaleRow
      */
-    public function providerForTestScaleRow(): array
+    public static function providerForTestScaleRow(): array
     {
         return [
             [
@@ -336,7 +336,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
     public function testPrepareRowAsPng(): void
     {
         $image = ImageWrapper::create(120, 150);
-        $this->assertNotNull($image);
+        self::assertNotNull($image);
         $return = $this->object->prepareRowAsPng(
             'MULTIPOLYGON(((136 40,147 83,16 75,136 40)),((105 0,56 20,78 73,105 0)))',
             'image',
@@ -344,8 +344,8 @@ class GisMultiPolygonTest extends GisGeomTestCase
             ['x' => 12, 'y' => 69, 'scale' => 2, 'height' => 150],
             $image
         );
-        $this->assertEquals(120, $return->width());
-        $this->assertEquals(150, $return->height());
+        self::assertSame(120, $return->width());
+        self::assertSame(150, $return->height());
     }
 
     /**
@@ -367,7 +367,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
         TCPDF $pdf
     ): void {
         $return = $this->object->prepareRowAsPdf($spatial, $label, $fill_color, $scale_data, $pdf);
-        $this->assertInstanceOf(TCPDF::class, $return);
+        self::assertInstanceOf(TCPDF::class, $return);
     }
 
     /**
@@ -375,7 +375,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array test data for testPrepareRowAsPdf() test case
      */
-    public function providerForPrepareRowAsPdf(): array
+    public static function providerForPrepareRowAsPdf(): array
     {
         return [
             [
@@ -412,7 +412,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
         string $output
     ): void {
         $string = $this->object->prepareRowAsSvg($spatial, $label, $fillColor, $scaleData);
-        $this->assertEquals(1, preg_match($output, $string));
+        self::assertSame(1, preg_match($output, $string));
     }
 
     /**
@@ -420,7 +420,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array test data for testPrepareRowAsSvg() test case
      */
-    public function providerForPrepareRowAsSvg(): array
+    public static function providerForPrepareRowAsSvg(): array
     {
         return [
             [
@@ -433,10 +433,10 @@ class GisMultiPolygonTest extends GisGeomTestCase
                     'scale' => 2,
                     'height' => 150,
                 ],
-                '/^(<path d=" M 248, 208 L 270, 122 L 8, 138 Z " name="svg" class="'
+                '/^(<path d=" M 248, 208 L 270, 122 L 8, 138 Z " data-label="svg" class="'
                 . 'multipolygon vector" stroke="black" stroke-width="0.5" fill="'
                 . '#B02EE0" fill-rule="evenodd" fill-opacity="0.8" id="svg)(\d+)'
-                . '("\/><path d=" M 186, 288 L 88, 248 L 132, 142 Z " name="svg" '
+                . '("\/><path d=" M 186, 288 L 88, 248 L 132, 142 Z " data-label="svg" '
                 . 'class="multipolygon vector" stroke="black" stroke-width="0.5" '
                 . 'fill="#B02EE0" fill-rule="evenodd" fill-opacity="0.8" id="svg)'
                 . '(\d+)("\/>)$/',
@@ -464,16 +464,13 @@ class GisMultiPolygonTest extends GisGeomTestCase
         array $scale_data,
         string $output
     ): void {
-        $this->assertEquals(
-            $output,
-            $this->object->prepareRowAsOl(
-                $spatial,
-                $srid,
-                $label,
-                $fill_color,
-                $scale_data
-            )
-        );
+        self::assertSame($output, $this->object->prepareRowAsOl(
+            $spatial,
+            $srid,
+            $label,
+            $fill_color,
+            $scale_data
+        ));
     }
 
     /**
@@ -481,7 +478,7 @@ class GisMultiPolygonTest extends GisGeomTestCase
      *
      * @return array test data for testPrepareRowAsOl() test case
      */
-    public function providerForPrepareRowAsOl(): array
+    public static function providerForPrepareRowAsOl(): array
     {
         return [
             [
