@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
+use PhpMyAdmin\Console;
 use PhpMyAdmin\Core;
 use PhpMyAdmin\Header;
 use ReflectionProperty;
@@ -11,6 +12,7 @@ use ReflectionProperty;
 use function gmdate;
 
 use const DATE_RFC1123;
+use const PHP_VERSION_ID;
 
 /**
  * @covers \PhpMyAdmin\Header
@@ -49,10 +51,7 @@ class HeaderTest extends AbstractTestCase
     {
         $header = new Header();
         $header->disable();
-        $this->assertEquals(
-            '',
-            $header->getDisplay()
-        );
+        self::assertSame('', $header->getDisplay());
     }
 
     /**
@@ -62,10 +61,7 @@ class HeaderTest extends AbstractTestCase
     {
         $GLOBALS['server'] = 0;
         $header = new Header();
-        $this->assertStringContainsString(
-            '<title>phpMyAdmin</title>',
-            $header->getDisplay()
-        );
+        self::assertStringContainsString('<title>phpMyAdmin</title>', $header->getDisplay());
     }
 
     /**
@@ -75,10 +71,7 @@ class HeaderTest extends AbstractTestCase
     {
         $header = new Header();
         $header->setBodyId('PMA_header_id');
-        $this->assertStringContainsString(
-            'PMA_header_id',
-            $header->getDisplay()
-        );
+        self::assertStringContainsString('PMA_header_id', $header->getDisplay());
     }
 
     /**
@@ -87,10 +80,7 @@ class HeaderTest extends AbstractTestCase
     public function testGetJsParams(): void
     {
         $header = new Header();
-        $this->assertArrayHasKey(
-            'common_query',
-            $header->getJsParams()
-        );
+        self::assertArrayHasKey('common_query', $header->getJsParams());
     }
 
     /**
@@ -99,10 +89,7 @@ class HeaderTest extends AbstractTestCase
     public function testGetJsParamsCode(): void
     {
         $header = new Header();
-        $this->assertStringContainsString(
-            'CommonParams.setAll',
-            $header->getJsParamsCode()
-        );
+        self::assertStringContainsString('CommonParams.setAll', $header->getJsParamsCode());
     }
 
     /**
@@ -111,10 +98,7 @@ class HeaderTest extends AbstractTestCase
     public function testGetMessage(): void
     {
         $header = new Header();
-        $this->assertStringContainsString(
-            'phpmyadminmessage',
-            $header->getMessage()
-        );
+        self::assertStringContainsString('phpmyadminmessage', $header->getMessage());
     }
 
     /**
@@ -123,12 +107,14 @@ class HeaderTest extends AbstractTestCase
     public function testDisableWarnings(): void
     {
         $reflection = new ReflectionProperty(Header::class, 'warningsEnabled');
-        $reflection->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $reflection->setAccessible(true);
+        }
 
         $header = new Header();
         $header->disableWarnings();
 
-        $this->assertFalse($reflection->getValue($header));
+        self::assertFalse($reflection->getValue($header));
     }
 
     /**
@@ -161,7 +147,7 @@ class HeaderTest extends AbstractTestCase
 
         $expected = [
             'X-Frame-Options' => $expectedFrameOptions,
-            'Referrer-Policy' => 'no-referrer',
+            'Referrer-Policy' => 'same-origin',
             'Content-Security-Policy' => $expectedCsp,
             'X-Content-Security-Policy' => $expectedXCsp,
             'X-WebKit-CSP' => $expectedWebKitCsp,
@@ -180,10 +166,10 @@ class HeaderTest extends AbstractTestCase
         }
 
         $headers = $this->callFunction($header, Header::class, 'getHttpHeaders', []);
-        $this->assertSame($expected, $headers);
+        self::assertSame($expected, $headers);
     }
 
-    public function providerForTestGetHttpHeaders(): array
+    public static function providerForTestGetHttpHeaders(): array
     {
         return [
             [
@@ -245,4 +231,34 @@ class HeaderTest extends AbstractTestCase
             ],
         ];
     }
+
+    public function testSetAjax(): void
+    {
+        $header = new Header();
+        $consoleReflection = new ReflectionProperty(Header::class, 'console');
+        if (PHP_VERSION_ID < 80100) {
+            $consoleReflection->setAccessible(true);
+        }
+
+        $console = $consoleReflection->getValue($header);
+        self::assertInstanceOf(Console::class, $console);
+        $isAjax = new ReflectionProperty(Header::class, 'isAjax');
+        if (PHP_VERSION_ID < 80100) {
+            $isAjax->setAccessible(true);
+        }
+
+        $consoleIsAjax = new ReflectionProperty(Console::class, 'isAjax');
+        if (PHP_VERSION_ID < 80100) {
+            $consoleIsAjax->setAccessible(true);
+        }
+
+        self::assertFalse($isAjax->getValue($header));
+        self::assertFalse($consoleIsAjax->getValue($console));
+        $header->setAjax(true);
+        self::assertTrue($isAjax->getValue($header));
+        self::assertTrue($consoleIsAjax->getValue($console));
+        $header->setAjax(false);
+        self::assertFalse($isAjax->getValue($header));
+        self::assertFalse($consoleIsAjax->getValue($console));
+    }
 }
