@@ -17,7 +17,7 @@ class MySQLDocumentationTest extends AbstractTestCase
         $GLOBALS['server'] = '99';
         $GLOBALS['cfg']['ServerDefault'] = 1;
 
-        $this->assertEquals(
+        self::assertSame(
             '<a href="./url.php?url=https%3A%2F%2Fdocs.phpmyadmin.net%2Fen'
             . '%2Flatest%2Fpage.html%23anchor" target="documentation"><img src="themes/dot.gif"'
             . ' title="Documentation" alt="Documentation" class="icon ic_b_help"></a>',
