@@ -27,14 +27,11 @@ class NodeEventContainerTest extends AbstractTestCase
     public function testConstructor(): void
     {
         $parent = NodeFactory::getInstance('NodeEventContainer');
-        $this->assertIsArray($parent->links);
-        $this->assertEquals(
-            [
-                'text' => ['route' => '/database/events', 'params' => ['db' => null]],
-                'icon' => ['route' => '/database/events', 'params' => ['db' => null]],
-            ],
-            $parent->links
-        );
-        $this->assertEquals('events', $parent->realName);
+        self::assertIsArray($parent->links);
+        self::assertSame([
+            'text' => ['route' => '/database/events', 'params' => ['db' => null]],
+            'icon' => ['route' => '/database/events', 'params' => ['db' => null]],
+        ], $parent->links);
+        self::assertSame('events', $parent->realName);
     }
 }
