@@ -27,19 +27,16 @@ class NodeEventTest extends AbstractTestCase
     public function testConstructor(): void
     {
         $parent = NodeFactory::getInstance('NodeEvent');
-        $this->assertIsArray($parent->links);
-        $this->assertEquals(
-            [
-                'text' => [
-                    'route' => '/database/events',
-                    'params' => ['edit_item' => 1, 'db' => null, 'item_name' => null],
-                ],
-                'icon' => [
-                    'route' => '/database/events',
-                    'params' => ['export_item' => 1, 'db' => null, 'item_name' => null],
-                ],
+        self::assertIsArray($parent->links);
+        self::assertSame([
+            'text' => [
+                'route' => '/database/events',
+                'params' => ['edit_item' => 1, 'db' => null, 'item_name' => null],
             ],
-            $parent->links
-        );
+            'icon' => [
+                'route' => '/database/events',
+                'params' => ['export_item' => 1, 'db' => null, 'item_name' => null],
+            ],
+        ], $parent->links);
     }
 }
