@@ -31,15 +31,12 @@ class NodeViewContainerTest extends AbstractTestCase
     public function testConstructor(): void
     {
         $parent = NodeFactory::getInstance('NodeViewContainer');
-        $this->assertIsArray($parent->links);
-        $this->assertEquals(
-            [
-                'text' => ['route' => '/database/structure', 'params' => ['tbl_type' => 'view', 'db' => null]],
-                'icon' => ['route' => '/database/structure', 'params' => ['tbl_type' => 'view', 'db' => null]],
-            ],
-            $parent->links
-        );
-        $this->assertEquals('views', $parent->realName);
-        $this->assertStringContainsString('viewContainer', $parent->classes);
+        self::assertIsArray($parent->links);
+        self::assertSame([
+            'text' => ['route' => '/database/structure', 'params' => ['tbl_type' => 'view', 'db' => null]],
+            'icon' => ['route' => '/database/structure', 'params' => ['tbl_type' => 'view', 'db' => null]],
+        ], $parent->links);
+        self::assertSame('views', $parent->realName);
+        self::assertStringContainsString('viewContainer', $parent->classes);
     }
 }
