@@ -25,33 +25,33 @@ class OpenDocumentTest extends AbstractTestCase
             'application/vnd.oasis.opendocument.text',
             '<data>'
         );
-        $this->assertNotFalse($document);
+        self::assertNotFalse($document);
 
         $tmpFile = tempnam('./', 'open-document-test');
-        $this->assertNotFalse($tmpFile);
-        $this->assertNotFalse(file_put_contents($tmpFile, $document), 'The temp file should be written');
+        self::assertNotFalse($tmpFile);
+        self::assertNotFalse(file_put_contents($tmpFile, $document), 'The temp file should be written');
 
         $zipExtension = new ZipExtension(new ZipArchive());
-        $this->assertSame([
+        self::assertSame([
             'error' => '',
             'data' => 'application/vnd.oasis.opendocument.text',
         ], $zipExtension->getContents($tmpFile));
 
-        $this->assertSame([
+        self::assertSame([
             'error' => '',
             'data' => '<data>',
         ], $zipExtension->getContents($tmpFile, '/content\.xml/'));
 
         $dateTimeCreation = (new DateTime())->format('Y-m-d\TH:i');
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             // Do not use a full version or seconds could be out of sync and cause flaky test failures
             '<meta:creation-date>' . $dateTimeCreation,
             $zipExtension->getContents($tmpFile, '/meta\.xml/')['data']
         );
 
-        $this->assertSame(5, $zipExtension->getNumberOfFiles($tmpFile));
+        self::assertSame(5, $zipExtension->getNumberOfFiles($tmpFile));
         // Unset to close any file that were left open.
         unset($zipExtension);
-        $this->assertTrue(unlink($tmpFile));
+        self::assertTrue(unlink($tmpFile));
     }
 }
