@@ -49,9 +49,7 @@ class AuthenticationConfigTest extends AbstractTestCase
 
     public function testAuth(): void
     {
-        $this->assertTrue(
-            $this->object->showLoginForm()
-        );
+        self::assertTrue($this->object->showLoginForm());
     }
 
     public function testAuthCheck(): void
@@ -60,23 +58,18 @@ class AuthenticationConfigTest extends AbstractTestCase
             'user' => 'username',
             'password' => 'password',
         ];
-        $this->assertTrue(
-            $this->object->readCredentials()
-        );
+        self::assertTrue($this->object->readCredentials());
     }
 
     public function testAuthSetUser(): void
     {
-        $this->assertTrue(
-            $this->object->storeCredentials()
-        );
+        self::assertTrue($this->object->storeCredentials());
     }
 
     public function testAuthFails(): void
     {
         $GLOBALS['errorHandler'] = new ErrorHandler();
         $GLOBALS['cfg']['Servers'] = [1];
-        $GLOBALS['allowDeny_forbidden'] = false;
 
         $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
@@ -87,29 +80,20 @@ class AuthenticationConfigTest extends AbstractTestCase
         $this->object->showFailure('');
         $html = ob_get_clean();
 
-        $this->assertIsString($html);
+        self::assertIsString($html);
 
-        $this->assertStringContainsString(
-            'You probably did not create a configuration file. You might want ' .
-            'to use the <a href="setup/">setup script</a> to create one.',
-            $html
-        );
+        self::assertStringContainsString('You probably did not create a configuration file. You might want ' .
+        'to use the <a href="setup/">setup script</a> to create one.', $html);
 
-        $this->assertStringContainsString(
-            '<strong>MySQL said: </strong><a href="./url.php?url=https%3A%2F%2F' .
-            'dev.mysql.com%2Fdoc%2Frefman%2F5.5%2Fen%2Fserver-error-reference.html"' .
-            ' target="mysql_doc">' .
-            '<img src="themes/dot.gif" title="Documentation" alt="Documentation" ' .
-            'class="icon ic_b_help"></a>',
-            $html
-        );
+        self::assertStringContainsString('<strong>MySQL said: </strong><a href="./url.php?url=https%3A%2F%2F' .
+        'dev.mysql.com%2Fdoc%2Frefman%2F5.5%2Fen%2Fserver-error-reference.html"' .
+        ' target="mysql_doc">' .
+        '<img src="themes/dot.gif" title="Documentation" alt="Documentation" ' .
+        'class="icon ic_b_help"></a>', $html);
 
-        $this->assertStringContainsString('Cannot connect: invalid settings.', $html);
+        self::assertStringContainsString('Cannot connect: invalid settings.', $html);
 
-        $this->assertStringContainsString(
-            '<a href="index.php?route=/&server=0&lang=en" '
-            . 'class="btn btn-primary mt-1 mb-1 disableAjax">Retry to connect</a>',
-            $html
-        );
+        self::assertStringContainsString('<a href="index.php?route=/&server=0&lang=en" '
+        . 'class="btn btn-primary mt-1 mb-1 disableAjax">Retry to connect</a>', $html);
     }
 }
