@@ -26,6 +26,7 @@ use function str_repeat;
 use function str_shuffle;
 use function time;
 
+use const PHP_VERSION_ID;
 use const SODIUM_CRYPTO_SECRETBOX_KEYBYTES;
 
 /**
@@ -85,9 +86,7 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
             ->with('redirect_flag', '1');
 
         $GLOBALS['conn_error'] = true;
-        $this->assertTrue(
-            $this->object->showLoginForm()
-        );
+        self::assertTrue($this->object->showLoginForm());
     }
 
     private function getAuthErrorMockResponse(): void
@@ -202,45 +201,36 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $this->object->showLoginForm();
         $result = ob_get_clean();
 
-        $this->assertIsString($result);
+        self::assertIsString($result);
 
-        $this->assertStringContainsString(' id="imLogo"', $result);
+        self::assertStringContainsString(' id="imLogo"', $result);
 
-        $this->assertStringContainsString('<div class="alert alert-danger" role="alert">', $result);
+        self::assertStringContainsString('<div class="alert alert-danger" role="alert">', $result);
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<form method="post" id="login_form" action="index.php?route=/" name="login_form" ' .
             'class="disableAjax hide js-show">',
             $result
         );
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<input type="text" name="pma_servername" id="serverNameInput" value="localhost"',
             $result
         );
 
-        $this->assertStringContainsString(
-            '<input type="text" name="pma_username" id="input_username" ' .
-            'value="pmauser" class="form-control" autocomplete="username" spellcheck="false">',
-            $result
-        );
+        self::assertStringContainsString('<input type="text" name="pma_username" id="input_username" ' .
+        'value="pmauser" class="form-control" autocomplete="username" spellcheck="false">', $result);
 
-        $this->assertStringContainsString(
-            '<input type="password" name="pma_password" id="input_password" ' .
-            'value="" class="form-control" autocomplete="current-password" spellcheck="false">',
-            $result
-        );
+        self::assertStringContainsString('<input type="password" name="pma_password" id="input_password" ' .
+        'value="" class="form-control" autocomplete="current-password" spellcheck="false">', $result);
 
-        $this->assertStringContainsString(
-            '<select name="server" id="select_server" class="form-select" ' .
-            'onchange="document.forms[\'login_form\'].' .
-            'elements[\'pma_servername\'].value = \'\'">',
-            $result
-        );
+        self::assertStringContainsString('<select name="server" id="select_server" class="form-select" ' .
+        'onchange="document.forms[\'login_form\'].' .
+        'elements[\'pma_servername\'].value = \'\'">', $result);
 
-        $this->assertStringContainsString('<input type="hidden" name="db" value="testDb">', $result);
+        self::assertStringContainsString('<input type="hidden" name="db" value="testDb">', $result);
 
-        $this->assertStringContainsString('<input type="hidden" name="table" value="testTable">', $result);
+        self::assertStringContainsString('<input type="hidden" name="table" value="testTable">', $result);
     }
 
     /**
@@ -284,38 +274,32 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $this->object->showLoginForm();
         $result = ob_get_clean();
 
-        $this->assertIsString($result);
+        self::assertIsString($result);
 
-        $this->assertStringContainsString('id="imLogo"', $result);
+        self::assertStringContainsString('id="imLogo"', $result);
 
         // Check for language selection if locales are there
         $loc = LOCALE_PATH . '/cs/LC_MESSAGES/phpmyadmin.mo';
         if (is_readable($loc)) {
-            $this->assertStringContainsString(
-                '<select name="lang" class="form-select autosubmit" lang="en" dir="ltr"'
-                . ' id="languageSelect" aria-labelledby="languageSelectLabel">',
-                $result
-            );
+            self::assertStringContainsString('<select name="lang" class="form-select autosubmit" lang="en" dir="ltr"'
+            . ' id="languageSelect" aria-labelledby="languageSelectLabel">', $result);
         }
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<form method="post" id="login_form" action="index.php?route=/" name="login_form"' .
             ' class="disableAjax hide js-show" autocomplete="off">',
             $result
         );
 
-        $this->assertStringContainsString('<input type="hidden" name="server" value="0">', $result);
+        self::assertStringContainsString('<input type="hidden" name="server" value="0">', $result);
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<script src="https://www.google.com/recaptcha/api.js?hl=en" async defer></script>',
             $result
         );
 
-        $this->assertStringContainsString(
-            '<input class="btn btn-primary g-recaptcha" data-sitekey="testpubkey"'
-            . ' data-callback="Functions_recaptchaCallback" value="Log in" type="submit" id="input_go">',
-            $result
-        );
+        self::assertStringContainsString('<input class="btn btn-primary g-recaptcha" data-sitekey="testpubkey"'
+        . ' data-callback="Functions_recaptchaCallback" value="Log in" type="submit" id="input_go">', $result);
     }
 
     /**
@@ -360,36 +344,33 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $this->object->showLoginForm();
         $result = ob_get_clean();
 
-        $this->assertIsString($result);
+        self::assertIsString($result);
 
-        $this->assertStringContainsString('id="imLogo"', $result);
+        self::assertStringContainsString('id="imLogo"', $result);
 
         // Check for language selection if locales are there
         $loc = LOCALE_PATH . '/cs/LC_MESSAGES/phpmyadmin.mo';
         if (is_readable($loc)) {
-            $this->assertStringContainsString(
-                '<select name="lang" class="form-select autosubmit" lang="en" dir="ltr"'
-                . ' id="languageSelect" aria-labelledby="languageSelectLabel">',
-                $result
-            );
+            self::assertStringContainsString('<select name="lang" class="form-select autosubmit" lang="en" dir="ltr"'
+            . ' id="languageSelect" aria-labelledby="languageSelectLabel">', $result);
         }
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<form method="post" id="login_form" action="index.php?route=/" name="login_form"' .
             ' class="disableAjax hide js-show" autocomplete="off">',
             $result
         );
 
-        $this->assertStringContainsString('<input type="hidden" name="server" value="0">', $result);
+        self::assertStringContainsString('<input type="hidden" name="server" value="0">', $result);
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<script src="https://www.google.com/recaptcha/api.js?hl=en" async defer></script>',
             $result
         );
 
-        $this->assertStringContainsString('<div class="g-recaptcha" data-sitekey="testpubkey"></div>', $result);
+        self::assertStringContainsString('<div class="g-recaptcha" data-sitekey="testpubkey"></div>', $result);
 
-        $this->assertStringContainsString(
+        self::assertStringContainsString(
             '<input class="btn btn-primary" value="Log in" type="submit" id="input_go">',
             $result
         );
@@ -437,11 +418,9 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $_POST['g-recaptcha-response'] = '';
         $_POST['pma_username'] = 'testPMAUser';
 
-        $this->assertFalse(
-            $this->object->readCredentials()
-        );
+        self::assertFalse($this->object->readCredentials());
 
-        $this->assertEquals(
+        self::assertSame(
             'Missing reCAPTCHA verification, maybe it has been blocked by adblock?',
             $GLOBALS['conn_error']
         );
@@ -465,7 +444,7 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
 
         $this->object->logOut();
 
-        $this->assertArrayNotHasKey('pmaAuth-0', $_COOKIE);
+        self::assertArrayNotHasKey('pmaAuth-0', $_COOKIE);
     }
 
     public function testLogout(): void
@@ -488,7 +467,7 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
 
         $this->object->logOut();
 
-        $this->assertArrayNotHasKey('pmaAuth-1', $_COOKIE);
+        self::assertArrayNotHasKey('pmaAuth-1', $_COOKIE);
     }
 
     public function testAuthCheckArbitrary(): void
@@ -504,17 +483,15 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $_POST['pma_password'] = 'testPMAPSWD';
         $GLOBALS['cfg']['AllowArbitraryServer'] = true;
 
-        $this->assertTrue(
-            $this->object->readCredentials()
-        );
+        self::assertTrue($this->object->readCredentials());
 
-        $this->assertEquals('testPMAUser', $this->object->user);
+        self::assertSame('testPMAUser', $this->object->user);
 
-        $this->assertEquals('testPMAPSWD', $this->object->password);
+        self::assertSame('testPMAPSWD', $this->object->password);
 
-        $this->assertEquals('testPMAServer', $GLOBALS['pma_auth_server']);
+        self::assertSame('testPMAServer', $GLOBALS['pma_auth_server']);
 
-        $this->assertArrayNotHasKey('pmaAuth-1', $_COOKIE);
+        self::assertArrayNotHasKey('pmaAuth-1', $_COOKIE);
     }
 
     public function testAuthCheckInvalidCookie(): void
@@ -527,9 +504,7 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $_COOKIE['pmaUser-1'] = '';
         $_COOKIE['pma_iv-1'] = base64_encode('testiv09testiv09');
 
-        $this->assertFalse(
-            $this->object->readCredentials()
-        );
+        self::assertFalse($this->object->readCredentials());
     }
 
     public function testAuthCheckExpires(): void
@@ -543,9 +518,7 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $_SESSION['last_access_time'] = time() - 1000;
         $GLOBALS['cfg']['LoginCookieValidity'] = 1440;
 
-        $this->assertFalse(
-            $this->object->readCredentials()
-        );
+        self::assertFalse($this->object->readCredentials());
     }
 
     public function testAuthCheckDecryptUser(): void
@@ -575,11 +548,9 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
             ->method('cookieDecrypt')
             ->will($this->returnValue('testBF'));
 
-        $this->assertFalse(
-            $this->object->readCredentials()
-        );
+        self::assertFalse($this->object->readCredentials());
 
-        $this->assertEquals('testBF', $this->object->user);
+        self::assertSame('testBF', $this->object->user);
     }
 
     public function testAuthCheckDecryptPassword(): void
@@ -611,13 +582,11 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
             ->method('cookieDecrypt')
             ->will($this->returnValue('{"password":""}'));
 
-        $this->assertTrue(
-            $this->object->readCredentials()
-        );
+        self::assertTrue($this->object->readCredentials());
 
-        $this->assertTrue($GLOBALS['from_cookie']);
+        self::assertTrue($GLOBALS['from_cookie']);
 
-        $this->assertEquals('', $this->object->password);
+        self::assertSame('', $this->object->password);
     }
 
     public function testAuthCheckAuthFails(): void
@@ -652,9 +621,7 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $this->object->expects($this->once())
             ->method('showFailure');
 
-        $this->assertFalse(
-            $this->object->readCredentials()
-        );
+        self::assertFalse($this->object->readCredentials());
     }
 
     public function testAuthSetUser(): void
@@ -683,14 +650,14 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
 
         $this->object->rememberCredentials();
 
-        $this->assertArrayHasKey('pmaUser-2', $_COOKIE);
+        self::assertArrayHasKey('pmaUser-2', $_COOKIE);
 
-        $this->assertArrayHasKey('pmaAuth-2', $_COOKIE);
+        self::assertArrayHasKey('pmaAuth-2', $_COOKIE);
 
         $arr['password'] = 'testPW';
         $arr['host'] = 'b';
         $arr['port'] = '2';
-        $this->assertEquals($arr, $GLOBALS['cfg']['Server']);
+        self::assertSame($arr, $GLOBALS['cfg']['Server']);
     }
 
     public function testAuthSetUserWithHeaders(): void
@@ -723,6 +690,9 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $this->object->rememberCredentials();
     }
 
+    /**
+     * @requires PHPUnit < 10
+     */
     public function testAuthFailsNoPass(): void
     {
         $this->object = $this->getMockBuilder(AuthenticationCookie::class)
@@ -739,32 +709,26 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         );
         $this->object->showFailure('empty-denied');
 
-        $this->assertEquals(
-            $GLOBALS['conn_error'],
-            'Login without a password is forbidden by configuration (see AllowNoPassword)'
+        self::assertSame(
+            'Login without a password is forbidden by configuration (see AllowNoPassword)',
+            $GLOBALS['conn_error']
         );
     }
 
-    public function dataProviderPasswordLength(): array
+    public static function dataProviderPasswordLength(): array
     {
         return [
             [
-                str_repeat('a', 1000),
+                str_repeat('a', 2001),
                 false,
                 'Your password is too long. To prevent denial-of-service attacks,'
-                . ' phpMyAdmin restricts passwords to less than 1000 characters.',
-            ],
-            [
-                str_repeat('a', 1001),
-                false,
-                'Your password is too long. To prevent denial-of-service attacks,'
-                . ' phpMyAdmin restricts passwords to less than 1000 characters.',
+                . ' phpMyAdmin restricts passwords to less than 2000 characters.',
             ],
             [
                 str_repeat('a', 3000),
                 false,
                 'Your password is too long. To prevent denial-of-service attacks,'
-                . ' phpMyAdmin restricts passwords to less than 1000 characters.',
+                . ' phpMyAdmin restricts passwords to less than 2000 characters.',
             ],
             [
                 str_repeat('a', 256),
@@ -788,18 +752,17 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $_POST['pma_password'] = $password;
 
         if ($trueFalse === false) {
-            $this->assertFalse(
-                $this->object->readCredentials()
-            );
+            self::assertFalse($this->object->readCredentials());
         } else {
-            $this->assertTrue(
-                $this->object->readCredentials()
-            );
+            self::assertTrue($this->object->readCredentials());
         }
 
-        $this->assertEquals($GLOBALS['conn_error'], $connError);
+        self::assertSame($GLOBALS['conn_error'], $connError);
     }
 
+    /**
+     * @requires PHPUnit < 10
+     */
     public function testAuthFailsDeny(): void
     {
         $this->object = $this->getMockBuilder(AuthenticationCookie::class)
@@ -816,9 +779,12 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         );
         $this->object->showFailure('allow-denied');
 
-        $this->assertEquals($GLOBALS['conn_error'], 'Access denied!');
+        self::assertSame($GLOBALS['conn_error'], 'Access denied!');
     }
 
+    /**
+     * @requires PHPUnit < 10
+     */
     public function testAuthFailsActivity(): void
     {
         $this->object = $this->getMockBuilder(AuthenticationCookie::class)
@@ -829,7 +795,6 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $GLOBALS['server'] = 2;
         $_COOKIE['pmaAuth-2'] = 'pass';
 
-        $GLOBALS['allowDeny_forbidden'] = '';
         $GLOBALS['cfg']['LoginCookieValidity'] = 10;
 
         $this->mockResponse(
@@ -838,13 +803,16 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         );
         $this->object->showFailure('no-activity');
 
-        $this->assertEquals(
-            $GLOBALS['conn_error'],
+        self::assertSame(
             'You have been automatically logged out due to inactivity of 10 seconds.'
-            . ' Once you log in again, you should be able to resume the work where you left off.'
+            . ' Once you log in again, you should be able to resume the work where you left off.',
+            $GLOBALS['conn_error']
         );
     }
 
+    /**
+     * @requires PHPUnit < 10
+     */
     public function testAuthFailsDBI(): void
     {
         $this->object = $this->getMockBuilder(AuthenticationCookie::class)
@@ -872,9 +840,12 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         );
         $this->object->showFailure('');
 
-        $this->assertEquals($GLOBALS['conn_error'], '#42 Cannot log in to the MySQL server');
+        self::assertSame($GLOBALS['conn_error'], '#42 Cannot log in to the MySQL server');
     }
 
+    /**
+     * @requires PHPUnit < 10
+     */
     public function testAuthFailsErrno(): void
     {
         $this->object = $this->getMockBuilder(AuthenticationCookie::class)
@@ -902,27 +873,31 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         );
         $this->object->showFailure('');
 
-        $this->assertEquals($GLOBALS['conn_error'], 'Cannot log in to the MySQL server');
+        self::assertSame($GLOBALS['conn_error'], 'Cannot log in to the MySQL server');
     }
 
     public function testGetEncryptionSecretEmpty(): void
     {
         $method = new ReflectionMethod(AuthenticationCookie::class, 'getEncryptionSecret');
-        $method->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $method->setAccessible(true);
+        }
 
         $GLOBALS['cfg']['blowfish_secret'] = '';
         $_SESSION['encryption_key'] = '';
 
         $result = $method->invoke($this->object, null);
 
-        $this->assertSame($result, $_SESSION['encryption_key']);
-        $this->assertSame(SODIUM_CRYPTO_SECRETBOX_KEYBYTES, mb_strlen($result, '8bit'));
+        self::assertSame($result, $_SESSION['encryption_key']);
+        self::assertSame(SODIUM_CRYPTO_SECRETBOX_KEYBYTES, mb_strlen($result, '8bit'));
     }
 
     public function testGetEncryptionSecretConfigured(): void
     {
         $method = new ReflectionMethod(AuthenticationCookie::class, 'getEncryptionSecret');
-        $method->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $method->setAccessible(true);
+        }
 
         $key = str_repeat('a', SODIUM_CRYPTO_SECRETBOX_KEYBYTES);
         $GLOBALS['cfg']['blowfish_secret'] = $key;
@@ -930,13 +905,15 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
 
         $result = $method->invoke($this->object, null);
 
-        $this->assertSame($key, $result);
+        self::assertSame($key, $result);
     }
 
     public function testGetSessionEncryptionSecretConfigured(): void
     {
         $method = new ReflectionMethod(AuthenticationCookie::class, 'getEncryptionSecret');
-        $method->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $method->setAccessible(true);
+        }
 
         $key = str_repeat('a', SODIUM_CRYPTO_SECRETBOX_KEYBYTES);
         $GLOBALS['cfg']['blowfish_secret'] = 'blowfish_secret';
@@ -944,28 +921,28 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
 
         $result = $method->invoke($this->object, null);
 
-        $this->assertSame($key, $result);
+        self::assertSame($key, $result);
     }
 
     public function testCookieEncryption(): void
     {
         $key = random_bytes(SODIUM_CRYPTO_SECRETBOX_KEYBYTES);
         $encrypted = $this->object->cookieEncrypt('data123', $key);
-        $this->assertNotFalse(base64_decode($encrypted, true));
-        $this->assertSame('data123', $this->object->cookieDecrypt($encrypted, $key));
+        self::assertNotFalse(base64_decode($encrypted, true));
+        self::assertSame('data123', $this->object->cookieDecrypt($encrypted, $key));
     }
 
     public function testCookieDecryptInvalid(): void
     {
-        $this->assertNull($this->object->cookieDecrypt('', ''));
+        self::assertNull($this->object->cookieDecrypt('', ''));
 
         $key = random_bytes(SODIUM_CRYPTO_SECRETBOX_KEYBYTES);
         $encrypted = $this->object->cookieEncrypt('data123', $key);
-        $this->assertSame('data123', $this->object->cookieDecrypt($encrypted, $key));
+        self::assertSame('data123', $this->object->cookieDecrypt($encrypted, $key));
 
-        $this->assertNull($this->object->cookieDecrypt('', $key));
-        $this->assertNull($this->object->cookieDecrypt($encrypted, ''));
-        $this->assertNull($this->object->cookieDecrypt($encrypted, random_bytes(SODIUM_CRYPTO_SECRETBOX_KEYBYTES)));
+        self::assertNull($this->object->cookieDecrypt('', $key));
+        self::assertNull($this->object->cookieDecrypt($encrypted, ''));
+        self::assertNull($this->object->cookieDecrypt($encrypted, random_bytes(SODIUM_CRYPTO_SECRETBOX_KEYBYTES)));
     }
 
     /**
@@ -984,12 +961,12 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
 
         $payload = ['password' => $newPassword, 'server' => 'b 2'];
 
-        $this->assertIsString($_COOKIE['pmaAuth-' . $GLOBALS['server']]);
+        self::assertIsString($_COOKIE['pmaAuth-' . $GLOBALS['server']]);
         $decryptedCookie = $this->object->cookieDecrypt(
             $_COOKIE['pmaAuth-' . $GLOBALS['server']],
             $_SESSION['encryption_key']
         );
-        $this->assertSame(json_encode($payload), $decryptedCookie);
+        self::assertSame(json_encode($payload), $decryptedCookie);
     }
 
     public function testAuthenticate(): void
@@ -1010,15 +987,15 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $result = ob_get_clean();
 
         /* Nothing should be printed */
-        $this->assertEquals('', $result);
+        self::assertSame('', $result);
 
         /* Verify readCredentials worked */
-        $this->assertEquals('testUser', $this->object->user);
-        $this->assertEquals('testPassword', $this->object->password);
+        self::assertSame('testUser', $this->object->user);
+        self::assertSame('testPassword', $this->object->password);
 
         /* Verify storeCredentials worked */
-        $this->assertEquals('testUser', $GLOBALS['cfg']['Server']['user']);
-        $this->assertEquals('testPassword', $GLOBALS['cfg']['Server']['password']);
+        self::assertSame('testUser', $GLOBALS['cfg']['Server']['user']);
+        self::assertSame('testPassword', $GLOBALS['cfg']['Server']['password']);
     }
 
     /**
@@ -1059,16 +1036,16 @@ class AuthenticationCookieTest extends AbstractNetworkTestCase
         $this->object->checkRules();
         $result = ob_get_clean();
 
-        $this->assertIsString($result);
+        self::assertIsString($result);
 
         if (empty($expected)) {
-            $this->assertEquals($expected, $result);
+            self::assertSame($expected, $result);
         } else {
-            $this->assertStringContainsString($expected, $result);
+            self::assertStringContainsString($expected, $result);
         }
     }
 
-    public function checkRulesProvider(): array
+    public static function checkRulesProvider(): array
     {
         return [
             'nopass-ok' => [
