@@ -22,103 +22,70 @@ class PropertyItemsTest extends AbstractTestCase
     {
         $object = new BoolPropertyItem(null, 'Text');
 
-        $this->assertEquals(
-            'Text',
-            $object->getText()
-        );
+        self::assertSame('Text', $object->getText());
 
         $object->setText('xtext2');
 
-        $this->assertEquals(
-            'xtext2',
-            $object->getText()
-        );
+        self::assertSame('xtext2', $object->getText());
     }
 
     public function testBoolName(): void
     {
         $object = new BoolPropertyItem('xname');
 
-        $this->assertEquals(
-            'xname',
-            $object->getName()
-        );
+        self::assertSame('xname', $object->getName());
 
         $object->setName('xname2');
 
-        $this->assertEquals(
-            'xname2',
-            $object->getName()
-        );
+        self::assertSame('xname2', $object->getName());
     }
 
     public function testBoolGetItemType(): void
     {
         $object = new BoolPropertyItem();
 
-        $this->assertEquals(
-            'bool',
-            $object->getItemType()
-        );
+        self::assertSame('bool', $object->getItemType());
     }
 
     public function testGetItemTypeDoc(): void
     {
         $object = new DocPropertyItem();
 
-        $this->assertEquals(
-            'doc',
-            $object->getItemType()
-        );
+        self::assertSame('doc', $object->getItemType());
     }
 
     public function testGetItemTypeHidden(): void
     {
         $object = new HiddenPropertyItem();
 
-        $this->assertEquals(
-            'hidden',
-            $object->getItemType()
-        );
+        self::assertSame('hidden', $object->getItemType());
     }
 
     public function testGetItemTypeMessageOnly(): void
     {
         $object = new MessageOnlyPropertyItem();
 
-        $this->assertEquals(
-            'messageOnly',
-            $object->getItemType()
-        );
+        self::assertSame('messageOnly', $object->getItemType());
     }
 
     public function testGetItemTypeRadio(): void
     {
         $object = new RadioPropertyItem();
 
-        $this->assertEquals(
-            'radio',
-            $object->getItemType()
-        );
+        self::assertSame('radio', $object->getItemType());
     }
 
     public function testGetItemTypeSelect(): void
     {
         $object = new SelectPropertyItem();
 
-        $this->assertEquals(
-            'select',
-            $object->getItemType()
-        );
+        self::assertSame('select', $object->getItemType());
     }
 
     public function testGetItemTypeText(): void
     {
         $object = new TextPropertyItem();
 
-        $this->assertEquals(
-            'text',
-            $object->getItemType()
-        );
+        self::assertSame('text', $object->getItemType());
     }
 }
