@@ -9,6 +9,8 @@ use PhpMyAdmin\Tests\AbstractTestCase;
 use PHPUnit\Framework\MockObject\MockObject;
 use ReflectionProperty;
 
+use const PHP_VERSION_ID;
+
 /**
  * @covers \PhpMyAdmin\Properties\Options\OptionsPropertyGroup
  */
@@ -38,75 +40,70 @@ class OptionsPropertyGroupTest extends AbstractTestCase
     public function testAddProperty(): void
     {
         $properties = new ReflectionProperty(OptionsPropertyGroup::class, 'properties');
-        $properties->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $properties->setAccessible(true);
+        }
 
         $properties->setValue($this->stub, [1, 2, 3]);
 
         $this->stub->addProperty(2);
         $this->stub->addProperty('2');
 
-        $this->assertEquals(
-            [
-                1,
-                2,
-                3,
-                '2',
-            ],
-            $properties->getValue($this->stub)
-        );
+        self::assertSame([
+            1,
+            2,
+            3,
+            '2',
+        ], $properties->getValue($this->stub));
     }
 
     public function testRemoveProperty(): void
     {
         $properties = new ReflectionProperty(OptionsPropertyGroup::class, 'properties');
-        $properties->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $properties->setAccessible(true);
+        }
 
         $properties->setValue($this->stub, [1, 2, 'test', 3]);
         $this->stub->removeProperty('test');
 
-        $this->assertEquals(
-            [
-                0 => 1,
-                1 => 2,
-                3 => 3,
-            ],
-            $properties->getValue($this->stub)
-        );
+        self::assertSame([
+            0 => 1,
+            1 => 2,
+            3 => 3,
+        ], $properties->getValue($this->stub));
     }
 
     public function testGetGroup(): void
     {
-        $this->assertInstanceOf(
-            OptionsPropertyGroup::class,
-            $this->stub->getGroup()
-        );
+        self::assertInstanceOf(OptionsPropertyGroup::class, $this->stub->getGroup());
     }
 
     public function testGetProperties(): void
     {
         $properties = new ReflectionProperty(OptionsPropertyGroup::class, 'properties');
-        $properties->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $properties->setAccessible(true);
+        }
+
         $properties->setValue($this->stub, [1, 2, 3]);
 
-        $this->assertEquals(
-            [
-                1,
-                2,
-                3,
-            ],
-            $this->stub->getProperties()
-        );
+        self::assertSame([
+            1,
+            2,
+            3,
+        ], $this->stub->getProperties());
     }
 
     public function testGetNrOfProperties(): void
     {
         $properties = new ReflectionProperty(OptionsPropertyGroup::class, 'properties');
-        $properties->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $properties->setAccessible(true);
+        }
+
         $properties->setValue($this->stub, [1, 2, 3]);
 
-        $this->assertEquals(
-            3,
-            $this->stub->getNrOfProperties()
-        );
+        self::assertSame(3, $this->stub->getNrOfProperties());
     }
 }
