@@ -43,10 +43,7 @@ class OptionsPropertyItemTest extends AbstractTestCase
     {
         $this->stub->setName('name123');
 
-        $this->assertEquals(
-            'name123',
-            $this->stub->getName()
-        );
+        self::assertSame('name123', $this->stub->getName());
     }
 
     /**
@@ -58,10 +55,7 @@ class OptionsPropertyItemTest extends AbstractTestCase
     {
         $this->stub->setText('text123');
 
-        $this->assertEquals(
-            'text123',
-            $this->stub->getText()
-        );
+        self::assertSame('text123', $this->stub->getText());
     }
 
     /**
@@ -73,17 +67,11 @@ class OptionsPropertyItemTest extends AbstractTestCase
     {
         $this->stub->setForce('force123');
 
-        $this->assertEquals(
-            'force123',
-            $this->stub->getForce()
-        );
+        self::assertSame('force123', $this->stub->getForce());
     }
 
     public function testGetPropertyType(): void
     {
-        $this->assertEquals(
-            'options',
-            $this->stub->getPropertyType()
-        );
+        self::assertSame('options', $this->stub->getPropertyType());
     }
 }
