@@ -10,6 +10,8 @@ use ReflectionProperty;
 
 use function rawurlencode;
 
+use const PHP_VERSION_ID;
+
 /**
  * @covers \PhpMyAdmin\Scripts
  */
@@ -47,12 +49,9 @@ class ScriptsTest extends AbstractTestCase
 
         $actual = $this->object->getDisplay();
 
-        $this->assertStringContainsString(
-            'src="js/dist/common.js?v=' . rawurlencode(Version::VERSION) . '"',
-            $actual
-        );
-        $this->assertStringContainsString('.add(\'common.js\', 1)', $actual);
-        $this->assertStringContainsString('AJAX.fireOnload(\'common.js\')', $actual);
+        self::assertStringContainsString('src="js/dist/common.js?v=' . rawurlencode(Version::VERSION) . '"', $actual);
+        self::assertStringContainsString('.add(\'common.js\', 1)', $actual);
+        self::assertStringContainsString('AJAX.fireOnload(\'common.js\')', $actual);
     }
 
     /**
@@ -64,7 +63,7 @@ class ScriptsTest extends AbstractTestCase
 
         $actual = $this->object->getDisplay();
 
-        $this->assertStringContainsString('alert(\'CodeAdded\');', $actual);
+        self::assertStringContainsString('alert(\'CodeAdded\');', $actual);
     }
 
     /**
@@ -76,19 +75,16 @@ class ScriptsTest extends AbstractTestCase
         $this->object->addFile('vendor/codemirror/lib/codemirror.js');
 
         $this->object->addFile('common.js');
-        $this->assertEquals(
+        self::assertSame([
             [
-                [
-                    'name' => 'vendor/codemirror/lib/codemirror.js',
-                    'fire' => 0,
-                ],
-                [
-                    'name' => 'common.js',
-                    'fire' => 1,
-                ],
+                'name' => 'vendor/codemirror/lib/codemirror.js',
+                'fire' => 0,
             ],
-            $this->object->getFiles()
-        );
+            [
+                'name' => 'common.js',
+                'fire' => 1,
+            ],
+        ], $this->object->getFiles());
     }
 
     /**
@@ -97,11 +93,13 @@ class ScriptsTest extends AbstractTestCase
     public function testAddFile(): void
     {
         $reflection = new ReflectionProperty(Scripts::class, 'files');
-        $reflection->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $reflection->setAccessible(true);
+        }
 
         // Assert empty _files property of
         // Scripts
-        $this->assertEquals([], $reflection->getValue($this->object));
+        self::assertSame([], $reflection->getValue($this->object));
 
         // Add one script file
         $file = 'common.js';
@@ -114,7 +112,7 @@ class ScriptsTest extends AbstractTestCase
             ],
         ];
         $this->object->addFile($file);
-        $this->assertEquals($_files, $reflection->getValue($this->object));
+        self::assertSame($_files, $reflection->getValue($this->object));
     }
 
     /**
@@ -123,7 +121,9 @@ class ScriptsTest extends AbstractTestCase
     public function testAddFiles(): void
     {
         $reflection = new ReflectionProperty(Scripts::class, 'files');
-        $reflection->setAccessible(true);
+        if (PHP_VERSION_ID < 80100) {
+            $reflection->setAccessible(true);
+        }
 
         $filenames = [
             'common.js',
@@ -143,6 +143,6 @@ class ScriptsTest extends AbstractTestCase
             ],
         ];
         $this->object->addFiles($filenames);
-        $this->assertEquals($_files, $reflection->getValue($this->object));
+        self::assertSame($_files, $reflection->getValue($this->object));
     }
 }
