@@ -12,11 +12,13 @@ use PhpMyAdmin\ParseAnalyze;
 use PhpMyAdmin\Sql;
 use PhpMyAdmin\Template;
 use PhpMyAdmin\Transformations;
+use ReflectionMethod;
 use stdClass;
 
 use const MYSQLI_TYPE_SHORT;
 use const MYSQLI_TYPE_TIMESTAMP;
 use const MYSQLI_TYPE_VAR_STRING;
+use const PHP_VERSION_ID;
 
 /**
  * @covers \PhpMyAdmin\Sql
@@ -72,7 +74,7 @@ class SqlTest extends AbstractTestCase
         $GLOBALS['_SESSION']['tmpval']['max_rows'] = 2;
 
         $analyzed_sql_results = $this->parseAndAnalyze('SELECT * FROM test LIMIT 0, 10');
-        $this->assertEquals(
+        self::assertSame(
             'SELECT * FROM test LIMIT 1, 2 ',
             $this->callFunction($this->sql, Sql::class, 'getSqlWithLimitClause', [&$analyzed_sql_results])
         );
@@ -86,35 +88,25 @@ class SqlTest extends AbstractTestCase
         // Test environment.
         $GLOBALS['cfg']['RememberSorting'] = true;
 
-        $this->assertTrue(
-            $this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
-                $this->parseAndAnalyze('SELECT * FROM tbl'),
-            ])
-        );
+        self::assertTrue($this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
+            $this->parseAndAnalyze('SELECT * FROM tbl'),
+        ]));
 
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
-                $this->parseAndAnalyze('SELECT col FROM tbl'),
-            ])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
+            $this->parseAndAnalyze('SELECT col FROM tbl'),
+        ]));
 
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
-                $this->parseAndAnalyze('SELECT 1'),
-            ])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
+            $this->parseAndAnalyze('SELECT 1'),
+        ]));
 
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
-                $this->parseAndAnalyze('SELECT col1, col2 FROM tbl'),
-            ])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
+            $this->parseAndAnalyze('SELECT col1, col2 FROM tbl'),
+        ]));
 
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
-                $this->parseAndAnalyze('SELECT COUNT(*) from tbl'),
-            ])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'isRememberSortingOrder', [
+            $this->parseAndAnalyze('SELECT COUNT(*) from tbl'),
+        ]));
     }
 
     /**
@@ -125,17 +117,13 @@ class SqlTest extends AbstractTestCase
         // Test environment.
         $GLOBALS['_SESSION']['tmpval']['max_rows'] = 10;
 
-        $this->assertTrue(
-            $this->callFunction($this->sql, Sql::class, 'isAppendLimitClause', [
-                $this->parseAndAnalyze('SELECT * FROM tbl'),
-            ])
-        );
+        self::assertTrue($this->callFunction($this->sql, Sql::class, 'isAppendLimitClause', [
+            $this->parseAndAnalyze('SELECT * FROM tbl'),
+        ]));
 
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'isAppendLimitClause', [
-                $this->parseAndAnalyze('SELECT * from tbl LIMIT 0, 10'),
-            ])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'isAppendLimitClause', [
+            $this->parseAndAnalyze('SELECT * from tbl LIMIT 0, 10'),
+        ]));
     }
 
     public function testIsJustBrowsing(): void
@@ -143,17 +131,17 @@ class SqlTest extends AbstractTestCase
         // Test environment.
         $GLOBALS['_SESSION']['tmpval']['max_rows'] = 10;
 
-        $this->assertTrue(Sql::isJustBrowsing(
+        self::assertTrue(Sql::isJustBrowsing(
             $this->parseAndAnalyze('SELECT * FROM db.tbl'),
             null
         ));
 
-        $this->assertTrue(Sql::isJustBrowsing(
+        self::assertTrue(Sql::isJustBrowsing(
             $this->parseAndAnalyze('SELECT * FROM tbl WHERE 1'),
             null
         ));
 
-        $this->assertFalse(Sql::isJustBrowsing(
+        self::assertFalse(Sql::isJustBrowsing(
             $this->parseAndAnalyze('SELECT * from tbl1, tbl2 LIMIT 0, 10'),
             null
         ));
@@ -164,23 +152,17 @@ class SqlTest extends AbstractTestCase
      */
     public function testIsDeleteTransformationInfo(): void
     {
-        $this->assertTrue(
-            $this->callFunction($this->sql, Sql::class, 'isDeleteTransformationInfo', [
-                $this->parseAndAnalyze('ALTER TABLE tbl DROP COLUMN col'),
-            ])
-        );
+        self::assertTrue($this->callFunction($this->sql, Sql::class, 'isDeleteTransformationInfo', [
+            $this->parseAndAnalyze('ALTER TABLE tbl DROP COLUMN col'),
+        ]));
 
-        $this->assertTrue(
-            $this->callFunction($this->sql, Sql::class, 'isDeleteTransformationInfo', [
-                $this->parseAndAnalyze('DROP TABLE tbl'),
-            ])
-        );
+        self::assertTrue($this->callFunction($this->sql, Sql::class, 'isDeleteTransformationInfo', [
+            $this->parseAndAnalyze('DROP TABLE tbl'),
+        ]));
 
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'isDeleteTransformationInfo', [
-                $this->parseAndAnalyze('SELECT * from tbl'),
-            ])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'isDeleteTransformationInfo', [
+            $this->parseAndAnalyze('SELECT * from tbl'),
+        ]));
     }
 
     /**
@@ -188,29 +170,23 @@ class SqlTest extends AbstractTestCase
      */
     public function testHasNoRightsToDropDatabase(): void
     {
-        $this->assertTrue(
-            $this->sql->hasNoRightsToDropDatabase(
-                $this->parseAndAnalyze('DROP DATABASE db'),
-                false,
-                false
-            )
-        );
+        self::assertTrue($this->sql->hasNoRightsToDropDatabase(
+            $this->parseAndAnalyze('DROP DATABASE db'),
+            false,
+            false
+        ));
 
-        $this->assertFalse(
-            $this->sql->hasNoRightsToDropDatabase(
-                $this->parseAndAnalyze('DROP TABLE tbl'),
-                false,
-                false
-            )
-        );
+        self::assertFalse($this->sql->hasNoRightsToDropDatabase(
+            $this->parseAndAnalyze('DROP TABLE tbl'),
+            false,
+            false
+        ));
 
-        $this->assertFalse(
-            $this->sql->hasNoRightsToDropDatabase(
-                $this->parseAndAnalyze('SELECT * from tbl'),
-                false,
-                false
-            )
-        );
+        self::assertFalse($this->sql->hasNoRightsToDropDatabase(
+            $this->parseAndAnalyze('SELECT * from tbl'),
+            false,
+            false
+        ));
     }
 
     /**
@@ -230,9 +206,7 @@ class SqlTest extends AbstractTestCase
             $col2,
             $col3,
         ];
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta]));
 
         // should not matter on where the odd column occurs
         $fields_meta = [
@@ -240,18 +214,14 @@ class SqlTest extends AbstractTestCase
             $col3,
             $col1,
         ];
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta]));
 
         $fields_meta = [
             $col3,
             $col1,
             $col2,
         ];
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta]));
     }
 
     /**
@@ -271,9 +241,7 @@ class SqlTest extends AbstractTestCase
             $col3,
         ];
 
-        $this->assertTrue(
-            $this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta])
-        );
+        self::assertTrue($this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta]));
     }
 
     /**
@@ -294,9 +262,7 @@ class SqlTest extends AbstractTestCase
             $col2,
             $col3,
         ];
-        $this->assertTrue(
-            $this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta])
-        );
+        self::assertTrue($this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta]));
 
         // should not matter on where the function column occurs
         $fields_meta = [
@@ -304,18 +270,14 @@ class SqlTest extends AbstractTestCase
             $col3,
             $col1,
         ];
-        $this->assertTrue(
-            $this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta])
-        );
+        self::assertTrue($this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta]));
 
         $fields_meta = [
             $col3,
             $col1,
             $col2,
         ];
-        $this->assertTrue(
-            $this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta])
-        );
+        self::assertTrue($this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta]));
     }
 
     /**
@@ -336,9 +298,7 @@ class SqlTest extends AbstractTestCase
             $col3,
         ];
 
-        $this->assertFalse(
-            $this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta])
-        );
+        self::assertFalse($this->callFunction($this->sql, Sql::class, 'resultSetHasJustOneTable', [$fields_meta]));
     }
 
     /**
@@ -353,7 +313,7 @@ class SqlTest extends AbstractTestCase
         return $analyzedSqlResults;
     }
 
-    public function dataProviderCountQueryResults(): array
+    public static function dataProviderCountQueryResults(): array
     {
         // sql query
         // session tmpval
@@ -370,9 +330,9 @@ class SqlTest extends AbstractTestCase
                 164056,
                 50,
                 false,
-                'SELECT COUNT(*) FROM (select * from game_auth_logs l join ('
+                'SELECT COUNT(*) FROM (SELECT 1 FROM game_auth_logs AS `l` JOIN ('
                     . ' select al.user_id, max(al.id) as id from game_auth_logs al '
-                    . 'where al.successfull = 1 group by al.user_id ) last_log on last_log.id = l.id'
+                    . 'where al.successfull = 1 group by al.user_id ) AS `last_log` ON last_log.id = l.id'
                     . ' ) as cnt',
             ],
             'join on SELECT results with alias.*' => [
@@ -384,9 +344,9 @@ class SqlTest extends AbstractTestCase
                 267,
                 50,
                 false,
-                'SELECT COUNT(*) FROM (select l.* from game_auth_logs l join ('
+                'SELECT COUNT(*) FROM (SELECT 1 FROM game_auth_logs AS `l` JOIN ('
                     . ' select al.user_id, max(al.id) as id from game_auth_logs al '
-                    . 'where al.successfull = 1 group by al.user_id ) last_log on last_log.id = l.id'
+                    . 'where al.successfull = 1 group by al.user_id ) AS `last_log` ON last_log.id = l.id'
                     . ' ) as cnt',
             ],
             [
@@ -562,6 +522,30 @@ class SqlTest extends AbstractTestCase
                 20,
 
             ],
+            [
+                'SELECT DISTINCT country_id FROM city;',
+                ['max_rows' => 25, 'pos' => 0],
+                25,
+                109,
+                false,
+                'SELECT COUNT(*) FROM (SELECT DISTINCT country_id FROM city ) as cnt',
+            ],
+            [
+                'SELECT * FROM t1 UNION SELECT * FROM t2;',
+                ['max_rows' => -1, 'pos' => 0],
+                25,
+                109,
+                false,
+                'SELECT COUNT(*) FROM (SELECT * FROM t1 UNION SELECT * FROM t2 ) as cnt',
+            ],
+            [
+                'SELECT SQL_NO_CACHE * FROM t1 WHERE id <> 0',
+                ['max_rows' => -1, 'pos' => 0],
+                25,
+                100,
+                false,
+                'SELECT COUNT(*) FROM (SELECT 1 FROM t1 WHERE id <> 0 ) as cnt',
+            ],
         ];
     }
 
@@ -605,7 +589,7 @@ class SqlTest extends AbstractTestCase
                 $analyzed_sql_results,
             ]
         );
-        $this->assertSame($expectedNumRows, $result);
+        self::assertSame($expectedNumRows, $result);
         $this->assertAllQueriesConsumed();
     }
 
@@ -772,13 +756,145 @@ class SqlTest extends AbstractTestCase
             'SELECT * FROM `sakila`.`country` LIMIT 0, 3;',
             null
         );
-        $this->assertStringContainsString('Showing rows 0 -  2 (3 total', $actual);
-        $this->assertStringContainsString('SELECT * FROM `sakila`.`country` LIMIT 0, 3;', $actual);
-        $this->assertStringContainsString('Afghanistan', $actual);
-        $this->assertStringContainsString('Algeria', $actual);
-        $this->assertStringContainsString('American Samoa', $actual);
-        $this->assertStringContainsString('data-type="int"', $actual);
-        $this->assertStringContainsString('data-type="string"', $actual);
-        $this->assertStringContainsString('data-type="timestamp"', $actual);
+        self::assertStringContainsString('Showing rows 0 -  2 (3 total', $actual);
+        self::assertStringContainsString('SELECT * FROM `sakila`.`country` LIMIT 0, 3;', $actual);
+        self::assertStringContainsString('Afghanistan', $actual);
+        self::assertStringContainsString('Algeria', $actual);
+        self::assertStringContainsString('American Samoa', $actual);
+        self::assertStringContainsString('data-type="int"', $actual);
+        self::assertStringContainsString('data-type="string"', $actual);
+        self::assertStringContainsString('data-type="timestamp"', $actual);
+    }
+
+    public function testGetDetailedProfilingStatsWithoutData(): void
+    {
+        $method = new ReflectionMethod($this->sql, 'getDetailedProfilingStats');
+        if (PHP_VERSION_ID < 80100) {
+            $method->setAccessible(true);
+        }
+
+        self::assertSame(
+            ['total_time' => 0, 'states' => [], 'chart' => [], 'profile' => []],
+            $method->invoke($this->sql, [])
+        );
+    }
+
+    public function testGetDetailedProfilingStatsWithData(): void
+    {
+        $method = new ReflectionMethod($this->sql, 'getDetailedProfilingStats');
+        if (PHP_VERSION_ID < 80100) {
+            $method->setAccessible(true);
+        }
+
+        $profiling = [
+            ['Status' => 'Starting', 'Duration' => '0.000017'],
+            ['Status' => 'checking permissions', 'Duration' => '0.000003'],
+            ['Status' => 'Opening tables', 'Duration' => '0.000152'],
+            ['Status' => 'After opening tables', 'Duration' => '0.000004'],
+            ['Status' => 'System lock', 'Duration' => '0.000002'],
+            ['Status' => 'table lock', 'Duration' => '0.000003'],
+            ['Status' => 'Opening tables', 'Duration' => '0.000008'],
+            ['Status' => 'After opening tables', 'Duration' => '0.000002'],
+            ['Status' => 'System lock', 'Duration' => '0.000002'],
+            ['Status' => 'table lock', 'Duration' => '0.000012'],
+            ['Status' => 'Unlocking tables', 'Duration' => '0.000003'],
+            ['Status' => 'closing tables', 'Duration' => '0.000005'],
+            ['Status' => 'init', 'Duration' => '0.000007'],
+            ['Status' => 'Optimizing', 'Duration' => '0.000004'],
+            ['Status' => 'Statistics', 'Duration' => '0.000006'],
+            ['Status' => 'Preparing', 'Duration' => '0.000006'],
+            ['Status' => 'Executing', 'Duration' => '0.000002'],
+            ['Status' => 'Sending data', 'Duration' => '0.000029'],
+            ['Status' => 'End of update loop', 'Duration' => '0.000003'],
+            ['Status' => 'Query end', 'Duration' => '0.000002'],
+            ['Status' => 'Commit', 'Duration' => '0.000002'],
+            ['Status' => 'closing tables', 'Duration' => '0.000002'],
+            ['Status' => 'Unlocking tables', 'Duration' => '0.000001'],
+            ['Status' => 'closing tables', 'Duration' => '0.000002'],
+            ['Status' => 'Starting cleanup', 'Duration' => '0.000002'],
+            ['Status' => 'Freeing items', 'Duration' => '0.000002'],
+            ['Status' => 'Updating status', 'Duration' => '0.000007'],
+            ['Status' => 'Reset for next command', 'Duration' => '0.000009'],
+        ];
+        $expected = [
+            'total_time' => 0.000299,
+            'states' => [
+                'Starting' => ['total_time' => '0.000017', 'calls' => 1],
+                'Checking Permissions' => ['total_time' => '0.000003', 'calls' => 1],
+                'Opening Tables' => ['total_time' => 0.00016, 'calls' => 2],
+                'After Opening Tables' => ['total_time' => 6.0E-6, 'calls' => 2],
+                'System Lock' => ['total_time' => 4.0E-6, 'calls' => 2],
+                'Table Lock' => ['total_time' => 1.5E-5, 'calls' => 2],
+                'Unlocking Tables' => ['total_time' => 4.0E-6, 'calls' => 2],
+                'Closing Tables' => ['total_time' => 9.0E-6, 'calls' => 3],
+                'Init' => ['total_time' => '0.000007', 'calls' => 1],
+                'Optimizing' => ['total_time' => '0.000004', 'calls' => 1],
+                'Statistics' => ['total_time' => '0.000006', 'calls' => 1],
+                'Preparing' => ['total_time' => '0.000006', 'calls' => 1],
+                'Executing' => ['total_time' => '0.000002', 'calls' => 1],
+                'Sending Data' => ['total_time' => '0.000029', 'calls' => 1],
+                'End Of Update Loop' => ['total_time' => '0.000003', 'calls' => 1],
+                'Query End' => ['total_time' => '0.000002', 'calls' => 1],
+                'Commit' => ['total_time' => '0.000002', 'calls' => 1],
+                'Starting Cleanup' => ['total_time' => '0.000002', 'calls' => 1],
+                'Freeing Items' => ['total_time' => '0.000002', 'calls' => 1],
+                'Updating Status' => ['total_time' => '0.000007', 'calls' => 1],
+                'Reset For Next Command' => ['total_time' => '0.000009', 'calls' => 1],
+            ],
+            'chart' => [
+                'Starting' => '0.000017',
+                'Checking Permissions' => '0.000003',
+                'Opening Tables' => 0.00016,
+                'After Opening Tables' => 6.0E-6,
+                'System Lock' => 4.0E-6,
+                'Table Lock' => 1.5E-5,
+                'Unlocking Tables' => 4.0E-6,
+                'Closing Tables' => 9.0E-6,
+                'Init' => '0.000007',
+                'Optimizing' => '0.000004',
+                'Statistics' => '0.000006',
+                'Preparing' => '0.000006',
+                'Executing' => '0.000002',
+                'Sending Data' => '0.000029',
+                'End Of Update Loop' => '0.000003',
+                'Query End' => '0.000002',
+                'Commit' => '0.000002',
+                'Starting Cleanup' => '0.000002',
+                'Freeing Items' => '0.000002',
+                'Updating Status' => '0.000007',
+                'Reset For Next Command' => '0.000009',
+            ],
+            'profile' => [
+                ['status' => 'Starting', 'duration' => '17 µ', 'duration_raw' => '0.000017'],
+                ['status' => 'Checking Permissions', 'duration' => '3 µ', 'duration_raw' => '0.000003'],
+                ['status' => 'Opening Tables', 'duration' => '152 µ', 'duration_raw' => '0.000152'],
+                ['status' => 'After Opening Tables', 'duration' => '4 µ', 'duration_raw' => '0.000004'],
+                ['status' => 'System Lock', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'Table Lock', 'duration' => '3 µ', 'duration_raw' => '0.000003'],
+                ['status' => 'Opening Tables', 'duration' => '8 µ', 'duration_raw' => '0.000008'],
+                ['status' => 'After Opening Tables', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'System Lock', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'Table Lock', 'duration' => '12 µ', 'duration_raw' => '0.000012'],
+                ['status' => 'Unlocking Tables', 'duration' => '3 µ', 'duration_raw' => '0.000003'],
+                ['status' => 'Closing Tables', 'duration' => '5 µ', 'duration_raw' => '0.000005'],
+                ['status' => 'Init', 'duration' => '7 µ', 'duration_raw' => '0.000007'],
+                ['status' => 'Optimizing', 'duration' => '4 µ', 'duration_raw' => '0.000004'],
+                ['status' => 'Statistics', 'duration' => '6 µ', 'duration_raw' => '0.000006'],
+                ['status' => 'Preparing', 'duration' => '6 µ', 'duration_raw' => '0.000006'],
+                ['status' => 'Executing', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'Sending Data', 'duration' => '29 µ', 'duration_raw' => '0.000029'],
+                ['status' => 'End Of Update Loop', 'duration' => '3 µ', 'duration_raw' => '0.000003'],
+                ['status' => 'Query End', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'Commit', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'Closing Tables', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'Unlocking Tables', 'duration' => '1 µ', 'duration_raw' => '0.000001'],
+                ['status' => 'Closing Tables', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'Starting Cleanup', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'Freeing Items', 'duration' => '2 µ', 'duration_raw' => '0.000002'],
+                ['status' => 'Updating Status', 'duration' => '7 µ', 'duration_raw' => '0.000007'],
+                ['status' => 'Reset For Next Command', 'duration' => '9 µ', 'duration_raw' => '0.000009'],
+            ],
+        ];
+        self::assertSame($expected, $method->invoke($this->sql, $profiling));
     }
 }
