@@ -32,17 +32,14 @@ class SearchTest extends AbstractTestCase
         $_POST['order'] = 'asc';
         $_POST['customWhereClause'] = "name='pma'";
 
-        $this->assertEquals(
-            'SELECT DISTINCT *  FROM `PMA` WHERE name=\'pma\' ORDER BY `name` asc',
+        self::assertSame(
+            'SELECT DISTINCT * FROM `PMA` WHERE name=\'pma\' ORDER BY `name` asc',
             $this->search->buildSqlQuery()
         );
 
         unset($_POST['customWhereClause']);
 
-        $this->assertEquals(
-            'SELECT DISTINCT *  FROM `PMA` ORDER BY `name` asc',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT DISTINCT * FROM `PMA` ORDER BY `name` asc', $this->search->buildSqlQuery());
 
         $_POST['criteriaValues'] = [
             'value1',
@@ -90,14 +87,11 @@ class SearchTest extends AbstractTestCase
             'BETWEEN',
         ];
 
-        $expected = 'SELECT DISTINCT *  FROM `PMA` WHERE `name` != \'value1\''
+        $expected = 'SELECT DISTINCT * FROM `PMA` WHERE `name` != \'value1\''
             . ' AND `id` > value2 AND `index` IS NULL AND `index2` LIKE \'%value4%\''
             . ' AND `index3` REGEXP ^value5$ AND `index4` IN (value6) AND `index5`'
             . ' BETWEEN value7 AND value8 ORDER BY `name` asc';
-        $this->assertEquals(
-            $expected,
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame($expected, $this->search->buildSqlQuery());
     }
 
     public function testBuildSqlQueryWithWhereClause(): void
@@ -105,17 +99,11 @@ class SearchTest extends AbstractTestCase
         $_POST['zoom_submit'] = true;
         $_POST['table'] = 'PMA';
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA`',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA`', $this->search->buildSqlQuery());
 
         $_POST['customWhereClause'] = '`table` = \'WhereClause\'';
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA` WHERE `table` = \'WhereClause\'',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA` WHERE `table` = \'WhereClause\'', $this->search->buildSqlQuery());
 
         unset($_POST['customWhereClause']);
         $_POST['criteriaColumnNames'] = [
@@ -143,8 +131,8 @@ class SearchTest extends AbstractTestCase
             'int(11)',
         ];
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA` WHERE `b` <= 10 AND `a` = 2 AND `c` IS NULL AND `d` IS NOT NULL',
+        self::assertSame(
+            'SELECT * FROM `PMA` WHERE `b` <= 10 AND `a` = 2 AND `c` IS NULL AND `d` IS NOT NULL',
             $this->search->buildSqlQuery()
         );
     }
@@ -154,17 +142,11 @@ class SearchTest extends AbstractTestCase
         $_POST['zoom_submit'] = true;
         $_POST['table'] = 'PMA';
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA`',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA`', $this->search->buildSqlQuery());
 
         $_POST['customWhereClause'] = '`table` = \'WhereClause\'';
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA` WHERE `table` = \'WhereClause\'',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA` WHERE `table` = \'WhereClause\'', $this->search->buildSqlQuery());
 
         unset($_POST['customWhereClause']);
         $_POST['criteriaColumnNames'] = ['b'];
@@ -173,10 +155,7 @@ class SearchTest extends AbstractTestCase
         $_POST['criteriaValues'] = ['1'];
         $_POST['criteriaColumnTypes'] = ['geometry'];
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA` WHERE Dimension(`b`) = \'1\'',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA` WHERE Dimension(`b`) = \'1\'', $this->search->buildSqlQuery());
     }
 
     public function testBuildSqlQueryWithWhereClauseEnum(): void
@@ -184,17 +163,11 @@ class SearchTest extends AbstractTestCase
         $_POST['zoom_submit'] = true;
         $_POST['table'] = 'PMA';
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA`',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA`', $this->search->buildSqlQuery());
 
         $_POST['customWhereClause'] = '`table` = \'WhereClause\'';
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA` WHERE `table` = \'WhereClause\'',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA` WHERE `table` = \'WhereClause\'', $this->search->buildSqlQuery());
 
         unset($_POST['customWhereClause']);
         $_POST['criteriaColumnNames'] = ['rating'];
@@ -203,10 +176,7 @@ class SearchTest extends AbstractTestCase
         $_POST['criteriaValues'] = ['PG-13'];
         $_POST['criteriaColumnTypes'] = ['enum(\'G\', \'PG\', \'PG-13\', \'R\', \'NC-17\')'];
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA` WHERE `rating` = \'PG-13\'',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA` WHERE `rating` = \'PG-13\'', $this->search->buildSqlQuery());
     }
 
     public function testBuildSqlQueryWithWhereClauseUUID(): void
@@ -214,17 +184,11 @@ class SearchTest extends AbstractTestCase
         $_POST['zoom_submit'] = true;
         $_POST['table'] = 'PMA';
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA`',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA`', $this->search->buildSqlQuery());
 
         $_POST['customWhereClause'] = '';
 
-        $this->assertEquals(
-            'SELECT *  FROM `PMA`',
-            $this->search->buildSqlQuery()
-        );
+        self::assertSame('SELECT * FROM `PMA`', $this->search->buildSqlQuery());
 
         unset($_POST['customWhereClause']);
         $_POST['criteriaColumnNames'] = ['id'];
@@ -233,9 +197,26 @@ class SearchTest extends AbstractTestCase
         $_POST['criteriaValues'] = ['07ca1fdd-4805-11ed-a4dc-0242ac110002'];
         $_POST['criteriaColumnTypes'] = ['uuid'];
 
-        $this->assertEquals(
-            "SELECT *  FROM `PMA` WHERE `id` = '07ca1fdd-4805-11ed-a4dc-0242ac110002'",
+        self::assertSame(
+            "SELECT * FROM `PMA` WHERE `id` = '07ca1fdd-4805-11ed-a4dc-0242ac110002'",
             $this->search->buildSqlQuery()
         );
     }
+
+    public function testBuildSqlQueryWithoutConditions(): void
+    {
+        $_POST['db'] = 'opengis';
+        $_POST['table'] = 'world_cities';
+        $_POST['back'] = 'index.php?route=/table/search';
+        $_POST['geom_func'] = [2 => ' '];
+        $_POST['customWhereClause'] = '';
+        $_POST['session_max_rows'] = '25';
+        $_POST['orderByColumn'] = '--nil--';
+        $_POST['order'] = 'ASC';
+        $_POST['submit'] = 'Go';
+        $_POST['ajax_request'] = 'true';
+        $_POST['displayAllColumns'] = 'true';
+
+        self::assertSame('SELECT * FROM `world_cities`', $this->search->buildSqlQuery());
+    }
 }
