@@ -12,6 +12,8 @@ use PhpMyAdmin\Tracker;
 use PhpMyAdmin\Util;
 use ReflectionMethod;
 
+use const PHP_VERSION_ID;
+
 /**
  * @covers \PhpMyAdmin\Tracker
  */
@@ -53,13 +55,9 @@ class TrackerTest extends AbstractTestCase
      */
     public function testEnabled(): void
     {
-        $this->assertFalse(
-            Cache::has(Tracker::TRACKER_ENABLED_CACHE_KEY)
-        );
+        self::assertFalse(Cache::has(Tracker::TRACKER_ENABLED_CACHE_KEY));
         Tracker::enable();
-        $this->assertTrue(
-            Cache::get(Tracker::TRACKER_ENABLED_CACHE_KEY)
-        );
+        self::assertTrue(Cache::get(Tracker::TRACKER_ENABLED_CACHE_KEY));
     }
 
     /**
@@ -67,22 +65,16 @@ class TrackerTest extends AbstractTestCase
      */
     public function testIsActive(): void
     {
-        $this->assertFalse(
-            Cache::has(Tracker::TRACKER_ENABLED_CACHE_KEY)
-        );
+        self::assertFalse(Cache::has(Tracker::TRACKER_ENABLED_CACHE_KEY));
 
-        $this->assertFalse(
-            Tracker::isActive()
-        );
+        self::assertFalse(Tracker::isActive());
 
         Tracker::enable();
 
         $_SESSION['relation'] = [];
         $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([])->toArray();
 
-        $this->assertFalse(
-            Tracker::isActive()
-        );
+        self::assertFalse(Tracker::isActive());
 
         $_SESSION['relation'] = [];
         $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
@@ -91,9 +83,7 @@ class TrackerTest extends AbstractTestCase
             'tracking' => 'tracking',
         ])->toArray();
 
-        $this->assertTrue(
-            Tracker::isActive()
-        );
+        self::assertTrue(Tracker::isActive());
     }
 
     /**
@@ -106,10 +96,7 @@ class TrackerTest extends AbstractTestCase
      */
     public function testGetTableName(string $string, string $expected): void
     {
-        $this->assertEquals(
-            $expected,
-            $this->callFunction(null, Tracker::class, 'getTableName', [$string])
-        );
+        self::assertSame($expected, $this->callFunction(null, Tracker::class, 'getTableName', [$string]));
     }
 
     /**
@@ -117,7 +104,7 @@ class TrackerTest extends AbstractTestCase
      *
      * @return array Test data
      */
-    public function getTableNameData(): array
+    public static function getTableNameData(): array
     {
         return [
             [
@@ -140,22 +127,16 @@ class TrackerTest extends AbstractTestCase
      */
     public function testIsTracked(): void
     {
-        $this->assertFalse(
-            Cache::has(Tracker::TRACKER_ENABLED_CACHE_KEY)
-        );
+        self::assertFalse(Cache::has(Tracker::TRACKER_ENABLED_CACHE_KEY));
 
-        $this->assertFalse(
-            Tracker::isTracked('', '')
-        );
+        self::assertFalse(Tracker::isTracked('', ''));
 
         Tracker::enable();
 
         $_SESSION['relation'] = [];
         $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([])->toArray();
 
-        $this->assertFalse(
-            Tracker::isTracked('', '')
-        );
+        self::assertFalse(Tracker::isTracked('', ''));
 
         $_SESSION['relation'] = [];
         $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
@@ -164,13 +145,9 @@ class TrackerTest extends AbstractTestCase
             'tracking' => 'tracking',
         ])->toArray();
 
-        $this->assertTrue(
-            Tracker::isTracked('pma_test_db', 'pma_test_table')
-        );
+        self::assertTrue(Tracker::isTracked('pma_test_db', 'pma_test_table'));
 
-        $this->assertFalse(
-            Tracker::isTracked('pma_test_db', 'pma_test_table2')
-        );
+        self::assertFalse(Tracker::isTracked('pma_test_db', 'pma_test_table2'));
     }
 
     /**
@@ -181,14 +158,13 @@ class TrackerTest extends AbstractTestCase
         $date = Util::date('Y-m-d H:i:s');
         $GLOBALS['cfg']['Server']['user'] = 'pma_test_user';
 
-        $this->assertEquals(
-            '# log ' . $date . " pma_test_user\n",
-            Tracker::getLogComment()
-        );
+        self::assertSame('# log ' . $date . " pma_test_user\n", Tracker::getLogComment());
     }
 
     /**
      * Test for Tracker::createVersion()
+     *
+     * @requires PHPUnit < 10
      */
     public function testCreateVersion(): void
     {
@@ -253,7 +229,7 @@ class TrackerTest extends AbstractTestCase
             ->will($this->returnValue([]));
 
         $GLOBALS['dbi'] = $dbi;
-        $this->assertTrue(Tracker::createVersion('pma_test', 'pma_tbl', '1', '11', true));
+        self::assertTrue(Tracker::createVersion('pma_test', 'pma_tbl', '1', '11', true));
     }
 
     /**
@@ -280,7 +256,7 @@ class TrackerTest extends AbstractTestCase
             ->will($this->returnArgument(0));
 
         $GLOBALS['dbi'] = $dbi;
-        $this->assertTrue(Tracker::deleteTracking('testdb', 'testtable'));
+        self::assertTrue(Tracker::deleteTracking('testdb', 'testtable'));
     }
 
     /**
@@ -313,7 +289,7 @@ class TrackerTest extends AbstractTestCase
             ->will($this->returnArgument(0));
 
         $GLOBALS['dbi'] = $dbi;
-        $this->assertTrue(Tracker::createDatabaseVersion('pma_test', '1', 'SHOW DATABASES'));
+        self::assertTrue(Tracker::createDatabaseVersion('pma_test', '1', 'SHOW DATABASES'));
     }
 
     /**
@@ -357,7 +333,10 @@ class TrackerTest extends AbstractTestCase
 
         if ($type === null) {
             $method = new ReflectionMethod(Tracker::class, 'changeTracking');
-            $method->setAccessible(true);
+            if (PHP_VERSION_ID < 80100) {
+                $method->setAccessible(true);
+            }
+
             $method->invoke(null, $dbname, $tablename, $version, $new_state);
         } elseif ($type === 'activate') {
             Tracker::activateTracking($dbname, $tablename, $version);
@@ -373,9 +352,7 @@ class TrackerTest extends AbstractTestCase
      */
     public function testChangeTrackingData(): void
     {
-        $this->assertFalse(
-            Tracker::changeTrackingData('', '', '', '', '')
-        );
+        self::assertFalse(Tracker::changeTrackingData('', '', '', '', ''));
 
         $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
@@ -431,25 +408,21 @@ class TrackerTest extends AbstractTestCase
 
         $GLOBALS['dbi'] = $dbi;
 
-        $this->assertTrue(
-            Tracker::changeTrackingData(
-                'pma_db',
-                'pma_table',
-                '1.0',
-                'DDL',
-                '# new_data_processed'
-            )
-        );
+        self::assertTrue(Tracker::changeTrackingData(
+            'pma_db',
+            'pma_table',
+            '1.0',
+            'DDL',
+            '# new_data_processed'
+        ));
 
-        $this->assertTrue(
-            Tracker::changeTrackingData(
-                'pma_db',
-                'pma_table',
-                '1.0',
-                'DML',
-                $new_data
-            )
-        );
+        self::assertTrue(Tracker::changeTrackingData(
+            'pma_db',
+            'pma_table',
+            '1.0',
+            'DML',
+            $new_data
+        ));
     }
 
     /**
@@ -516,7 +489,7 @@ class TrackerTest extends AbstractTestCase
         $GLOBALS['dbi'] = $dbi;
         $result = Tracker::getTrackedData("pma'db", "pma'table", '1.0');
 
-        $this->assertEquals($expectedArray, $result);
+        self::assertEquals($expectedArray, $result);
     }
 
     /**
@@ -524,7 +497,7 @@ class TrackerTest extends AbstractTestCase
      *
      * @return array Test data
      */
-    public function getTrackedDataProvider(): array
+    public static function getTrackedDataProvider(): array
     {
         $fetchArrayReturn = [
             [
@@ -632,21 +605,21 @@ class TrackerTest extends AbstractTestCase
     ): void {
         $result = Tracker::parseQuery($query);
 
-        $this->assertEquals($type, $result['type']);
+        self::assertSame($type, $result['type']);
 
-        $this->assertEquals($identifier, $result['identifier']);
+        self::assertSame($identifier, $result['identifier']);
 
-        $this->assertEquals($tablename, $result['tablename']);
+        self::assertSame($tablename, $result['tablename']);
 
         if ($db) {
-            $this->assertEquals($db, $GLOBALS['db']);
+            self::assertSame($db, $GLOBALS['db']);
         }
 
         if (! $tablename_after_rename) {
             return;
         }
 
-        $this->assertEquals($result['tablename_after_rename'], $tablename_after_rename);
+        self::assertSame($result['tablename_after_rename'], $tablename_after_rename);
     }
 
     /**
@@ -654,7 +627,7 @@ class TrackerTest extends AbstractTestCase
      *
      * @return array Test data
      */
-    public function parseQueryData(): array
+    public static function parseQueryData(): array
     {
         // query
         // type
