@@ -66,7 +66,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
 
         if ($includes) {
             foreach ($includes as $value) {
-                $this->assertContains($value, $result);
+                self::assertContains($value, $result);
             }
         }
 
@@ -75,7 +75,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
         }
 
         foreach ($excludes as $value) {
-            $this->assertNotContains($value, $result);
+            self::assertNotContains($value, $result);
         }
     }
 
@@ -84,7 +84,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
      *
      * @psalm-return array<string, array{string, int, string, array<string>, array<string>}>
      */
-    public function providerFortTestGetFunctionsClass(): array
+    public static function providerFortTestGetFunctionsClass(): array
     {
         return [
             'mysql 5.1.0 - CHAR - not support INET6 Converter' => [
@@ -286,7 +286,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
 
         if ($includes) {
             foreach ($includes as $value) {
-                $this->assertContains($value, $result);
+                self::assertContains($value, $result);
             }
         }
 
@@ -295,7 +295,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
         }
 
         foreach ($excludes as $value) {
-            $this->assertNotContains($value, $result);
+            self::assertNotContains($value, $result);
         }
     }
 
@@ -304,7 +304,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
      *
      * @psalm-return array<string, array{string, int, array<string>, array<string>}>
      */
-    public function providerFortTestGetFunctions(): array
+    public static function providerFortTestGetFunctions(): array
     {
         return [
             'mysql 5.1.0 - not support INET6 Converter' => [
@@ -362,7 +362,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
 
         if ($includes) {
             foreach ($includes as $value) {
-                $this->assertContains($value, $result);
+                self::assertContains($value, $result);
             }
         }
 
@@ -371,7 +371,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
         }
 
         foreach ($excludes as $value) {
-            $this->assertNotContains($value, $result);
+            self::assertNotContains($value, $result);
         }
     }
 
@@ -380,7 +380,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
      *
      * @psalm-return array<string, array{string, int, array<string>, array<string>}>
      */
-    public function providerFortTestGetAllFunctions(): array
+    public static function providerFortTestGetAllFunctions(): array
     {
         return [
             'mysql 5.1.0 - not support INET6_ATON, ST_Geometry' => [
@@ -618,7 +618,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
     {
         $this->createObject($database, $dbVersion);
 
-        $this->assertEquals($expected, $this->object->getColumns());
+        self::assertSame($expected, $this->object->getColumns());
     }
 
     /**
@@ -626,7 +626,7 @@ class TypesByDatabaseVersionTest extends AbstractTestCase
      *
      * @psalm-return array<string, array{string, int, array<int|string, array<int, string>|string>}>
      */
-    public function providerFortTestGetColumns(): array
+    public static function providerFortTestGetColumns(): array
     {
         return [
             'mysql 5.1.0 - not support INET6, JSON and UUID' => [
