@@ -125,31 +125,29 @@ class EventsTest extends TestBase
         // Refresh the page
         $this->webDriver->navigate()->refresh();
 
-        $this->assertTrue(
-            $this->isElementPresent(
-                'xpath',
-                "//td[contains(., 'test_event')]"
-            )
-        );
+        self::assertTrue($this->isElementPresent(
+            'xpath',
+            "//td[contains(., 'test_event')]"
+        ));
 
         $this->dbQuery(
             'USE `' . $this->databaseName . '`;'
             . 'SHOW EVENTS WHERE Db=\'' . $this->databaseName . '\' AND Name=\'test_event\';',
             function (): void {
-                $this->assertTrue($this->isElementPresent('className', 'table_results'));
-                $this->assertEquals($this->databaseName, $this->getCellByTableClass('table_results', 1, 1));
-                $this->assertEquals('test_event', $this->getCellByTableClass('table_results', 1, 2));
-                $this->assertEquals('RECURRING', $this->getCellByTableClass('table_results', 1, 5));
+                self::assertTrue($this->isElementPresent('className', 'table_results'));
+                self::assertEquals($this->databaseName, $this->getCellByTableClass('table_results', 1, 1));
+                self::assertEquals('test_event', $this->getCellByTableClass('table_results', 1, 2));
+                self::assertEquals('RECURRING', $this->getCellByTableClass('table_results', 1, 5));
             }
         );
 
         sleep(2);
         $this->dbQuery(
-            'SELECT val FROM `' . $this->databaseName . '`.`test_table`',
+            'SELECT * FROM `' . $this->databaseName . '`.`test_table`',
             function (): void {
-                $this->assertTrue($this->isElementPresent('className', 'table_results'));
+                $this->scrollToElement($this->waitForElement('className', 'table_results'), 0, 20);
                 // [ ] | Edit | Copy | Delete | 1 | <number>
-                $this->assertGreaterThan(2, (int) $this->getCellByTableClass('table_results', 1, 5));
+                self::assertGreaterThan(2, (int) $this->getCellByTableClass('table_results', 1, 6));
             }
         );
     }
@@ -183,11 +181,11 @@ class EventsTest extends TestBase
 
         sleep(2);
         $this->dbQuery(
-            'SELECT val FROM `' . $this->databaseName . '`.`test_table`',
+            'SELECT * FROM `' . $this->databaseName . '`.`test_table`',
             function (): void {
-                $this->assertTrue($this->isElementPresent('className', 'table_results'));
+                $this->scrollToElement($this->waitForElement('className', 'table_results'), 0, 20);
                 // [ ] | Edit | Copy | Delete | 4
-                $this->assertGreaterThan(3, (int) $this->getCellByTableClass('table_results', 1, 5));
+                self::assertGreaterThan(3, (int) $this->getCellByTableClass('table_results', 1, 6));
             }
         );
     }
@@ -215,7 +213,8 @@ class EventsTest extends TestBase
             'USE `' . $this->databaseName . '`;'
             . 'SHOW EVENTS WHERE Db=\'' . $this->databaseName . '\' AND Name=\'test_event\';',
             function (): void {
-                $this->assertFalse($this->isElementPresent('className', 'table_results'));
+                self::assertTrue($this->isElementPresent('className', 'table_results'));
+                self::assertFalse($this->isElementPresent('cssSelector', '.table_results tbody tr'));
             }
         );
     }
