@@ -111,7 +111,7 @@ class QueryByExampleTest extends TestBase
         $actual = trim((string) $this->waitForElement('id', 'textSqlquery')->getAttribute('value'));
 
         /* Compare generated query */
-        $this->assertEquals($expected, $actual);
+        self::assertEquals($expected, $actual);
 
         /* Submit the query */
         $submitButton = $this->waitForElement('cssSelector', '#tblQbeFooters > input[type=submit]');
@@ -119,56 +119,26 @@ class QueryByExampleTest extends TestBase
         $submitButton->click();
         $this->waitAjax();
 
-        $this->waitForElement('cssSelector', 'table.table_results');
+        $this->scrollToElement($this->waitForElement('className', 'table_results'), 0, 20);
 
         /* Assert Row 1 */
-        $this->assertEquals(
-            4,
-            $this->getCellByTableClass('table_results', 1, 5)
-        );
-        $this->assertEquals(
-            3,
-            $this->getCellByTableClass('table_results', 1, 6)
-        );
+        self::assertEquals(4, $this->getCellByTableClass('table_results', 1, 1));
+        self::assertEquals(3, $this->getCellByTableClass('table_results', 1, 2));
 
         /* Assert Row 2 */
-        $this->assertEquals(
-            6,
-            $this->getCellByTableClass('table_results', 2, 5)
-        );
-        $this->assertEquals(
-            4,
-            $this->getCellByTableClass('table_results', 2, 6)
-        );
+        self::assertEquals(6, $this->getCellByTableClass('table_results', 2, 1));
+        self::assertEquals(4, $this->getCellByTableClass('table_results', 2, 2));
 
         /* Assert Row 3 */
-        $this->assertEquals(
-            5,
-            $this->getCellByTableClass('table_results', 3, 5)
-        );
-        $this->assertEquals(
-            4,
-            $this->getCellByTableClass('table_results', 3, 6)
-        );
+        self::assertEquals(5, $this->getCellByTableClass('table_results', 3, 1));
+        self::assertEquals(4, $this->getCellByTableClass('table_results', 3, 2));
 
         /* Assert Row 4 */
-        $this->assertEquals(
-            7,
-            $this->getCellByTableClass('table_results', 4, 5)
-        );
-        $this->assertEquals(
-            5,
-            $this->getCellByTableClass('table_results', 4, 6)
-        );
+        self::assertEquals(7, $this->getCellByTableClass('table_results', 4, 1));
+        self::assertEquals(5, $this->getCellByTableClass('table_results', 4, 2));
 
         /* Assert Row 5 */
-        $this->assertEquals(
-            3,
-            $this->getCellByTableClass('table_results', 5, 5)
-        );
-        $this->assertEquals(
-            5,
-            $this->getCellByTableClass('table_results', 5, 6)
-        );
+        self::assertEquals(3, $this->getCellByTableClass('table_results', 5, 1));
+        self::assertEquals(5, $this->getCellByTableClass('table_results', 5, 2));
     }
 }
